package com.brilliance.swift;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2SwiftDto.Mt2SwiftDtoCreateManager;
import com.brilliance.swift.mx2map.Mx2MapCreatorManager;
import com.brilliance.swift.mx2mt.Mx2MtCreatorManager;
import com.brilliance.swift.swiftdto2mx.SwiftDto2MxCreatorManager;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.util.XmlUtil;
import com.brilliance.swift.vo.SwiftDto;
import com.prowidesoftware.swift.model.mx.AbstractMX;
import org.apache.commons.io.FileUtils;
import org.dom4j.Document;
import org.dom4j.DocumentException;
import org.dom4j.DocumentHelper;

import java.io.File;
import java.io.IOException;
import java.util.Map;

public class SwiftTransfer {

    /**
     * MX TRANSFER MT
     */
    public static String mx2Mt(File file, String outPutFilePath, Map<String, Object> extraMap) throws SwiftException {
        try{
            String xmlStr = FileUtils.readFileToString(file);
            return mx2Mt(xmlStr, outPutFilePath, extraMap);
        } catch (IOException e) {
            throw new SwiftException("ERROR", e.getMessage());
        }

    }

    public static String mx2Mt(String xmlStr, String outPutFilePath, Map<String, Object> extraMap) throws SwiftException {
        return new Mx2MtCreatorManager().mx2Mt(xmlStr, outPutFilePath, extraMap);
    }

    /**
     * MT TRANSFER MX
     */
    public static String mt2Mx(File file, String outPutFilePath, Map<String, Object> extraMap) throws SwiftException {
        try{
            String mtStr = FileUtils.readFileToString(file);
            SwiftDto swiftDto = new Mt2SwiftDtoCreateManager().convert(mtStr, outPutFilePath, extraMap);
            return new SwiftDto2MxCreatorManager().swiftDto2Mx(swiftDto, outPutFilePath);
        } catch (IOException e) {
            throw new SwiftException("ERROR", e.getMessage());
        }
    }

    public static String mt2Mx(String mtStr, String outPutFilePath, Map<String, Object> extraMap) throws SwiftException {
        SwiftDto swiftDto = new Mt2SwiftDtoCreateManager().convert(mtStr, outPutFilePath, extraMap);
        return new SwiftDto2MxCreatorManager().swiftDto2Mx(swiftDto, outPutFilePath);
    }

    /**
     * swift xml输出mt 相关的map
     * 用于邮储版本
     * @param xmlStr
     * @param extraMap
     * @return
     * @throws SwiftException
     */
    public static Map<String, String> mx2MtMap(String xmlStr, Map<String, Object> extraMap) throws SwiftException {
        try {
            String mtStr = new Mx2MtCreatorManager().mx2Mt(xmlStr, null, extraMap);
            Map<String, String> maps = MessageReader.getSwfMsgInfoViaMsg(mtStr);
            AbstractMX abstractMx = AbstractMX.parse(xmlStr);
            if (abstractMx != null) {
                String messageType = abstractMx.getMxId().id();
                maps.put("xty", messageType);//ISO20022类型
                if (messageType.startsWith("pacs.008.001") || messageType.startsWith("pacs.009.001")) {
                    Document document = DocumentHelper.parseText(xmlStr);
                    Map<String, String> parentElementMaps = XmlUtil.getParentElementMaps(document);
                    String bodyParentElementName = parentElementMaps.get("CdtTrfTxInf");
                    String endToEndId = XmlUtil.getXmlNodeValue(document, bodyParentElementName + ".CdtTrfTxInf.PmtId.EndToEndId");
                    if (StringUtil.isNotEmpty(endToEndId)) {
                        maps.put("endToEndId", endToEndId);
                    }
                }
            }
            return maps;
        } catch (DocumentException e) {
            throw new SwiftException("ERROR", e.getMessage());
        }

    }

    /**
     * 将MX xml转换成gson 字符串
     * @param xmlStr
     * @return
     */
    public static String mx2Gson(String xmlStr) {
        if (StringUtil.isEmpty(xmlStr)) return null;
        AbstractMX abstractMX = AbstractMX.parse(xmlStr);
        String gsonStr = abstractMX.toJson();
        return gsonStr;
    }

    /**
     * 将MX xml转换成Map<String, String>
     * @param xmlStr
     * @return
     */
    public static Map<String, String> mx2Map(String xmlStr) {
        if (StringUtil.isEmpty(xmlStr)) return null;
        return new Mx2MapCreatorManager().mx2Map(xmlStr);
    }

}
