package com.brilliance.swift.mt2SwiftDto;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.SwiftHeader;
import com.brilliance.swift.vo.common.MessagePriority;
import com.brilliance.swift.vo.common.TransactionReference;
import com.prowidesoftware.swift.model.mt.AbstractMT;

import java.util.Date;

public abstract class AbstractMt2SwiftDtoCreator implements Mt2SwiftDtoCreator {

    protected Mt2SwiftDtoContext context;

    public Mt2SwiftDtoContext getContext() {
        return context;
    }

    public void setContext(Mt2SwiftDtoContext context) {
        this.context = context;
    }

    public SwiftHeader buildSwiftHeader() throws SwiftException {
        SwiftHeader swiftHeader = new SwiftHeader();
        AbstractMT abstractMT = context.get(AbstractMT.class);
        String senderBic = abstractMT.getSender();
        if (senderBic.endsWith(Mx2MtConstants.BICSUFFIX)) {
            senderBic = senderBic.substring(0, 8);
        } else {
            senderBic = senderBic.substring(0, 8) + senderBic.substring(9, 12);
        }
        swiftHeader.setSenderBic(senderBic);

        String receiverBic = abstractMT.getReceiver();
        if (receiverBic.endsWith(Mx2MtConstants.BICSUFFIX)) {
            receiverBic = receiverBic.substring(0, 8);
        } else {
            receiverBic = receiverBic.substring(0, 8) + receiverBic.substring(9, 12);
        }
        swiftHeader.setReceiverBic(receiverBic);
        swiftHeader.setCreateDate(new Date());
        String priority = abstractMT.getMessagePriority();
        if ("N".equals(priority)) {
            swiftHeader.setMessagePriority(MessagePriority.NORM);
        } else if ("U".equals(priority) || "S".equals(priority)) {
            swiftHeader.setMessagePriority(MessagePriority.HIGH);
        }
        return swiftHeader;
    }

    public TransactionReference buildTxnRef() throws SwiftException {
        TransactionReference txnRef = new TransactionReference();
        AbstractMT abstractMT = context.get(AbstractMT.class);
        String uetr = abstractMT.getSwiftMessage().getUETR();
        if (StringUtil.isNotEmpty(uetr)) {
            txnRef.setUetr(uetr);
        }
        return txnRef;
    }
}
