package com.brilliance.swift.mt2SwiftDto.camt053001.impl;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2SwiftDto.AbstractMt2SwiftDtoParseFields;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.vo.BankToCustomerStatement;
import com.brilliance.swift.vo.common.*;
import com.prowidesoftware.swift.model.field.Field60F;
import com.prowidesoftware.swift.model.field.Field60M;
import com.prowidesoftware.swift.model.mt.AbstractMT;
import com.prowidesoftware.swift.model.mt9xx.MT940;
import com.prowidesoftware.swift.model.mt9xx.MT950;

/**
 * @author zh
 * @create 2022-04-24 14:59
 */
public class Camt053001Parse60aField extends AbstractMt2SwiftDtoParseFields {
    @Override
    public void parseFields() throws SwiftException {
        try {
            BankToCustomerStatement bankToCustomerStatement = context.get(BankToCustomerStatement.class);
            Field60F field60F = getField60F();
            if (field60F != null) {
                CashBalance cashBalance = new CashBalance();
                cashBalance.setCode(BalanceTypeCode.PRCD);
                cashBalance.setCdtDbtCode("D".equals(field60F.getDCMark())? CdtDbtCode.DBIT:CdtDbtCode.CRDT);
                cashBalance.setDate(DateUtil.parseDate("20"+field60F.getDate(), "yyyyMMdd"));
                CcyFormatAmount ccyFormatAmount = new CcyFormatAmount();
                ccyFormatAmount.setCcy(field60F.getCurrency());
                ccyFormatAmount.setAmt(field60F.amount());
                cashBalance.setAmt(ccyFormatAmount);
                bankToCustomerStatement.setOpeningBalance(cashBalance);
            } else {
                Field60M field60M = getField60M();
                if (field60M != null) {
                    CashBalance cashBalance = new CashBalance();
                    cashBalance.setCode(BalanceTypeCode.ITBD);
                    cashBalance.setCdtDbtCode("D".equals(field60M.getDCMark())? CdtDbtCode.DBIT:CdtDbtCode.CRDT);
                    cashBalance.setDate(DateUtil.parseDate("20"+field60M.getDate(), "yyyyMMdd"));
                    CcyFormatAmount ccyFormatAmount = new CcyFormatAmount();
                    ccyFormatAmount.setCcy(field60M.getCurrency());
                    ccyFormatAmount.setAmt(field60M.amount());
                    cashBalance.setAmt(ccyFormatAmount);
                    bankToCustomerStatement.setOpeningBalance(cashBalance);
                }
            }
        }catch (Exception e){
            throw new SwiftException("ERROR", e.getMessage());
        }
    }

    private Field60F getField60F() {
        AbstractMT abstractMT = context.get(AbstractMT.class);
        if ("940".equals(abstractMT.getMessageType())) {
            MT940 mt940 = (MT940) context.get(AbstractMT.class);
            return mt940.getField60F();
        } else {
            MT950 mt950 = (MT950) context.get(AbstractMT.class);
            return mt950.getField60F();
        }
    }

    private Field60M getField60M() {
        AbstractMT abstractMT = context.get(AbstractMT.class);
        if ("940".equals(abstractMT.getMessageType())) {
            MT940 mt940 = (MT940) context.get(AbstractMT.class);
            return mt940.getField60M();
        } else {
            MT950 mt950 = (MT950) context.get(AbstractMT.class);
            return mt950.getField60M();
        }
    }
}
