package com.brilliance.swift.mt2SwiftDto.camt053001.impl;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2SwiftDto.AbstractMt2SwiftDtoParseFields;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.vo.BankToCustomerStatement;
import com.brilliance.swift.vo.common.BankTransactionCodeStructure;
import com.brilliance.swift.vo.common.CcyFormatAmount;
import com.brilliance.swift.vo.common.CdtDbtCode;
import com.brilliance.swift.vo.common.ReportEntry;
import com.prowidesoftware.swift.model.Tag;
import com.prowidesoftware.swift.model.field.Field61;
import com.prowidesoftware.swift.model.field.Field86;
import com.prowidesoftware.swift.model.mt.AbstractMT;

import java.math.BigDecimal;
import java.util.List;

/**
 * @author zh
 * @create 2022-04-24 14:59
 */
public class Camt053001Parse61Field extends AbstractMt2SwiftDtoParseFields {

    private String name_61 = "61";

    private String name_86 = "86";

    @Override
    public void parseFields() throws SwiftException {
        try {
            BankToCustomerStatement bankToCustomerStatement = context.get(BankToCustomerStatement.class);
            AbstractMT abstractMT = context.get(AbstractMT.class);
            List<Tag> tags = abstractMT.getSwiftMessage().getBlock4().getTags();
            if (tags.size() > 0) {
                for (int i=0; i< tags.size(); i++) {
                    Tag tag = tags.get(i);
                    if (name_61.equals(tag.getName())) {
                        Field61 field61 = new Field61(tag.getValue());
                        ReportEntry reportEntry = new ReportEntry();
                        reportEntry.setValueDate(DateUtil.parseDate("20"+field61.getValueDate(), "yyyyMMdd"));
                        reportEntry.setBookDate(DateUtil.parseDate("20"+field61.getEntryDate(), "yyyyMMdd"));
                        String dcMark = field61.getDCMark();
                        if ("C".equals(dcMark)) {
                            reportEntry.setCdtDbtCode(CdtDbtCode.CRDT);
                        } else if ("RC".equals(dcMark)) {
                            reportEntry.setCdtDbtCode(CdtDbtCode.CRDT);
                            reportEntry.setReversalIndicator(true);
                        } else if ("D".equals(dcMark)) {
                            reportEntry.setCdtDbtCode(CdtDbtCode.DBIT);
                        } else if ("RD".equals(dcMark)) {
                            reportEntry.setCdtDbtCode(CdtDbtCode.DBIT);
                            reportEntry.setReversalIndicator(true);
                        }
                        String ccy = field61.getFundsCode();
                        BigDecimal amt = field61.amount();
                        CcyFormatAmount ccyFormatAmount = new CcyFormatAmount();
                        ccyFormatAmount.setCcy(ccy);
                        ccyFormatAmount.setAmt(amt);
                        reportEntry.setAmt(ccyFormatAmount);

                        String txnType = field61.getTransactionType();
                        String identificationCode = field61.getIdentificationCode();
                        /*String mxCode = getDomainCodeByIdentyCode(identificationCode);
                        if (StringUtil.isNotEmpty(mxCode)) {
                            BankTransactionCodeStructure bankTransactionCodeStructure = new BankTransactionCodeStructure();
                            String[] mxCodes = mxCode.split("_");
                            bankTransactionCodeStructure.setDomianCode(mxCodes[0]);
                            bankTransactionCodeStructure.setFamilyCode(mxCodes[1]);
                            bankTransactionCodeStructure.setSubFamilyCode(mxCodes[2]);
                            reportEntry.setBankTransactionCodeStructure(bankTransactionCodeStructure);
                        } else {*/
                            BankTransactionCodeStructure bankTransactionCodeStructure = new BankTransactionCodeStructure();
                            bankTransactionCodeStructure.setCode(txnType + identificationCode);
                            reportEntry.setBankTransactionCodeStructure(bankTransactionCodeStructure);
                        /*}*/
                        reportEntry.setEndToEndId(field61.getReferenceForTheAccountOwner());
                        reportEntry.setAcctSvcrRef(field61.getReferenceOfTheAccountServicingInstitution());
                        reportEntry.setAddtlTxInf(field61.getSupplementaryDetails());
                        if (name_86.equals(tags.get(i+1).getName())) {
                            Field86 field86 = new Field86(tags.get(i+1).getValue());
                            reportEntry.setAddtlNtryInf(field86.getValue().replace("\r\n", ""));
                        }
                        bankToCustomerStatement.addReportEntry(reportEntry);
                    }
                }
            }
        }catch (Exception e) {
            throw new SwiftException("ERROR", e.getMessage());
        }
    }
}
