package com.brilliance.swift.mt2SwiftDto.pacs009001;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2SwiftDto.AbstractMt2SwiftDtoCreator;
import com.brilliance.swift.mt2SwiftDto.Mt2SwiftDtoContextIdentifier;
import com.brilliance.swift.mt2SwiftDto.Mt2SwiftDtoParseFields;
import com.brilliance.swift.mt2SwiftDto.pacs009001.impl.*;
import com.brilliance.swift.mt2SwiftDto.pacs009001.impl.cov.*;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.SwiftHeader;
import com.brilliance.swift.vo.VoFinancialInstitutionCreditTransfer;
import com.brilliance.swift.vo.common.TransactionReference;
import com.prowidesoftware.swift.model.mt.AbstractMT;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

public class Mt2SwiftDtoPacs009001Creator extends AbstractMt2SwiftDtoCreator {

    @Override
    public void preProcess() throws SwiftException {
        SwiftHeader swiftHeader = buildSwiftHeader();
        swiftHeader.setMessageDefId("pacs.009.001.09");
        AbstractMT abstractMT = context.get(AbstractMT.class);
        if (abstractMT.getSwiftMessage().isCOV()) {
            swiftHeader.setBusinessService("swift.cbprplus.cov.02");
        } else {
            swiftHeader.setBusinessService("swift.cbprplus.02");
        }
        swiftHeader.setMessageType("pacs.009.001");
        swiftHeader.setVersion("09");
        VoFinancialInstitutionCreditTransfer financialInstitutionCreditTransfer = new VoFinancialInstitutionCreditTransfer();
        financialInstitutionCreditTransfer.setSwiftHeader(swiftHeader);
        TransactionReference txnRef = buildTxnRef();
        financialInstitutionCreditTransfer.setTxnRef(txnRef);
        context.set(financialInstitutionCreditTransfer);
    }

    @Override
    public List<Mt2SwiftDtoParseFields> getParseFieldsList() throws SwiftException {
        List<Mt2SwiftDtoParseFields> list = new ArrayList<>();
        list.add(new Pacs009001Parse20Field());
        list.add(new Pacs009001Parse21Field());
        list.add(new Pacs009001Parse13CField());
        list.add(new Pacs009001Parse32AField());
        list.add(new Pacs009001Parse52Field());
        list.add(new Pacs009001Parse53Field());
        list.add(new Pacs009001Parse54Field());
        list.add(new Pacs009001Parse56Field());
        list.add(new Pacs009001Parse57Field());
        list.add(new Pacs009001Parse58Field());
        list.add(new Pacs009001Parse72Field());

        //cov
        list.add(new Pacs009001Parse33BField());
        list.add(new Pacs009001Parse50Field());
        list.add(new Pacs009001Parse52BField());
        list.add(new Pacs009001Parse56BField());
        list.add(new Pacs009001Parse57BField());
        list.add(new Pacs009001Parse59Field());
        list.add(new Pacs009001Parse70Field());
        list.add(new Pacs009001Parse72BField());
        return list;
    }

    @Override
    public void postProcess() throws SwiftException {
        try {
            String outputFilePath = (String)context.get(Mt2SwiftDtoContextIdentifier.MT_TO_SWIFTDTO_OUTPUT_FILE_PATH, true);
            VoFinancialInstitutionCreditTransfer financialInstitutionCreditTransfer = context.get(VoFinancialInstitutionCreditTransfer.class);
            context.set(Mt2SwiftDtoContextIdentifier.MT_TO_SWIFTDTO_OBJ, financialInstitutionCreditTransfer);
            if (StringUtil.isNotEmpty(outputFilePath)) {
                financialInstitutionCreditTransfer.write(new File(outputFilePath));
            }
        } catch (Exception e) {
            throw new SwiftException("ERROR", e.getMessage());
        }
    }
}
