package com.brilliance.swift.mt2SwiftDto.pacs009001.impl;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2SwiftDto.AbstractMt2SwiftDtoParseFields;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.VoFinancialInstitutionCreditTransfer;
import com.brilliance.swift.vo.common.PartyDto;
import com.prowidesoftware.swift.model.field.*;
import com.prowidesoftware.swift.model.mt.AbstractMT;
import com.prowidesoftware.swift.model.mt2xx.MT202;
import com.prowidesoftware.swift.model.mt2xx.MT202COV;

public class Pacs009001Parse54Field extends AbstractMt2SwiftDtoParseFields {
    @Override
    public void parseFields() throws SwiftException {
        try {
            VoFinancialInstitutionCreditTransfer financialInstitutionCreditTransfer = context.get(VoFinancialInstitutionCreditTransfer.class);
            PartyDto partyDto = null;
            if (getField54A() != null) {
                Field54A field54A = getField54A();
                partyDto = new PartyDto();
                if (StringUtil.isNotEmpty(field54A.getAccount())) {
                    partyDto = buildPartyAccount(partyDto, field54A.getLine(1));
                }
                partyDto.setPartyBic(field54A.getBIC());
            } else if (getField54B() != null) {
                Field54B field54B = getField54B();
                //TODO
            } else if (getField54D() != null) {
                Field54D field54D = getField54D();
                partyDto = new PartyDto();
                if (StringUtil.isNotEmpty(field54D.getAccount())) {
                    partyDto = buildPartyAccount(partyDto, field54D.getLine(1));
                }
                partyDto.setPartyName(field54D.getNameAndAddressLine1());
                if (StringUtil.isNotEmpty(field54D.getNameAndAddressLine2())) {
                    partyDto.addAddress(field54D.getNameAndAddressLine2());
                }
                if (StringUtil.isNotEmpty(field54D.getNameAndAddressLine3())) {
                    partyDto.addAddress(field54D.getNameAndAddressLine3());
                }
                if (StringUtil.isNotEmpty(field54D.getNameAndAddressLine4())) {
                    partyDto.addAddress(field54D.getNameAndAddressLine4());
                }
            }
            if (partyDto != null) {
                financialInstitutionCreditTransfer.setInstdAgtParty(partyDto);
            }
        } catch (Exception e) {
            throw new SwiftException("ERROR", e.getMessage());
        }
    }

    private Field54A getField54A() {
        if (isCov()) {
            MT202COV mt202Cov = (MT202COV)context.get(AbstractMT.class);
            return mt202Cov.getField54A();
        } else {
            MT202 mt202 = (MT202)context.get(AbstractMT.class);
            return mt202.getField54A();
        }
    }

    private Field54B getField54B() {
        if (isCov()) {
            MT202COV mt202Cov = (MT202COV)context.get(AbstractMT.class);
            return mt202Cov.getField54B();
        } else {
            MT202 mt202 = (MT202)context.get(AbstractMT.class);
            return mt202.getField54B();
        }
    }

    private Field54D getField54D() {
        if (isCov()) {
            MT202COV mt202Cov = (MT202COV)context.get(AbstractMT.class);
            return mt202Cov.getField54D();
        } else {
            MT202 mt202 = (MT202)context.get(AbstractMT.class);
            return mt202.getField54D();
        }
    }
}
