package com.brilliance.swift.mt2SwiftDto.pacs009001.impl;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2SwiftDto.AbstractMt2SwiftDtoParseFields;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.VoFinancialInstitutionCreditTransfer;
import com.brilliance.swift.vo.common.PartyDto;
import com.prowidesoftware.swift.model.field.Field56A;
import com.prowidesoftware.swift.model.field.Field56D;
import com.prowidesoftware.swift.model.mt.AbstractMT;
import com.prowidesoftware.swift.model.mt2xx.MT202;
import com.prowidesoftware.swift.model.mt2xx.MT202COV;

public class Pacs009001Parse56Field extends AbstractMt2SwiftDtoParseFields {
    @Override
    public void parseFields() throws SwiftException {
        try {
            VoFinancialInstitutionCreditTransfer financialInstitutionCreditTransfer = context.get(VoFinancialInstitutionCreditTransfer.class);
            PartyDto partyDto = null;
            if (getField56A() != null) {
                Field56A field56A = getField56A();
                partyDto = new PartyDto();
                if (StringUtil.isNotEmpty(field56A.getAccount())) {
                    partyDto = buildPartyAccount(partyDto, field56A.getLine(1));
                }
                partyDto.setPartyBic(field56A.getBIC());
            } else if (getField56D() != null) {
                Field56D field56D = getField56D();
                partyDto = new PartyDto();
                if (StringUtil.isNotEmpty(field56D.getAccount())) {
                    partyDto = buildPartyAccount(partyDto, field56D.getLine(1));
                }
                partyDto.setPartyName(field56D.getNameAndAddressLine1());
                if (StringUtil.isNotEmpty(field56D.getNameAndAddressLine2())) {
                    partyDto.addAddress(field56D.getNameAndAddressLine2());
                }
                if (StringUtil.isNotEmpty(field56D.getNameAndAddressLine3())) {
                    partyDto.addAddress(field56D.getNameAndAddressLine3());
                }
                if (StringUtil.isNotEmpty(field56D.getNameAndAddressLine4())) {
                    partyDto.addAddress(field56D.getNameAndAddressLine4());
                }
            }
            if (partyDto != null) {
                financialInstitutionCreditTransfer.setIntrmyAgtParty(partyDto);
            }
        } catch (Exception e) {
            throw new SwiftException("ERROR", e.getMessage());
        }
    }

    private Field56A getField56A() {
        if (isCov()) {
            MT202COV mt202Cov = (MT202COV)context.get(AbstractMT.class);
            Field56A field56A = null;
            if (mt202Cov.getSequenceA() != null) {
                field56A = (Field56A)mt202Cov.getSequenceA().getFieldByName("56A");
            }
            return field56A;
        } else {
            MT202 mt202 = (MT202)context.get(AbstractMT.class);
            return mt202.getField56A();
        }
    }

    private Field56D getField56D() {
        if (isCov()) {
            MT202COV mt202Cov = (MT202COV)context.get(AbstractMT.class);
            Field56D field56D = null;
            if (mt202Cov.getSequenceA() != null) {
                field56D = (Field56D)mt202Cov.getSequenceA().getFieldByName("56D");
            }
            return field56D;
        } else {
            MT202 mt202 = (MT202)context.get(AbstractMT.class);
            return mt202.getField56D();
        }
    }
}
