package com.brilliance.swift.mt2SwiftDto.pacs009001.impl;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2SwiftDto.AbstractMt2SwiftDtoParseFields;
import com.brilliance.swift.util.SwiftTransferUtil;
import com.brilliance.swift.vo.VoFinancialInstitutionCreditTransfer;
import com.brilliance.swift.vo.common.*;
import com.prowidesoftware.swift.model.field.Field72;
import com.prowidesoftware.swift.model.mt.AbstractMT;
import com.prowidesoftware.swift.model.mt2xx.MT202;
import com.prowidesoftware.swift.model.mt2xx.MT202COV;
import com.prowidesoftware.swift.model.mx.dic.Instruction4Code;

public class Pacs009001Parse72Field extends AbstractMt2SwiftDtoParseFields {
    @Override
    public void parseFields() throws SwiftException {
        try {
            VoFinancialInstitutionCreditTransfer financialInstitutionCreditTransfer = context.get(VoFinancialInstitutionCreditTransfer.class);
            Field72 field72 = getField72();
            if (field72 != null) {
                String field72Value = field72.getValue().replace("\r\n//", "");
                String[] lines = field72Value.split("\r\n");
                for (int i=0; i<lines.length; i++) {
                    String line = lines[i];
                    if (line.startsWith("/INS/")) {
                        PartyDto party = new PartyDto();
                        String lineStr = line.substring(5);
                        if (SwiftTransferUtil.isBIC(lineStr)) {
                            party.setPartyBic(lineStr);
                        } else {
                            party.setPartyName(lineStr);
                        }
                        financialInstitutionCreditTransfer.setPreInstgAgtParty(party);
                    }
                    if (line.startsWith("/ACC/")) {
                        InstructionForCreditAgent instForCrdAgent = new InstructionForCreditAgent();
                        instForCrdAgent.setInstrInf(line.substring(5));
                        financialInstitutionCreditTransfer.setInstForCrdAgt(instForCrdAgent);
                    }
                    if (line.startsWith("/PHONBEN/")) {
                        InstructionForCreditAgent instForCrdAgent = new InstructionForCreditAgent();
                        instForCrdAgent.setCode(ExternalCreditorAgentInstructionCode.TELB);
                        instForCrdAgent.setInstrInf(line.substring(9));
                        financialInstitutionCreditTransfer.setInstForCrdAgt(instForCrdAgent);
                    }
                    if (line.startsWith("/REC/")) {
                        InstructionForNextAgent instForNxtAgent = new InstructionForNextAgent();
                        instForNxtAgent.setInstrInf(line.substring(5));
                        financialInstitutionCreditTransfer.setInstForNxtAgt(instForNxtAgent);
                    }
                    if (line.startsWith("/PHON/")) {
                        InstructionForNextAgent instForNxtAgent = new InstructionForNextAgent();
                        instForNxtAgent.setCode(Instruction4Code.PHOA);
                        instForNxtAgent.setInstrInf(line.substring(6));
                        financialInstitutionCreditTransfer.setInstForNxtAgt(instForNxtAgent);
                    }
                    if (line.startsWith("/TELE/")) {
                        InstructionForNextAgent instForNxtAgent = new InstructionForNextAgent();
                        instForNxtAgent.setCode(Instruction4Code.TELA);
                        instForNxtAgent.setInstrInf(line.substring(6));
                        financialInstitutionCreditTransfer.setInstForNxtAgt(instForNxtAgent);
                    }
                    if (line.startsWith("/PHONIBK/")) {
                        InstructionForNextAgent instForNxtAgent = new InstructionForNextAgent();
                        instForNxtAgent.setCode(Instruction4Code.PHOA);
                        instForNxtAgent.setInstrInf(line.substring(8));
                        financialInstitutionCreditTransfer.setInstForNxtAgt(instForNxtAgent);
                    }
                }
            }
        } catch (Exception e) {
            throw new SwiftException("ERROR", e.getMessage());
        }
    }

    private Field72 getField72() {
        if (isCov()) {
            MT202COV mt202Cov = (MT202COV)context.get(AbstractMT.class);
            Field72 field72 = null;
            if (mt202Cov.getSequenceA() != null) {
                field72 = (Field72)mt202Cov.getSequenceA().getFieldByName("72");
            }
            return field72;
        } else {
            MT202 mt202 = (MT202)context.get(AbstractMT.class);
            return mt202.getField72();
        }
    }
}
