package com.brilliance.swift.mt2SwiftDto.pacs009001.impl.cov;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2SwiftDto.AbstractMt2SwiftDtoParseFields;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.VoCustomerCreditTransfer;
import com.brilliance.swift.vo.VoFinancialInstitutionCreditTransfer;
import com.brilliance.swift.vo.common.PartyDto;
import com.prowidesoftware.swift.model.field.Field50A;
import com.prowidesoftware.swift.model.field.Field50K;
import com.prowidesoftware.swift.model.mt.AbstractMT;
import com.prowidesoftware.swift.model.mt2xx.MT202COV;

public class Pacs009001Parse50Field extends AbstractMt2SwiftDtoParseFields {
    @Override
    public void parseFields() throws SwiftException {
        try {
            if (!isCov()) return;
            VoFinancialInstitutionCreditTransfer financialInstitutionCreditTransfer = context.get(VoFinancialInstitutionCreditTransfer.class);
            MT202COV mt202Cov = (MT202COV)context.get(AbstractMT.class);
            PartyDto partyDto = null;
            if (mt202Cov.getField50A() != null) {
                Field50A field50A = mt202Cov.getField50A();
                partyDto = new PartyDto();
                if (StringUtil.isNotEmpty(field50A.getAccount())) {
                    partyDto = buildPartyAccount(partyDto, field50A.getLine(1));
                }
                partyDto.setPartyBic(field50A.getBIC());
            } else if (mt202Cov.getField50F() != null) {
                //TODO
            } else if (mt202Cov.getField50K() != null) {
                Field50K field50K = mt202Cov.getField50K();
                partyDto = new PartyDto();
                if (StringUtil.isNotEmpty(field50K.getAccount())) {
                    partyDto = buildPartyAccount(partyDto, field50K.getLine(1));
                }
                partyDto.setPartyName(field50K.getNameAndAddressLine1());
                if (StringUtil.isNotEmpty(field50K.getNameAndAddressLine2())) {
                    partyDto.addAddress(field50K.getNameAndAddressLine2());
                }
                if (StringUtil.isNotEmpty(field50K.getNameAndAddressLine3())) {
                    partyDto.addAddress(field50K.getNameAndAddressLine3());
                }
                if (StringUtil.isNotEmpty(field50K.getNameAndAddressLine4())) {
                    partyDto.addAddress(field50K.getNameAndAddressLine4());
                }
            }
            if (partyDto != null) {
                VoCustomerCreditTransfer customerCreditTransfer = financialInstitutionCreditTransfer.getUnderCustomerCreditTransfer();
                if (customerCreditTransfer == null) {
                    customerCreditTransfer = new VoCustomerCreditTransfer();
                }
                customerCreditTransfer.setDebitParty(partyDto);
                financialInstitutionCreditTransfer.setUnderCustomerCreditTransfer(customerCreditTransfer);
            }
        } catch (Exception e) {
            throw new SwiftException("ERROR", e.getMessage());
        }
    }
}
