package com.brilliance.swift.mt2mx;

import com.alibaba.fastjson.JSONObject;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.common.MessagePriority;
import com.prowidesoftware.swift.model.SwiftBlock5;
import com.prowidesoftware.swift.model.SwiftBlock5Field;
import com.prowidesoftware.swift.model.mt.AbstractMT;
import com.prowidesoftware.swift.model.mx.AbstractMX;

import java.util.HashMap;
import java.util.Map;

public abstract class AbstractMt2MxCreator implements Mt2MxCreator{

    protected Mt2MxContext context;

    public Mt2MxContext getContext() {
        return context;
    }

    public void setContext(Mt2MxContext context) {
        this.context = context;
    }

    protected Map<String, Object> jsonMaps = new HashMap<>();

    @Override
    public void preProcess() {
        context.set(Mt2MxContextIdentifier.MT_TO_MX_JSON_MAP, jsonMaps);
        Map<String, Object> appHdrMaps = new HashMap<>();
        jsonMaps.put("appHdr", appHdrMaps);
        AbstractMT abstractMT = context.get(AbstractMT.class);
        String senderBic = abstractMT.getSender();
        senderBic = senderBic.substring(0, 8) + senderBic.substring(9, 12);
        context.set(Mt2MxContextIdentifier.MT_SEND_BIC, senderBic);
        Map<String, Object> frMaps = new HashMap<>();
        appHdrMaps.put("fr", frMaps);
        Map<String, Object> frFiIdMaps = new HashMap<>();
        frMaps.put("fiId", frFiIdMaps);
        Map<String, Object> frFiIdFinInstnIdMaps = new HashMap<>();
        frFiIdMaps.put("finInstnId", frFiIdFinInstnIdMaps);
        frFiIdFinInstnIdMaps.put("bicfi", senderBic);
        String receiverBic = abstractMT.getReceiver();
        receiverBic = receiverBic.substring(0, 8) + receiverBic.substring(9, 12);
        context.set(Mt2MxContextIdentifier.MT_RECEIVE_BIC, receiverBic);
        Map<String, Object> toMaps = new HashMap<>();
        appHdrMaps.put("to", toMaps);
        Map<String, Object> toFiIdMaps = new HashMap<>();
        toMaps.put("fiId", toFiIdMaps);
        Map<String, Object> toFiIdFinInstnIdMaps = new HashMap<>();
        toFiIdMaps.put("finInstnId", toFiIdFinInstnIdMaps);
        toFiIdFinInstnIdMaps.put("bicfi", receiverBic);
        String createDateStr = (String) context.get(Mt2MxContextIdentifier.EXTERNAL_PARAMETERS_CREATION_DATE, true);
        if (StringUtil.isEmpty(createDateStr)) {
            createDateStr = "9999-12-31T00:00:00+00:00";
        }
        appHdrMaps.put("creDt", createDateStr);
        boolean covFlag = abstractMT.getSwiftMessage().isCOV();
        if (covFlag) {
            appHdrMaps.put("bizSvc", "swift.cbprplus.cov.02");
        } else {
            appHdrMaps.put("bizSvc", "swift.cbprplus.02");
        }
        String priority = abstractMT.getMessagePriority();
        if  ("U".equals(priority)) {
            appHdrMaps.put("prty", MessagePriority.HIGH.value());
        } else { // "N".equals(priority)
            appHdrMaps.put("prty", MessagePriority.NORM.value());
        }
        SwiftBlock5 block5 = abstractMT.getSwiftMessage().getBlock5();
        if (block5 != null && block5.containsTag(SwiftBlock5Field.PDE.name())) {
            appHdrMaps.put("pssblDplct", Boolean.TRUE);
        } else {
            appHdrMaps.put("pssblDplct", Boolean.FALSE);
        }
    }

    @Override
    public void postProcess() {
        String swiftGsonStr = new JSONObject(jsonMaps).toJSONString();
        AbstractMX abstractMX = AbstractMX.fromJson(swiftGsonStr);
        String xml = abstractMX.message();
        context.set(Mt2MxContextIdentifier.MT_TO_MX_XML, xml);
    }

    /**
     * 公共方法
     */
    /**
     * FinInstnId.BICFI = mtBicCode
     * @param mtBicCode
     * @param maps
     */
    protected void mt_to_mxBICFI(String mtBicCode, Map<String, Object> maps) {
        if (StringUtil.isEmpty(mtBicCode)) {
            return;
        }
        Map<String, Object> finInstnIdMaps = null;
        if (maps.containsKey("finInstnId")) {
            finInstnIdMaps = (Map<String, Object>)maps.get("finInstnId");
        } else {
            finInstnIdMaps = new HashMap<>();
            maps.put("finInstnId", finInstnIdMaps);
        }
        finInstnIdMaps.put("bicfi", mtBicCode);
    }
}
