package com.brilliance.swift.mt2mx;

import com.alibaba.fastjson.JSONArray;
import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.util.SwiftTransferUtil;
import com.brilliance.swift.vo.common.*;
import com.prowidesoftware.swift.model.field.Field23E;

import java.text.ParseException;
import java.util.*;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public abstract class AbstractMt2MxParseField implements Mt2MxParseField {

    protected Mt2MxContext context;

    public Mt2MxContext getContext() {
        return context;
    }

    public AbstractMt2MxParseField setContext(Mt2MxContext context) {
        this.context = context;
        return this;
    }

    protected Map<String, Object> jsonMaps = null;

    public void initJsonMaps() {
        jsonMaps = (Map<String, Object>)context.get(Mt2MxContextIdentifier.MT_TO_MX_JSON_MAP, true);
    }
    /**
     * MT 转 MX 转换函数开始
     */

    /**
     * 1.如果 mtAccount 以//CH开始,Id.Othr.SchmeNm.Cd = CUID,Id.Othr.Id=mtAccount.subString(5)
     * 2.如果 mtAccount 是IBAN账户，Id.IBAN = mtAccount
     * 3.否则 Id.Othr.Id=mtAccount
     * @param mtAccount
     * @param maps(account对应的map对象)
     */
    protected void mt_to_mxPartyAccount(String mtAccount, Map<String, Object> maps) {
        if (StringUtil.isEmpty(mtAccount)) {
            return;
        }
        Map<String, Object> idMaps = null;
        if (maps.containsKey("id")) {
            idMaps = (Map<String, Object>)maps.get("id");
        } else {
            idMaps = new HashMap<>();
            maps.put("id", idMaps);
        }
        if (mtAccount.startsWith("//CH") && mtAccount.length() > 4) {
            Map<String, Object> othrMaps = null;
            if (idMaps.containsKey("othr")) {
                othrMaps = (Map<String, Object>)idMaps.get("othr");
            } else {
                othrMaps = new HashMap<>();
                idMaps.put("othr", othrMaps);
            }
            othrMaps.put("id", mtAccount.substring(4));
            Map<String, Object> schmeNmMaps = null;
            if (othrMaps.containsKey("schmeNm")) {
                schmeNmMaps = (Map<String, Object>)othrMaps.get("schmeNm");
            } else {
                schmeNmMaps = new HashMap<>();
                othrMaps.put("schmeNm", schmeNmMaps);
            }
            schmeNmMaps.put("cd", "CUID");
        } else if (mtAccount.length() > 1) {
            mtAccount = mtAccount.substring(1);
            if (SwiftTransferUtil.checkIbanAccount(mtAccount)){
                idMaps.put("iban", mtAccount);
            } else {
                Map<String, Object> othrMaps = null;
                if (idMaps.containsKey("othr")) {
                    othrMaps = (Map<String, Object>)idMaps.get("othr");
                } else {
                    othrMaps = new HashMap<>();
                    idMaps.put("othr", othrMaps);
                }
                othrMaps.put("id", mtAccount);
            }
        }
    }

    /**
     * 1.如果 mtAccount 以//CH开始,Id.Othr.SchmeNm.Cd = CUID,Id.Othr.Id=mtAccount.subString(5)
     * 2.如果长度大于34，Id.Othr.Id=mtAccount截取33位，最后一位给+
     * 3.如果 mtAccount 是IBAN账户，Id.IBAN = mtAccount
     * 4.否则 Id.Othr.Id=mtAccount
     * @param mtAccount
     * @param maps(account对应的map对象)
     */
    protected void mt_to_mxAccount35(String mtAccount, Map<String, Object> maps) {
        if (StringUtil.isEmpty(mtAccount)) {
            return;
        }
        Map<String, Object> idMaps = null;
        if (maps.containsKey("id")) {
            idMaps = (Map<String, Object>)maps.get("id");
        } else {
            idMaps = new HashMap<>();
            maps.put("id", idMaps);
        }
        if (mtAccount.startsWith("//CH") && mtAccount.length() > 4) {
            Map<String, Object> othrMaps = null;
            if (idMaps.containsKey("othr")) {
                othrMaps = (Map<String, Object>)idMaps.get("othr");
            } else {
                othrMaps = new HashMap<>();
                idMaps.put("othr", othrMaps);
            }
            othrMaps.put("id", mtAccount.substring(4));
            Map<String, Object> schmeNmMaps = null;
            if (othrMaps.containsKey("schmeNm")) {
                schmeNmMaps = (Map<String, Object>)othrMaps.get("schmeNm");
            } else {
                schmeNmMaps = new HashMap<>();
                othrMaps.put("schmeNm", schmeNmMaps);
            }
            schmeNmMaps.put("cd", "CUID");
        } else if (mtAccount.length() > 34) {
            mtAccount = mtAccount.substring(1);
            Map<String, Object> othrMaps = null;
            if (idMaps.containsKey("othr")) {
                othrMaps = (Map<String, Object>)idMaps.get("othr");
            } else {
                othrMaps = new HashMap<>();
                idMaps.put("othr", othrMaps);
            }
            othrMaps.put("id", mtAccount.substring(0, 33) + "+");
        } else if (mtAccount.length() > 1) {
            mtAccount = mtAccount.substring(1);
            if (SwiftTransferUtil.checkIbanAccount(mtAccount)){
                idMaps.put("iban", mtAccount);
            } else {
                Map<String, Object> othrMaps = null;
                if (idMaps.containsKey("othr")) {
                    othrMaps = (Map<String, Object>)idMaps.get("othr");
                } else {
                    othrMaps = new HashMap<>();
                    idMaps.put("othr", othrMaps);
                }
                othrMaps.put("id", mtAccount);
            }
        }
    }
    /**
     * Id.OrgId.AnyBIC = mtBicCode
     * @param mtBicCode
     * @param maps
     */
    protected void mt_to_mxAnyBIC(String mtBicCode, Map<String, Object> maps) {
        if (StringUtil.isEmpty(mtBicCode)) {
            return;
        }
        Map<String, Object> idMaps = null;
        if (maps.containsKey("id")) {
            idMaps = (Map<String, Object>)maps.get("id");
        } else {
            idMaps = new HashMap<>();
            maps.put("id", idMaps);
        }
        Map<String, Object> idOrgMaps = null;
        if (idMaps.containsKey("orgId")) {
            idOrgMaps = (Map<String, Object>)idMaps.get("orgId");
        } else {
            idOrgMaps = new HashMap<>();
            idMaps.put("orgId", idOrgMaps);
        }
        idOrgMaps.put("anyBIC", mtBicCode);
    }

    /**
     * FinInstnId.BICFI = mtBicCode
     * @param mtBicCode
     * @param maps
     */
    protected void mt_to_mxBICFI(String mtBicCode, Map<String, Object> maps) {
        if (StringUtil.isEmpty(mtBicCode)) {
            return;
        }
        Map<String, Object> finInstnIdMaps = null;
        if (maps.containsKey("finInstnId")) {
            finInstnIdMaps = (Map<String, Object>)maps.get("finInstnId");
        } else {
            finInstnIdMaps = new HashMap<>();
            maps.put("finInstnId", finInstnIdMaps);
        }
        finInstnIdMaps.put("bicfi", mtBicCode);
    }

    /**
     * nameAndAddress 通过回车换行切割成数组 nameAndAddress[]
     * Nm = nameAndAddress[0]
     * PstlAdr.AdrLine = 剩余的 nameAndAddress[]
     * @param nameAndAddress
     * @param maps
     */
    protected void mt_to_mxPartyNameAndAddress(String nameAndAddress, Map<String, Object> maps) {
        if (StringUtil.isEmpty(nameAndAddress)) {
            return;
        }
        String[] nameAndAddresses = nameAndAddress.split(Mx2MtConstants.NEW_LINE);
        String name = "";
        List<String> addressList = new ArrayList<>();
        for (int i=0; i<nameAndAddresses.length; i++) {
            if (i == 0) {
                name = nameAndAddresses[i];
            } else {
                addressList.add(nameAndAddresses[i]);
            }
        }
        maps.put("nm", name);
        if (addressList.size() > 0) {
            Map<String, Object> pstlAdrMaps = null;
            if (maps.containsKey("pstlAdr")) {
                pstlAdrMaps = (Map<String, Object>)maps.get("pstlAdr");
            } else {
                pstlAdrMaps = new HashMap<>();
                maps.put("pstlAdr", pstlAdrMaps);
            }
            pstlAdrMaps.put("adrLine", addressList);
        }
    }

    /**
     * 1/ 开头的给name
     * 2/ 开头的给adrLine
     * 3/[A-Z]{2}/LEIC/([A-Z0-9]{18,18}[0-9]{2,2}) 括号里面的内容给LEI
     * 否则 给 adrLine
     * @param nameAndAddress
     * @param maps
     */
    protected void mt_to_mxPartyNameAndStructuredAddress(String nameAndAddress, Map<String, Object> maps) {
        if (StringUtil.isEmpty(nameAndAddress)) {
            return;
        }
        String[] nameAndAddresses = nameAndAddress.split(Mx2MtConstants.NEW_LINE);
        String name = "";
        String lei = "";
        List<String> addressList = new ArrayList<>();
        for (int i=0; i<nameAndAddresses.length; i++) {
            String tmpNameAndAddress = nameAndAddresses[i];
            if (tmpNameAndAddress.startsWith("1/")) {
                name += tmpNameAndAddress.substring(2);
            }
            if (tmpNameAndAddress.startsWith("2/")) {
                addressList.add(tmpNameAndAddress);
            }
            if (tmpNameAndAddress.startsWith("3/")) {
                String regex = "3/[A-Z]{2}/LEIC/([A-Z0-9]{18,18}[0-9]{2,2})";
                Pattern p = Pattern.compile(regex);
                Matcher m = p.matcher(tmpNameAndAddress);
                if (m.find()) {
                    /**
                     * group(0)就是指的整个串，group(1)指的是第一个括号里的东西，group(2)指的第二个括号里的东西
                     */
                    lei = m.group(1);
                } else {
                    addressList.add(tmpNameAndAddress);
                }
            }
        }
        if (name.length() > 0) {
            maps.put("nm", name);
        }
        if (lei.length() > 0) {
            Map<String, Object> idMaps = null;
            if (maps.containsKey("id")) {
                idMaps = (Map<String, Object>)maps.get("id");
            } else {
                idMaps = new HashMap<>();
                maps.put("id", idMaps);
            }
            Map<String, Object> orgIdMaps = null;
            if (idMaps.containsKey("orgId")) {
                orgIdMaps = (Map<String, Object>) idMaps.get("orgId");
            } else {
                orgIdMaps = new HashMap<>();
                idMaps.put("orgId", orgIdMaps);
            }
            orgIdMaps.put("lei", lei);
        }
        if (addressList.size() > 0) {
            Map<String, Object> pstlAdrMaps = null;
            if (maps.containsKey("pstlAdr")) {
                pstlAdrMaps = (Map<String, Object>)maps.get("pstlAdr");
            } else {
                pstlAdrMaps = new HashMap<>();
                maps.put("pstlAdr", pstlAdrMaps);
            }
            pstlAdrMaps.put("adrLine", addressList);
        }
    }

    /**
     * ① //RT//([A-Z]{5})(.*)
     * ② //([A-Z]{5})(.*)
     * ③ //RT//([A-Z]{2})(.*)
     * ④ //([A-Z]{2})(.*)
     * 第一个括号内容给mxSystemCode
     * 第二个括号内容给mxMemberId
     * @param mtPartyIdentifier
     * @param maps
     */
    protected void mt_to_mxClearingIdentifier(String mtPartyIdentifier, Map<String, Object> maps) {
        if (StringUtil.isEmpty(mtPartyIdentifier)) {
            return;
        }
        String mxClearingSystem = "";
        String mxClearingCode = "";
        String regex1 = "//RT//([A-Z]{5})(.*)";
        Pattern p1 = Pattern.compile(regex1);
        Matcher m1 = p1.matcher(mtPartyIdentifier);
        if (m1.find()) {
            mxClearingSystem = m1.group(1);
            mxClearingCode = m1.group(2);
        }
        String regex2 = "//([A-Z]{5})(.*)";
        Pattern p2 = Pattern.compile(regex2);
        Matcher m2 = p2.matcher(mtPartyIdentifier);
        if (m2.find()) {
            mxClearingSystem = m2.group(1);
            mxClearingCode = m2.group(2);
        }
        ClearingSystemMemberCode code = SwiftTransferUtil.getClsSysMemberByValue(mxClearingSystem);
        if (mxClearingCode.length() > 0 && code != null) {
            Map<String, Object> clrSysIdMaps = null;
            if (maps.containsKey("clrSysId")) {
                clrSysIdMaps = (Map<String, Object>) maps.get("clrSysId");
            } else {
                clrSysIdMaps = new HashMap<>();
                maps.put("clrSysId", clrSysIdMaps);
            }
            clrSysIdMaps.put("cd", mxClearingSystem);
            maps.put("mmbId", mxClearingCode);
            return;
        }
        /**
         * 第2种情况
         */
        String mtClearingSystem = "";
        String mtClearingCode = "";
        String regex3 = "//RT//([A-Z]{2})(.*)";
        Pattern p3 = Pattern.compile(regex3);
        Matcher m3 = p3.matcher(mtPartyIdentifier);
        if (m3.find()) {
            mtClearingSystem = m3.group(1);
            mtClearingCode = m3.group(2);
        }
        String regex4 = "//([A-Z]{2})(.*)";
        Pattern p4 = Pattern.compile(regex4);
        Matcher m4 = p4.matcher(mtPartyIdentifier);
        if (m4.find()) {
            mtClearingSystem = m4.group(1);
            mtClearingCode = m4.group(2);
        }
        code = SwiftTransferUtil.getClsSysMemberByDesc(mtClearingSystem);
        if (mtClearingCode.length() > 0 && code != null) {
            if ("SW".equals(mtClearingSystem)){
                if (mtClearingCode.length() > 5) {
                    mxClearingSystem = ClearingSystemMemberCode.CHSIC.value();
                } else {
                    mxClearingSystem = ClearingSystemMemberCode.CHBCC.value();
                }
            } else {
                mxClearingSystem = code.value();
            }
            mxClearingCode = mtClearingCode;
            Map<String, Object> clrSysIdMaps = null;
            if (maps.containsKey("clrSysId")) {
                clrSysIdMaps = (Map<String, Object>) maps.get("clrSysId");
            } else {
                clrSysIdMaps = new HashMap<>();
                maps.put("clrSysId", clrSysIdMaps);
            }
            clrSysIdMaps.put("cd", mxClearingSystem);
            maps.put("mmbId", mxClearingCode);
        }
    }

    /**
     * 判断 mt systemcode 在不在 MTClearingSystemCodeList 里面
     * 存在返回true
     * 不在返回false
     * @param mtPartyIdentifier
     */
    protected boolean isMTClearingSystemCodeInList(String mtPartyIdentifier) {
        if (StringUtil.isEmpty(mtPartyIdentifier)) {
            return false;
        }
        boolean flag = false;
        String mxClearingSystem = "";
        String regex1 = "//RT//([A-Z]{5})(.*)";
        Pattern p1 = Pattern.compile(regex1);
        Matcher m1 = p1.matcher(mtPartyIdentifier);
        if (m1.find()) {
            mxClearingSystem = m1.group(1);
        }
        String regex2 = "//([A-Z]{5})(.*)";
        Pattern p2 = Pattern.compile(regex2);
        Matcher m2 = p2.matcher(mtPartyIdentifier);
        if (m2.find()) {
            mxClearingSystem = m2.group(1);
        }
        ClearingSystemMemberCode code = SwiftTransferUtil.getClsSysMemberByValue(mxClearingSystem);
        if (code != null) {
            flag = true;
        } else {
            /**
             * 第2种情况
             */
            String mtClearingSystem = "";
            String regex3 = "//RT//([A-Z]{2})(.*)";
            Pattern p3 = Pattern.compile(regex3);
            Matcher m3 = p3.matcher(mtPartyIdentifier);
            if (m3.find()) {
                mtClearingSystem = m3.group(1);
            }
            String regex4 = "//([A-Z]{2})(.*)";
            Pattern p4 = Pattern.compile(regex4);
            Matcher m4 = p4.matcher(mtPartyIdentifier);
            if (m4.find()) {
                mtClearingSystem = m4.group(1);
            }
            code = SwiftTransferUtil.getClsSysMemberByDesc(mtClearingSystem);
            if (code != null) {
                flag = true;
            }
        }
        return flag;
    }

    protected void mt_to_mxClearingSystemToNameAndAddressLine(String mtPartyIdentifier, String location, Map<String, Object> maps) {
        if (StringUtil.isEmpty(mtPartyIdentifier)) {
            return;
        }
        String nameAddress = "";
        String regex1 = "//RT//(.*)";
        Pattern p1 = Pattern.compile(regex1);
        Matcher m1 = p1.matcher(mtPartyIdentifier);
        if (m1.find()) {
            nameAddress = m1.group(1);
        }
        String regex2 = "//(.*)";
        Pattern p2 = Pattern.compile(regex2);
        Matcher m2 = p2.matcher(mtPartyIdentifier);
        if (m2.find()) {
            nameAddress = m2.group(1);
        }
        if (StringUtil.isNotEmpty(nameAddress) && !"RT".equals(nameAddress)) {
            nameAddress = "//" + nameAddress;
        } else {
            nameAddress = Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
        }
        maps.put("nm", nameAddress);
        List<String> addressList = new ArrayList<>();
        addressList.add(nameAddress);
        if (StringUtil.isNotEmpty(location)) {
            addressList.add(location);
        }
        Map<String, Object> pstlAdrMaps = null;
        if (maps.containsKey("pstlAdr")) {
            pstlAdrMaps = (Map<String, Object>)maps.get("pstlAdr");
        } else {
            pstlAdrMaps = new HashMap<>();
            maps.put("pstlAdr", pstlAdrMaps);
        }
        pstlAdrMaps.put("adrLine", addressList);
    }

    protected void mt_to_mxFinancialInstitutionNameAndUnstructuredAddress(String nameAddress, Map<String, Object> maps) {
        if (StringUtil.isEmpty(nameAddress)) {
            return;
        }
        Map<String, Object> finInstnIdMaps = null;
        if (maps.containsKey("finInstnId")) {
            finInstnIdMaps = (Map<String, Object>)maps.get("finInstnId");
        } else {
            finInstnIdMaps = new HashMap<>();
            maps.put("finInstnId", finInstnIdMaps);
        }
        String[] nameAddresses = nameAddress.split(Mx2MtConstants.NEW_LINE);
        String name = "";
        List<String> addressList = new ArrayList<>();
        for (int i=0; i<nameAddresses.length; i++) {
            if (i == 0) {
                name = nameAddresses[i];
            } else {
                addressList.add(nameAddresses[i]);
            }
        }
        finInstnIdMaps.put("nm", name);
        if (addressList.size() == 0) {
            addressList.add(Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE);
        }
        Map<String, Object> pstlAdrMaps = null;
        if (finInstnIdMaps.containsKey("pstlAdr")) {
            pstlAdrMaps = (Map<String, Object>)finInstnIdMaps.get("pstlAdr");
        } else {
            pstlAdrMaps = new HashMap<>();
            finInstnIdMaps.put("pstlAdr", pstlAdrMaps);
        }
        pstlAdrMaps.put("adrLine", addressList);
    }

    /**
     *
     * @param mt72
     * @param maps
     */
    protected void mt72_to_mxNextAgent(String mt72, List<String> excludeCodeList, Map<String, Object> maps) {
        if (StringUtil.isEmpty(mt72)) {
            return;
        }
        String mt72Value = mt72.replace("\r\n//", "");
        String[] lines = mt72Value.split("\r\n");
        String nextAgtInfo = "";
        for (int i=0; i<lines.length; i++) {
            boolean found = false;
            for (String excludeCode : excludeCodeList) {
                if (lines[i].startsWith(excludeCode)) {
                    found = true;
                    break;
                }
            }
            if (!found) {
                nextAgtInfo += lines[i];
            }
        }
        String nextAgeFin53 = (String)context.get(Mt2MxContextIdentifier.MT_TO_MX_INSTRUCTION_FOR_NEXT_AGENT_FIN53, true);
        if (StringUtil.isNotEmpty(nextAgeFin53)) {
            nextAgtInfo = nextAgeFin53 + nextAgtInfo;
        }
        if (StringUtil.isNotEmpty(nextAgtInfo)) {
            if (nextAgtInfo.length() > 210) {
                nextAgtInfo = nextAgtInfo.substring(0, 209) + "+";
            }
            JSONArray instrForNxtAgtJsonArray = null;
            if (maps.containsKey("instrForNxtAgt")) {
                instrForNxtAgtJsonArray = (JSONArray)maps.get("instrForNxtAgt");
            } else {
                instrForNxtAgtJsonArray = new JSONArray();
                maps.put("instrForNxtAgt", instrForNxtAgtJsonArray);
            }
            List<String> nextAgtInfoList = StringUtil.outStringList(nextAgtInfo, 35, "");
            for (int i=0; i<nextAgtInfoList.size(); i++) {
                Map<String, Object> instrForNxtAgtMaps = new HashMap<>();
                instrForNxtAgtMaps.put("instrInf", nextAgtInfoList.get(i));
                instrForNxtAgtJsonArray.add(instrForNxtAgtMaps);
            }
        }
    }
    /**
     *
     * @param mt72
     * @param maps
     */
    protected void mt72ins_to_mxAgent(String mt72, Map<String, Object> maps) {
        if (StringUtil.isEmpty(mt72)) {
            return;
        }
        String mt72Value = mt72.replace("\r\n//", "");
        String[] lines = mt72Value.split("\r\n");
        List<String> insList = new ArrayList<>();
        for (int i=0; i<lines.length; i++) {
            if (lines[i].startsWith("/INS/")) {
                insList.add(lines[i]);
            }
        }
        for (int i=0; i<insList.size(); i++) {
            String insLine = insList.get(i);
            insLine = insLine.substring(5);
            if (i == 3) break;
            String key = "prvsInstgAgt" + (i+1);
            Map<String, Object> prvsInstgAgt1Maps = null;
            if (maps.containsKey(key)) {
                prvsInstgAgt1Maps = (Map<String, Object>)maps.get(key);
            } else {
                prvsInstgAgt1Maps = new HashMap<>();
                maps.put(key, prvsInstgAgt1Maps);
            }
            Map<String, Object> finInstnIdMaps = null;
            if (prvsInstgAgt1Maps.containsKey("finInstnId")) {
                finInstnIdMaps = (Map<String, Object>)maps.get("finInstnId");
            } else {
                finInstnIdMaps = new HashMap<>();
                prvsInstgAgt1Maps.put("finInstnId", finInstnIdMaps);
            }
            if (SwiftTransferUtil.isBIC(insLine)) {
                finInstnIdMaps.put("bicfi", insLine);
            } else {
                if (insLine.length() > 140){
                    insLine = insLine.substring(0, 139) + "+";
                }
                finInstnIdMaps.put("nm", insLine);
                Map<String, Object> pstlAdrMaps = null;
                List<String> addressList = new ArrayList<>();
                addressList.add(Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE);
                if (finInstnIdMaps.containsKey("pstlAdr")) {
                    pstlAdrMaps = (Map<String, Object>)finInstnIdMaps.get("pstlAdr");
                } else {
                    pstlAdrMaps = new HashMap<>();
                    finInstnIdMaps.put("pstlAdr", pstlAdrMaps);
                }
                pstlAdrMaps.put("adrLine", addressList);
            }
        }
    }

    /**
     *
     * @param mtPartyIdentifier
     * @param maps
     */
    protected void mt_to_mxFinancialInstitutionAccount(String mtPartyIdentifier, Map<String, Object> maps) {
        if (StringUtil.isEmpty(mtPartyIdentifier)) {
            return;
        }
        Map<String, Object> idMaps = null;
        if (maps.containsKey("id")) {
            idMaps = (Map<String, Object>)maps.get("id");
        } else {
            idMaps = new HashMap<>();
            maps.put("id", idMaps);
        }
        if (mtPartyIdentifier.startsWith("//CH") && mtPartyIdentifier.length() > 4) {
            Map<String, Object> othrMaps = null;
            if (idMaps.containsKey("othr")) {
                othrMaps = (Map<String, Object>)idMaps.get("othr");
            } else {
                othrMaps = new HashMap<>();
                idMaps.put("othr", othrMaps);
            }
            othrMaps.put("id", mtPartyIdentifier.substring(4));
            Map<String, Object> schmeNmMaps = null;
            if (othrMaps.containsKey("schmeNm")) {
                schmeNmMaps = (Map<String, Object>)othrMaps.get("schmeNm");
            } else {
                schmeNmMaps = new HashMap<>();
                othrMaps.put("schmeNm", schmeNmMaps);
            }
            schmeNmMaps.put("cd", "CUID");
            return;
        } else if ((mtPartyIdentifier.startsWith("/C/") || mtPartyIdentifier.startsWith("/D/")) && mtPartyIdentifier.length() > 3) {
            mtPartyIdentifier = mtPartyIdentifier.substring(3);
        } else if (mtPartyIdentifier.length() > 1) {
            mtPartyIdentifier = mtPartyIdentifier.substring(1);
        }
        if (SwiftTransferUtil.checkIbanAccount(mtPartyIdentifier)){
            idMaps.put("iban", mtPartyIdentifier);
        } else {
            Map<String, Object> othrMaps = null;
            if (idMaps.containsKey("othr")) {
                othrMaps = (Map<String, Object>)idMaps.get("othr");
            } else {
                othrMaps = new HashMap<>();
                idMaps.put("othr", othrMaps);
            }
            othrMaps.put("id", mtPartyIdentifier);
        }
    }

    protected void mt_to_mxRemittanceInformation(String mt70, Map<String, Object> maps) {
        if (StringUtil.isEmpty(mt70)) {
            return;
        }
        String[] mt70Lines = mt70.split(Mx2MtConstants.NEW_LINE);
        String ustrd = "";
        for (int i=0; i<mt70Lines.length; i++) {
            String mt70Line = mt70Lines[i];
            if (mt70Line.length() < 35 && i < (mt70Lines.length-1)) {
                ustrd += mt70Line + " ";
            } else {
                ustrd += mt70Line;
            }
        }
        List<String> ustrdList = new ArrayList<>();
        ustrdList.add(ustrd);
        maps.put("ustrd", ustrdList);
    }

    /**
     * 获取 EndToEndId
     * @param mt70Value
     * @return
     */
    protected String mt70roc_to_mx35Text(String mt70Value) {
        if (StringUtil.isEmpty(mt70Value)) {
            return null;
        }
        String endToEndId = "";
        String tmpMtValue = mt70Value.replace(Mx2MtConstants.NEW_LINE, "");
        String regex = "/ROC/(.*)///";
        Pattern p = Pattern.compile(regex);
        Matcher m = p.matcher(tmpMtValue);
        if (m.find()) {
            endToEndId = m.group(1);
        } else {
            regex = "/ROC/(.*)";
            p = Pattern.compile(regex);
            m = p.matcher(tmpMtValue);
            if (m.find()) {
                endToEndId = m.group(1);
            }
        }
        if (endToEndId.length() > 35) endToEndId = endToEndId.substring(0, 34) + "+";
        return endToEndId;
    }

    /**
     * 提取72域中指定mtcode的值
     * @param mt72
     * @param mtCode
     * @param maxLength
     * @return
     */
    protected String mt72_to_mxText(String mt72, String mtCode, int maxLength) {
        if (StringUtil.isEmpty(mt72)) {
            return "";
        }
        String mxCode = "";
        String mt72Value = mt72.replace("\r\n//", "");
        String[] lines = mt72Value.split("\r\n");
        for (int i=0; i<lines.length; i++) {
            if (lines[i].startsWith(mtCode)) {
                mxCode = lines[i];
            }
        }
        mxCode = mtCode.substring(mtCode.length());
        if (mxCode.length() > maxLength) {
            mxCode = mxCode.substring(0, maxLength-1) + "+";
        }
        return mxCode;
    }

    /**
     * 23E 72 转换成 Instruction For Creditor Agent
     * @param field23EList (HOLD, PHOB, CHQB,TELB)
     * @param mt72
     * @param maps
     */
    protected void mt_to_mxInstructionForCreditorAgent(List<Field23E> field23EList, String mt72, Map<String, Object> maps) {
        if (field23EList.size() == 0 && StringUtil.isEmpty(mt72)) {
            return;
        }
        Map<String, Object> instrForCdtrAgt1 = new HashMap<>();
        Map<String, Object> instrForCdtrAgt2 = new HashMap<>();
        String mxText = mt72_to_mxText(mt72, "/ACC/", 205);
        String configIndicator = "";
        if (mxText.length() > 0 && field23EList.size() > 0) {
            configIndicator = "ACCCode";
        } else if (mxText.length() > 0) {
            configIndicator = "ACCOnly";
        } else if (field23EList.size() > 0) {
            configIndicator = "CodeOnly";
        }
        if ("ACCOnly".equals(configIndicator)) {
            if (mxText.length() > 140) {
                instrForCdtrAgt1.put("instrInf", mxText.substring(0, 140));
                instrForCdtrAgt2.put("instrInf", mxText.substring(140));
            } else {
                instrForCdtrAgt1.put("instrInf", mxText);
            }
        } else if ("ACCCode".equals(configIndicator)) {
            if (mxText.length() > 140) {
                instrForCdtrAgt1.put("instrInf", mxText.substring(0, 139) + "+");
            } else {
                instrForCdtrAgt1.put("instrInf", mxText);
            }
            String instructionCode = "";
            String instructionInfo = "";
            for (int i=0; i<field23EList.size(); i++) {
                Field23E field23E = field23EList.get(i);
                String code = field23E.getCode();
                String info = field23E.getAdditionalInformation();
                if (i == 0) {
                    instructionCode = code;
                    if (StringUtil.isNotEmpty(info)) {
                        instructionInfo += info;
                    }
                } else {
                    instructionInfo += "/" + code + "/";
                    if (StringUtil.isNotEmpty(info)) {
                        instructionInfo += info;
                    }
                }
            }
            instrForCdtrAgt2.put("cd", instructionCode);
            if (StringUtil.isNotEmpty(instructionInfo)) {
                instrForCdtrAgt2.put("instrInf", instructionInfo);
            }
        } else if ("CodeOnly".equals(configIndicator)) {
            String instructionCode = "";
            String instructionInfo = "";
            for (int i=0; i<field23EList.size(); i++) {
                Field23E field23E = field23EList.get(i);
                String code = field23E.getCode();
                String info = field23E.getAdditionalInformation();
                if (i == 0) {
                    instrForCdtrAgt1.put("cd", code);
                    if (StringUtil.isNotEmpty(info)) {
                        instrForCdtrAgt1.put("instrInf", info);
                    }
                } else if (i == 1){
                    instructionCode = code;
                    if (StringUtil.isNotEmpty(info)) {
                        instructionInfo += info;
                    }
                } else {
                    instructionInfo += "/" + code + "/";
                    if (StringUtil.isNotEmpty(info)) {
                        instructionInfo += info;
                    }
                }
            }
            instrForCdtrAgt2.put("cd", instructionCode);
            if (StringUtil.isNotEmpty(instructionInfo)) {
                instrForCdtrAgt2.put("instrInf", instructionInfo);
            }
        }
        JSONArray instrForCdtrAgtJsonArray = null;
        if (maps.containsKey("instrForCdtrAgt")) {
            instrForCdtrAgtJsonArray = (JSONArray)maps.get("instrForCdtrAgt");
        } else {
            instrForCdtrAgtJsonArray = new JSONArray();
            maps.put("instrForCdtrAgt", instrForCdtrAgtJsonArray);
        }
        if (instrForCdtrAgt1.size() > 0) {
            instrForCdtrAgtJsonArray.add(instrForCdtrAgt1);
        }
        if (instrForCdtrAgt2.size() > 0) {
            instrForCdtrAgtJsonArray.add(instrForCdtrAgt2);
        }
    }


    protected void mt_to_mxInstructionForCreditorAgent2(String mt72, Map<String, Object> maps) {
        if (StringUtil.isEmpty(mt72)) {
            return;
        }
        String mxUdlcText = mt72_to_mxText(mt72, "/UDLC/", 204);
        String mxAccText = mt72_to_mxText(mt72, "/ACC/", 205);
        String mxPhobText = mt72_to_mxText(mt72, "/PHONBEN/", 140);
        String mxTelbText = mt72_to_mxText(mt72, "/TELEBEN/", 140);
        Map<String, Object> instrForCdtrAgt1 = new HashMap<>();
        Map<String, Object> instrForCdtrAgt2 = new HashMap<>();
        String configIndicator = "";
        if (StringUtil.isEmpty(mxUdlcText)) {  //不包含UDLC
            if (StringUtil.isEmpty(mxAccText)) { //不包含ACC
                if (StringUtil.isNotEmpty(mxPhobText) || StringUtil.isNotEmpty(mxTelbText)) {
                    configIndicator = "CodeOnly";
                } else {
                    return;
                }
            } else { // 包含ACC
                if (StringUtil.isNotEmpty(mxPhobText) || StringUtil.isNotEmpty(mxTelbText)) {
                    configIndicator = "ACCCode";
                } else {
                    configIndicator = "ACCOnly";
                }
            }
        } else {
            if (StringUtil.isEmpty(mxAccText)) {
                configIndicator = "UDLC";
            } else {
                configIndicator = "UDLCACC";
            }
        }
        if ("ACCOnly".equals(configIndicator)) {
            if (mxAccText.length() > 140) {
                instrForCdtrAgt1.put("instrInf", mxAccText.substring(0, 140));
                instrForCdtrAgt2.put("instrInf", mxAccText.substring(140));
            } else {
                instrForCdtrAgt1.put("instrInf", mxAccText);
            }
        } else if ("ACCCode".equals(configIndicator)) {
            if (mxAccText.length() > 140) {
                instrForCdtrAgt1.put("instrInf", mxAccText.substring(0, 139) + "+");
            } else {
                instrForCdtrAgt1.put("instrInf", mxAccText);
            }
            if (StringUtil.isNotEmpty(mxPhobText)) {
                String instructionInfo = mxPhobText;
                int remainLength = 140 - instructionInfo.length();
                if (StringUtil.isNotEmpty(mxTelbText) && remainLength >= 7) {
                    String tmpInstructionInfo = "/TELB/" + mxTelbText;
                    if (tmpInstructionInfo.length() > remainLength) {
                        tmpInstructionInfo = tmpInstructionInfo.substring(0, remainLength-1) + "+";
                    }
                    instructionInfo += tmpInstructionInfo;
                }
                instrForCdtrAgt2.put("cd", "PHOB");
                instrForCdtrAgt2.put("instrInf", instructionInfo);
            } else { // /PHONBEN/不存在,/TELEBEN/必须存在
                instrForCdtrAgt2.put("cd", "TELB");
                instrForCdtrAgt2.put("instrInf", mxTelbText);
            }
        } else if ("CodeOnly".equals(configIndicator)) {
            if (StringUtil.isNotEmpty(mxPhobText)) {
                instrForCdtrAgt1.put("cd", "PHOB");
                instrForCdtrAgt1.put("instrInf", mxPhobText);
            }
            if (StringUtil.isNotEmpty(mxTelbText)) {
                if (instrForCdtrAgt1.size() == 0) {
                    instrForCdtrAgt1.put("cd", "TELB");
                    instrForCdtrAgt1.put("instrInf", mxTelbText);
                } else {
                    instrForCdtrAgt2.put("cd", "TELB");
                    instrForCdtrAgt2.put("instrInf", mxTelbText);
                }
            }
        } else if ("UDLCACC".equals(configIndicator)) {
            if (mxAccText.length() > 140) {
                instrForCdtrAgt1.put("instrInf", mxAccText.substring(0, 139) + "+");
            } else {
                instrForCdtrAgt1.put("instrInf", mxAccText);
            }
            mxUdlcText = "/UDLC/" + mxUdlcText;
            if (mxUdlcText.length() > 140) {
                instrForCdtrAgt2.put("instrInf", mxUdlcText.substring(0, 139) + "+");
            } else {
                instrForCdtrAgt2.put("instrInf", mxUdlcText);
            }
        } else if ("UDLC".equals(configIndicator)) {
            mxUdlcText = "/UDLC/" + mxUdlcText;
            if (mxUdlcText.length() > 140) {
                mxUdlcText = mxUdlcText.substring(0, 139) + "+";
            }
            if (StringUtil.isNotEmpty(mxPhobText) || StringUtil.isNotEmpty(mxTelbText)) {
                if (StringUtil.isNotEmpty(mxPhobText)) {
                    String instructionInfo = mxPhobText;
                    int remainLength = 140 - instructionInfo.length();
                    if (StringUtil.isNotEmpty(mxTelbText) && remainLength >= 7) {
                        String tmpInstructionInfo = "/TELB/" + mxTelbText;
                        if (tmpInstructionInfo.length() > remainLength) {
                            tmpInstructionInfo = tmpInstructionInfo.substring(0, remainLength-1) + "+";
                        }
                        instructionInfo += tmpInstructionInfo;
                    }
                    instrForCdtrAgt1.put("cd", "PHOB");
                    instrForCdtrAgt1.put("instrInf", instructionInfo);
                } else { // /PHONBEN/不存在,/TELEBEN/必须存在
                    instrForCdtrAgt1.put("cd", "TELB");
                    instrForCdtrAgt1.put("instrInf", mxTelbText);
                }
                instrForCdtrAgt2.put("instrInf", mxUdlcText);
            } else {
                instrForCdtrAgt1.put("instrInf", mxUdlcText);
            }
        }
        JSONArray instrForCdtrAgtJsonArray = null;
        if (maps.containsKey("instrForCdtrAgt")) {
            instrForCdtrAgtJsonArray = (JSONArray)maps.get("instrForCdtrAgt");
        } else {
            instrForCdtrAgtJsonArray = new JSONArray();
            maps.put("instrForCdtrAgt", instrForCdtrAgtJsonArray);
        }
        if (instrForCdtrAgt1.size() > 0) {
            instrForCdtrAgtJsonArray.add(instrForCdtrAgt1);
        }
        if (instrForCdtrAgt2.size() > 0) {
            instrForCdtrAgtJsonArray.add(instrForCdtrAgt2);
        }
    }

    protected void mt_to_mxBNF_TSU_RI(String mt72, Map<String, Object> maps) {
        if (StringUtil.isEmpty(mt72)) {
            return;
        }
        String mxBnfText = mt72_to_mxText(mt72, "/BNF/", 135);
        int remainLength = 140; //初始长度140
        String mxUnstructuredRemittanceInformation = "";
        if (StringUtil.isNotEmpty(mxBnfText)) {
            mxUnstructuredRemittanceInformation = "/BNF/" + mxBnfText;
            remainLength = 140 - mxUnstructuredRemittanceInformation.length();
        }
        String mxTsuText = mt72_to_mxText(mt72, "/TSU/", 135);
        if (StringUtil.isNotEmpty(mxTsuText) && remainLength >= 6) {
            mxTsuText = "/TSU/" + mxTsuText;
            if (mxTsuText.length() > remainLength) {
                mxUnstructuredRemittanceInformation += mxTsuText.substring(0, remainLength-1) + "+";
            }
        }
        if (StringUtil.isNotEmpty(mxUnstructuredRemittanceInformation)) {
            List<String> ustrdList = new ArrayList<>();
            ustrdList.add(mxUnstructuredRemittanceInformation);
            Map<String, Object> rmtInfMaps = null;
            if (maps.containsKey("rmtInf")) {
                rmtInfMaps = (Map<String, Object>)maps.get("rmtInf");
            } else {
                rmtInfMaps = new HashMap<>();
                maps.put("rmtInf", rmtInfMaps);
            }
            rmtInfMaps.put("ustrd", ustrdList);
        }
    }
    /**
     * 前提条件是 mtPartyIdentifier 不以/开始
     * @param mtPartyIdentifier
     * @param nameAddress
     * @param maps
     */
    protected void mt_to_mxFATFIdentification(String mtPartyIdentifier, String nameAddress, Map<String, Object> maps) {
        if (StringUtil.isEmpty(mtPartyIdentifier)) {
            return;
        }
        String mtCode8 = "";
        if (StringUtil.isNotEmpty(nameAddress)) {
            String[] nameAndAddresses = nameAddress.split(Mx2MtConstants.NEW_LINE);
            for (int i=0; i<nameAndAddresses.length; i++) {
                if (nameAndAddresses[i].startsWith("8/")) {
                    mtCode8 = nameAndAddresses[i].substring(2);
                }
            }
        }
        String mtFullId = mtPartyIdentifier;
        if (mtPartyIdentifier.length() == 35) {
            mtFullId += mtCode8;
        }
        //格式类似 mtSchemeCode + "/" + mtCountryCode + "/" + mtIssuer + "/" + mtIdentifier
        String mtFATFCode = mtFullId.substring(0, 4);
        String mtFATFId = mtFullId.substring(5);
        String mtCountry = "";
        String mtIssuer = "";
        String mtId = "";
        Boolean flagOrgId = false;
        String mxOrgSchemeCode = "";
        if ("CUST".equals(mtFATFCode) || "EMPL".equals(mtFATFCode) || "DRLC".equals(mtFATFCode)) {
            mtCountry = mtFATFId.substring(0, 2);
            String regex = "(.*)/(.*)";
            Pattern p = Pattern.compile(regex);
            Matcher m = p.matcher(mtFATFId.substring(3));
            if (m.find()) {
                mtIssuer = m.group(1);
                mtId = m.group(2);
                if (StringUtil.isEmpty(mtId)) {
                    mtId = Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
                }
                if (mtIssuer.length() > 4 && "CUST".equals(mtFATFCode)) {
                    OrganisationIdentificationCode code = SwiftTransferUtil.getOrganisationIdentificationCodeByCode(mtIssuer.substring(0, 4));
                    if (code != null
                        && !OrganisationIdentificationCode.CUST.equals(code)
                        && !OrganisationIdentificationCode.TXID.equals(code)
                        && !OrganisationIdentificationCode.EMPL.equals(code)) {
                        mxOrgSchemeCode = code.value();
                        mtIssuer = mtIssuer.substring(5);
                        flagOrgId = true;
                    }
                }
            } else {
                mtId = mtFATFId.substring(3);
            }
            if (mtId.length() > 35) mtId = mtId.substring(0, 34) + "+";
        } else { //MTFATFCode 不在 {EMPL, CUST, DRLC}
            mtCountry = mtFATFId.substring(0, 2);
            mtId = mtFATFId.substring(3);
            if (StringUtil.isEmpty(mtId)) {
                mtId = Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
            }
            if (mtId.length() > 35) mtId = mtId.substring(0, 34) + "+";
        }
        String mxIssuer = mtCountry;
        if (StringUtil.isNotEmpty(mtIssuer)) {
            mxIssuer += "/" + mtIssuer;
        }
        //开始转换
        Map<String, Object> orgIdMaps = null;
        if (maps.containsKey("orgId")) {
            orgIdMaps = (Map<String, Object>) maps.get("orgId");
        } else {
            orgIdMaps = new HashMap<>();
            //如果orgIdMaps 长度大于0,put到maps
        }
        Map<String, Object> prvtIdMaps = null;
        if (maps.containsKey("prvtId")) {
            prvtIdMaps = (Map<String, Object>) maps.get("prvtId");
        } else {
            prvtIdMaps = new HashMap<>();
            //如果prvtIdMaps 长度大于0,put到maps
        }
        if (PersonIdentificationCode.ARNU.value().equals(mtFATFCode)
          || PersonIdentificationCode.CCPT.value().equals(mtFATFCode)
          || PersonIdentificationCode.DRLC.value().equals(mtFATFCode)
          || PersonIdentificationCode.EMPL.value().equals(mtFATFCode)
          || PersonIdentificationCode.NIDN.value().equals(mtFATFCode)
          || PersonIdentificationCode.SOSE.value().equals(mtFATFCode)
          || PersonIdentificationCode.TXID.value().equals(mtFATFCode)
          || (PersonIdentificationCode.CUST.value().equals(mtFATFCode) && !flagOrgId)) {
            JSONArray othrJsonArray = null;
            if (prvtIdMaps.containsKey("othr")) {
                othrJsonArray = (JSONArray) prvtIdMaps.get("othr");
            } else {
                othrJsonArray = new JSONArray();
                prvtIdMaps.put("othr", othrJsonArray);
            }
            Map<String, Object> othrMaps = new HashMap<>();
            othrJsonArray.add(othrMaps);
            othrMaps.put("id", mtId);
            othrMaps.put("issr", mxIssuer);
            Map<String, Object> schmeNmMaps = null;
            if (othrMaps.containsKey("schmeNm")) {
                schmeNmMaps = (Map<String, Object>) othrMaps.get("schmeNm");
            } else {
                schmeNmMaps = new HashMap<>();
                othrMaps.put("schmeNm", schmeNmMaps);
            }
            schmeNmMaps.put("cd", mtFATFCode);
        } else if (PersonIdentificationCode.CUST.value().equals(mtFATFCode) && flagOrgId) {
            JSONArray othrJsonArray = null;
            if (orgIdMaps.containsKey("othr")) {
                othrJsonArray = (JSONArray) orgIdMaps.get("othr");
            } else {
                othrJsonArray = new JSONArray();
                orgIdMaps.put("othr", othrJsonArray);
            }
            Map<String, Object> othrMaps = new HashMap<>();
            othrJsonArray.add(othrMaps);
            othrMaps.put("id", mtId);
            othrMaps.put("issr", mxIssuer);
            Map<String, Object> schmeNmMaps = null;
            if (othrMaps.containsKey("schmeNm")) {
                schmeNmMaps = (Map<String, Object>) othrMaps.get("schmeNm");
            } else {
                schmeNmMaps = new HashMap<>();
                othrMaps.put("schmeNm", schmeNmMaps);
            }
            schmeNmMaps.put("cd", mxOrgSchemeCode);
        }
        if (orgIdMaps.size() > 0) {
            maps.put("orgId", orgIdMaps);
        }
        if (prvtIdMaps.size() > 0) {
            maps.put("prvtId", prvtIdMaps);
        }
    }

    /**
     *
     * @param mtPartyIdentifier
     * @param nameAddress
     * @param maps
     */
    protected void mt_to_mxFATFNameAndAddress(String mtPartyIdentifier, String nameAddress, Map<String, Object> maps) {
        mt_to_mxPartyNameAndStructuredAddress(nameAddress, maps);
        String mtCode4 = "";
        String mtCode5 = "";
        String mtCode6 = "";
        String mtCode7 = "";
        String mtCode8 = "";
        if (StringUtil.isNotEmpty(nameAddress)) {
            String[] nameAndAddresses = nameAddress.split(Mx2MtConstants.NEW_LINE);
            for (int i=0; i<nameAndAddresses.length; i++) {
                if (nameAndAddresses[i].startsWith("4/")) {
                    mtCode4 = nameAndAddresses[i].substring(2);
                }
                if (nameAndAddresses[i].startsWith("5/")) {
                    mtCode5 = nameAndAddresses[i].substring(2);
                }
                if (nameAndAddresses[i].startsWith("6/")) {
                    mtCode6 = nameAndAddresses[i].substring(2);
                }
                if (nameAndAddresses[i].startsWith("7/")) {
                    mtCode7 = nameAndAddresses[i].substring(2);
                }
                if (nameAndAddresses[i].startsWith("8/")) {
                    mtCode8 = nameAndAddresses[i].substring(2);
                }
            }
        }
        if (StringUtil.isEmpty(mtCode4)
                && StringUtil.isEmpty(mtCode5)
                && StringUtil.isEmpty(mtCode6)
                && StringUtil.isEmpty(mtCode7)) {
            return;  //找不到mtcode4 5 6 7，终止转换
        }
        Map<String, Object> idMaps = null;
        if (maps.containsKey("id")) {
            idMaps = (Map<String, Object>) maps.get("id");
        } else {
            idMaps = new HashMap<>();
            maps.put("id", idMaps);
        }
        if (StringUtil.isNotEmpty(mtCode6)) {
            boolean flagOrgId = false;
            String regex = "[A-Z]{2}/LEIC/([A-Z0-9]{18,18}[0-9]{2,2})";
            String lei = "";
            Pattern p = Pattern.compile(regex);
            Matcher m = p.matcher(mtCode6);
            if (m.find()) {
                lei = m.group(1);
                if (mtPartyIdentifier.startsWith("/")) {
                    flagOrgId = true;
                } else {
                    String regex1 = "CUST/[A-Z]{2}/([A-Z0-9]{4})";
                    Pattern p1 = Pattern.compile(regex1);
                    Matcher m1 = p1.matcher(mtPartyIdentifier);
                    if (m1.find()) {
                        String orgIdCode = m1.group(1);
                        OrganisationIdentificationCode code = SwiftTransferUtil.getOrganisationIdentificationCodeByCode(orgIdCode);
                        if (code != null
                            && !OrganisationIdentificationCode.CUST.equals(code)
                            && !OrganisationIdentificationCode.TXID.equals(code)
                            && !OrganisationIdentificationCode.EMPL.equals(code)) {
                            flagOrgId = true;
                        }
                    }
                }
            }
            if (flagOrgId) {
                Map<String, Object> orgIdMaps = null;
                if (idMaps.containsKey("orgId")) {
                    orgIdMaps = (Map<String, Object>)idMaps.get("orgId");
                } else {
                    orgIdMaps = new HashMap<>();
                    idMaps.put("orgId", orgIdMaps);
                }
                orgIdMaps.put("lei", lei);
                return;  //组织信息转换了,私人信息将不会转换.
            }
        }
        Map<String, Object> prvtIdMaps = null;
        if (idMaps.containsKey("prvtId")) {
            prvtIdMaps = (Map<String, Object>) idMaps.get("prvtId");
        } else {
            prvtIdMaps = new HashMap<>();
            //idMaps.put("prvtId", prvtIdMaps);
        }
        if (StringUtil.isNotEmpty(mtCode4) && StringUtil.isNotEmpty(mtCode5)) {
            try {
                Map<String, Object> dtAndPlcOfBirthMaps = null;
                if (prvtIdMaps.containsKey("dtAndPlcOfBirth")) {
                    dtAndPlcOfBirthMaps = (Map<String, Object>) prvtIdMaps.get("dtAndPlcOfBirth");
                } else {
                    dtAndPlcOfBirthMaps = new HashMap<>();
                    prvtIdMaps.put("dtAndPlcOfBirth", dtAndPlcOfBirthMaps);
                }
                Date brithDate = DateUtil.parseDate(mtCode4, "yyyyMMdd");
                String brithDateStr = DateUtil.format(brithDate, "yyyy-MM-dd");
                dtAndPlcOfBirthMaps.put("birthDt", brithDateStr);
                String regex = "([A-Z]{2})/(.*)";
                Pattern p = Pattern.compile(regex);
                Matcher m = p.matcher(mtCode5);
                if (m.find()) {
                    dtAndPlcOfBirthMaps.put("ctryOfBirth", m.group(1));
                    dtAndPlcOfBirthMaps.put("cityOfBirth", m.group(2));
                }
            } catch (ParseException e) {
                throw new SwiftException("ERROR", e.getMessage());
            }
        }
        if (StringUtil.isNotEmpty(mtPartyIdentifier) && !mtPartyIdentifier.startsWith("CUST")) {
            if (StringUtil.isNotEmpty(mtCode6)) {
                String mtFullId = mtCode6;
                if ((mtPartyIdentifier.startsWith("/") || mtPartyIdentifier.length() < 35) && mtCode8.length() > 0 && mtCode6.length() == 33) {
                    mtFullId += mtCode8;
                }
                String regex = "(.*)/(.*)";
                Pattern p = Pattern.compile(regex);
                Matcher m = p.matcher(mtFullId.substring(3));
                String mtCountry = mtFullId.substring(0,2);
                String mtIssuer = "";
                String mtNum = "";
                if (m.find()) {
                    mtIssuer = m.group(1);
                    mtNum = m.group(2);
                    if (StringUtil.isEmpty(mtNum)) {
                        mtNum = Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
                    }
                } else {
                    mtNum = mtFullId.substring(3);
                }
                if (mtNum.length() > 35) {
                    mtNum = mtNum.substring(0, 34) + "+";
                }
                JSONArray othrJsonArray = null;
                if (prvtIdMaps.containsKey("othr")) {
                    othrJsonArray = (JSONArray) prvtIdMaps.get("othr");
                } else {
                    othrJsonArray = new JSONArray();
                    prvtIdMaps.put("othr", othrJsonArray);
                }
                Map<String, Object> othrMaps = new HashMap<>();
                othrJsonArray.add(othrMaps);
                othrMaps.put("id", mtNum);
                Map<String, Object> schmeNmMaps = null;
                if (othrMaps.containsKey("schmeNm")) {
                    schmeNmMaps = (Map<String, Object>) othrMaps.get("schmeNm");
                } else {
                    schmeNmMaps = new HashMap<>();
                    othrMaps.put("schmeNm", schmeNmMaps);
                }
                schmeNmMaps.put("cd", "CUST");
                if (StringUtil.isNotEmpty(mtIssuer)) {
                    mtCountry += "/" + mtIssuer;
                }
                othrMaps.put("issr", mtCountry);
            }
        }
        if (StringUtil.isNotEmpty(mtPartyIdentifier) && !mtPartyIdentifier.startsWith("NIDN")) {
            if (StringUtil.isNotEmpty(mtCode7)) {
                JSONArray othrJsonArray = null;
                if (prvtIdMaps.containsKey("othr")) {
                    othrJsonArray = (JSONArray) prvtIdMaps.get("othr");
                } else {
                    othrJsonArray = new JSONArray();
                    prvtIdMaps.put("othr", othrJsonArray);
                }
                if (othrJsonArray.size() >= 2) {
                    return;
                }
                String mtFullId = mtCode7;
                if ((mtPartyIdentifier.startsWith("/") || mtPartyIdentifier.length() < 35) && mtCode8.length() > 0
                        && mtCode6.length() != 33 && mtCode7.length() == 33) {
                    mtFullId += mtCode8;
                }
                if (mtFullId.length() > 3 && mtFullId.indexOf("/") == 2) {
                    String mtNum = mtFullId.substring(3);
                    if (mtNum.length() > 35) {
                        mtNum = mtNum.substring(0, 34) + "+";
                    }
                    Map<String, Object> othrMaps = new HashMap<>();
                    othrJsonArray.add(othrMaps);
                    othrMaps.put("id", mtNum);
                    Map<String, Object> schmeNmMaps = null;
                    if (othrMaps.containsKey("schmeNm")) {
                        schmeNmMaps = (Map<String, Object>) othrMaps.get("schmeNm");
                    } else {
                        schmeNmMaps = new HashMap<>();
                        othrMaps.put("schmeNm", schmeNmMaps);
                    }
                    schmeNmMaps.put("cd", "NIDN");
                    othrMaps.put("issr", mtFullId.substring(0, 2));
                }
            }
        }
        if (prvtIdMaps.size() > 0) {
            idMaps.put("prvtId", prvtIdMaps);
        }
    }

    /**
     * /INTA/ -> MXIntermediaryAgent2, MXIntermediaryAgent3
     * /SVCLVL/ ->  Payment Type Information/Service Level
     * /LOCINS/ ->  Payment Type Information/Local Instrument
     * /CATPURP/ -> Payment Type Information/Category Purpose
     * @param mt72
     * @param maps
     */
    protected void mt_to_mxField72NewCodeWords(String mt72, boolean pacs009001Flag, Map<String, Object> maps) {
        String mt72Value = mt72.replace("\r\n//", "");
        String[] lines = mt72Value.split("\r\n");
        List<String> intermediaryAgentLines = new ArrayList<>();
        List<String> serviceLevelLines = new ArrayList<>();
        List<String> localInstrumentLines = new ArrayList<>();
        List<String> categoryPurposeLines = new ArrayList<>();
        List<String> purposeLines = new ArrayList<>();
        for (int i=0; i<lines.length; i++) {
            if (lines[i].startsWith("/INTA/")) {
                String line = lines[i].substring(6);
                if (StringUtil.isNotEmpty(line)) {
                    intermediaryAgentLines.add(line);
                }
            }
            if (lines[i].startsWith("/SVCLVL/")) {
                String line = lines[i].substring(8);
                if (StringUtil.isNotEmpty(line)) {
                    serviceLevelLines.add(line);
                }
            }
            if (lines[i].startsWith("/LOCINS/")) {
                String line = lines[i].substring(8);
                if (StringUtil.isNotEmpty(line)) {
                    localInstrumentLines.add(line);
                }
            }
            if (lines[i].startsWith("/CATPURP/")) {
                String line = lines[i].substring(9);
                if (StringUtil.isNotEmpty(line)) {
                    categoryPurposeLines.add(line);
                }
            }
            if (lines[i].startsWith("/PURP/")) {
                String line = lines[i].substring(6);
                if (StringUtil.isNotEmpty(line)) {
                    purposeLines.add(line);
                }
            }
        }
        //开始转换
        if (intermediaryAgentLines.size() > 0) {
            for (int i=0; i<intermediaryAgentLines.size(); i++) {
                if (i == 2) break; //最多转换2次 IntermediaryAgent2, IntermediaryAgent3
                String line = intermediaryAgentLines.get(i);
                Map<String, Object> intrmyAgtMaps = new HashMap<>();
                mt_to_mxIntermediaryAgent(line, intrmyAgtMaps);
                maps.put("intrmyAgt"+(i+2), intrmyAgtMaps);
            }
        }
        Map<String, Object> pmtTpInfMaps = null;
        if (maps.containsKey("pmtTpInf")) {
            pmtTpInfMaps = (Map<String, Object>) maps.get("pmtTpInf");
        } else {
            pmtTpInfMaps = new HashMap<>();
        }
        if (serviceLevelLines.size() > 0) {
            JSONArray svcLvlJsonArray = null;
            if (pmtTpInfMaps.containsKey("svcLvl")) {
                svcLvlJsonArray = (JSONArray) pmtTpInfMaps.get("svcLvl");
            } else {
                svcLvlJsonArray = new JSONArray();
            }
            for (int i=0; i<serviceLevelLines.size(); i++) {
                if (svcLvlJsonArray.size() >= 3) break; //Service Level 最多转换3次
                String line = serviceLevelLines.get(i);
                if (ServiceLevelCode.SDVA.value().equals(line)) {
                    continue;
                }
                if (line.matches("G00[1-9]{1}")) {
                    continue;
                }
                Map<String, Object> svcLvlMaps = new HashMap<>();
                ServiceLevelCode code = SwiftTransferUtil.getServiceLevelByValue(line);
                if (code != null) {
                    svcLvlMaps.put("cd", code.value());
                } else {
                    if (line.length() > 35) {
                        line = line.substring(0, 34) + "+";
                    }
                    svcLvlMaps.put("prtry", line);
                }
                svcLvlJsonArray.add(svcLvlMaps);
            }
            if (svcLvlJsonArray.size() > 0) {
                pmtTpInfMaps.put("svcLvl", svcLvlJsonArray);
            }
        }
        //NOT IsInList {CRED,CRTS,SPAY, SPRI, SSTD}
        if (localInstrumentLines.size() > 0 && !pmtTpInfMaps.containsKey("lclInstrm")) {
            Map<String, Object> lclInstrmMaps = new HashMap<>();
            for (int i=0; i<localInstrumentLines.size(); i++) {
                if (lclInstrmMaps.size() == 1) break; //只取第一条
                String line = localInstrumentLines.get(i);
                if ("CRED".equals(line) || "CRTS".equals(line)
                        || "SPAY".equals(line) || "SPRI".equals(line) || "SSTD".equals(line)) {
                    continue;
                }
                LocalInstrumentCode code = SwiftTransferUtil.getLocalInstrumentByValue(line);
                if (code != null) {
                    lclInstrmMaps.put("cd", code.value());
                } else {
                    if (line.length() > 35) {
                        line = line.substring(0, 34) + "+";
                    }
                    lclInstrmMaps.put("prtry", line);
                }
            }
            if (lclInstrmMaps.size() > 0) {
                pmtTpInfMaps.put("lclInstrm", lclInstrmMaps);
            }
        }
        if (categoryPurposeLines.size() > 0 && !pmtTpInfMaps.containsKey("ctgyPurp")) {
            Map<String, Object> ctgyPurpMaps = new HashMap<>();
            for (int i=0; i<localInstrumentLines.size(); i++) {
                if (ctgyPurpMaps.size() == 1) break; //只取第一条
                String line = localInstrumentLines.get(i);
                if (CategoryPurposeCode.INTC.value().equals(line)
                        || CategoryPurposeCode.CORT.value().equals(line)) {
                    continue;
                }
                CategoryPurposeCode code = SwiftTransferUtil.getCategoryPurposeByValue(line);
                if (code != null) {
                    ctgyPurpMaps.put("cd", code.value());
                } else {
                    if (line.length() > 35) {
                        line = line.substring(0, 34) + "+";
                    }
                    ctgyPurpMaps.put("prtry", line);
                }
            }
            if (ctgyPurpMaps.size() > 0) {
                pmtTpInfMaps.put("ctgyPurp", ctgyPurpMaps);
            }
        }
        if (pmtTpInfMaps.size() > 0) {
            maps.put("pmtTpInf", pmtTpInfMaps);
        }
        if (purposeLines.size() > 0 && pacs009001Flag) {
            Map<String, Object> purpMaps = null;
            if (maps.containsKey("purp")) {
                purpMaps = (Map<String, Object>)maps.get("purp");
            } else {
                purpMaps = new HashMap<>();
                maps.put("purp", purpMaps);
            }
            String purpCode = purposeLines.get(0);
            PurposeCode code = SwiftTransferUtil.getPurposeByValue(purpCode);
            if (code != null) {
                purpMaps.put("cd", purpCode);
            } else {
                if (purpCode.length() > 35) {
                    purpCode = purpCode.substring(0, 34) + "+";
                }
                purpMaps.put("prtry", purpCode);
            }
        }
    }
    /**
     *
     * @param mtAgent
     * @param maps
     */
    protected void mt_to_mxIntermediaryAgent(String mtAgent, Map<String, Object> maps) {
        if (StringUtil.isEmpty(mtAgent)) {
            return;
        }
        if (SwiftTransferUtil.isBIC(mtAgent)) {
            mt_to_mxBICFI(mtAgent, maps);
            return;
        }
        String regex = "([A-Z]{5})(.*)";
        Pattern p = Pattern.compile(regex);
        Matcher m = p.matcher(mtAgent);
        if (m.find()) {
            String mxCode = m.group(1);
            String mxMemId = m.group(2);
            if (SwiftTransferUtil.getClsSysMemberByValue(mxCode) != null) {
                Map<String, Object> finInstnIdMaps = null;
                if (maps.containsKey("finInstnId")) {
                    finInstnIdMaps = (Map<String, Object>)maps.get("finInstnId");
                } else {
                    finInstnIdMaps = new HashMap<>();
                    maps.put("finInstnId", finInstnIdMaps);
                }
                Map<String, Object> clrSysMmbIdMaps = null;
                if (finInstnIdMaps.containsKey("clrSysMmbId")) {
                    clrSysMmbIdMaps = (Map<String, Object>)finInstnIdMaps.get("clrSysMmbId");
                } else {
                    clrSysMmbIdMaps = new HashMap<>();
                    finInstnIdMaps.put("clrSysMmbId", clrSysMmbIdMaps);
                }
                if (mxMemId.length() > 28) {
                    mxMemId = mxMemId.substring(0, 27) + "+";
                }
                clrSysMmbIdMaps.put("mmbId", mxMemId);
                Map<String, Object> clrSysIdMaps = null;
                if (clrSysMmbIdMaps.containsKey("clrSysId")) {
                    clrSysIdMaps = (Map<String, Object>)clrSysMmbIdMaps.get("clrSysId");
                } else {
                    clrSysIdMaps = new HashMap<>();
                    clrSysMmbIdMaps.put("clrSysId", clrSysIdMaps);
                }
                clrSysMmbIdMaps.put("cd", mxCode);
                return;
            }
        }
        String mxName = "";
        String mxCountryCode = "";
        String mxTownName = "";
        regex = "(.*)\\(([A-Z]{2})\\((.*)";
        p = Pattern.compile(regex);
        m = p.matcher(mtAgent);
        if (m.find()) {
            mxName = m.group(1);
            mxCountryCode = m.group(2);
            mxTownName = m.group(3);
        } else {
            regex = "(.*)\\(([A-Z]{2})";
            p = Pattern.compile(regex);
            m = p.matcher(mtAgent);
            if (m.find()) {
                mxName = m.group(1);
                mxCountryCode = m.group(2);
            } else {
                mxName = mtAgent;
            }
        }
        Map<String, Object> finInstnIdMaps = null;
        if (maps.containsKey("finInstnId")) {
            finInstnIdMaps = (Map<String, Object>)maps.get("finInstnId");
        } else {
            finInstnIdMaps = new HashMap<>();
            maps.put("finInstnId", finInstnIdMaps);
        }
        finInstnIdMaps.put("nm", mxName);
        Map<String, Object> pstlAdrMaps = null;
        if (finInstnIdMaps.containsKey("pstlAdr")) {
            pstlAdrMaps = (Map<String, Object>)finInstnIdMaps.get("pstlAdr");
        } else {
            pstlAdrMaps = new HashMap<>();
            finInstnIdMaps.put("pstlAdr", pstlAdrMaps);
        }
        if (StringUtil.isEmpty(mxCountryCode) && StringUtil.isEmpty(mxTownName)) {
            List<String> adrLineList = new ArrayList<>();
            adrLineList.add(Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE);
            pstlAdrMaps.put("adrLine", adrLineList);
        } else {
            if (StringUtil.isNotEmpty(mxCountryCode)) {
                pstlAdrMaps.put("ctry", mxCountryCode);
            }
            if (StringUtil.isNotEmpty(mxTownName)) {
                pstlAdrMaps.put("twnNm", mxTownName);
            }
        }
    }

    protected String mt_To_mxField76(String mt76, Map<String, Object> maps){
        String mt76Value = mt76.replace("\r\n//", "").trim();
        String status = "";
        String reason = "";
        if(mt76Value.length()>5){
            status = mt76Value.substring(1,5);
        }
        if(mt76Value.length()>=10){
            if(mt76Value.length()==10){
                reason = mt76Value.substring(6);
            }else {
                reason = mt76Value.substring(6,10);
            }
        }
        String additionalInformation = "";
        //MXReasonList = {AC04, AGNT, AM04, ARDT, CUST, INDM, LEGL, NOAS, NOOR, PTNA, RQDA}
        if("AC04".equals(reason)||"AGNT".equals(reason)||"AM04".equals(reason)
                ||"ARDT".equals(reason)||"CUST".equals(reason)||"INDM".equals(reason)
                ||"LEGL".equals(reason)||"NOAS".equals(reason)||"NOOR".equals(reason)
                ||"PTNA".equals(reason)||"RQDA".equals(reason)){
                if(mt76Value.length()>10){
                    additionalInformation = mt76Value.substring(11);
                }
        }else {
            if(mt76Value.length()>6){
                additionalInformation = mt76Value.substring(6);
            }
            if ("RJCR".equals(status)){
                reason = "NARR";
            }else {
                reason = "";
            }
        }
        Map<String, Object> cxlStsRsnInfMaps = null;
        JSONArray cxlStsRsnInfJsonArray = null;
        if(maps.containsKey("txInfAndSts")){
            cxlStsRsnInfJsonArray = (JSONArray) maps.get("cxlStsRsnInf");
            if (cxlStsRsnInfJsonArray.size()>0) {
                cxlStsRsnInfMaps = (Map<String, Object>)cxlStsRsnInfJsonArray.get(0);
            } else {
                cxlStsRsnInfMaps = new HashMap<>();
                cxlStsRsnInfJsonArray.add(cxlStsRsnInfMaps);
            }
        }else {
            cxlStsRsnInfJsonArray = new JSONArray();
            cxlStsRsnInfMaps = new HashMap<>();
            maps.put("cxlStsRsnInf",cxlStsRsnInfJsonArray);
            cxlStsRsnInfJsonArray.add(cxlStsRsnInfMaps);
        }
        if(StringUtil.isNotEmpty(reason)){
            Map<String, Object> rsnMaps = null;
            if(cxlStsRsnInfMaps.containsKey("rsn")){
                rsnMaps = (Map<String, Object>)cxlStsRsnInfMaps.get("rsn");
            }else {
                rsnMaps = new HashMap<>();
                cxlStsRsnInfMaps.put("rsn",rsnMaps);
            }
            rsnMaps.put("cd",reason);
        }
        List<String> list = new ArrayList<>();
        if(additionalInformation.length()>210){
            additionalInformation = additionalInformation.substring(0,209) + "+";
        }
        if (additionalInformation.length()>105){
            list.add(additionalInformation.substring(0,105));
            list.add(additionalInformation.substring(105));
        }
        JSONArray addtlInfJsonArray = null;
        if(cxlStsRsnInfMaps.containsKey("addtlInf")){
            addtlInfJsonArray = (JSONArray) cxlStsRsnInfMaps.get("cxlStsRsnInf");
        }else {
            addtlInfJsonArray = new JSONArray();
            cxlStsRsnInfMaps.put("addtlInf",addtlInfJsonArray);
        }
        addtlInfJsonArray.addAll(list);
        if(StringUtil.isNotEmpty(status)){
            return status;
        }else {
            return "";
        }
    }
    protected String getMxType(String mtType){
        String mxType = "";
        if("103".equals(mtType)){
            mxType = "pacs.008";
        }else if("104".equals(mtType)){
            mxType = "pacs.003";
        }else if("202".equals(mtType)||"205".equals(mtType)){
            mxType = "pacs.009";
        }else if("204".equals(mtType)){
            mxType = "pacs.010";
        }else if(mtType.matches("10[0-9]{1}")||mxType.matches("20[0-9]{1}")){
            mxType = "MT" + mtType;
        }else {
            mxType = "MT" + mtType;
        }
        return mxType;
    }
    /**
     * MT 转 MX 转换函数结束
     */

}
