package com.brilliance.swift.mt2mx;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2mx.camt029001.Mt2MxCamt029001Creator;
import com.brilliance.swift.mt2mx.pacs008001.Mt2MxPacs008001Creator;
import com.brilliance.swift.mt2mx.pacs009001.Mt2MxPacs009001Creator;
import com.prowidesoftware.swift.model.mt.AbstractMT;

import java.util.List;
import java.util.Map;

public class Mt2MxCreatorManager {

    public AbstractMT abstractMT = null;

    public void init(String mtStr) {
        try {
            abstractMT = AbstractMT.parse(mtStr);
        } catch (Exception e) {
            throw new SwiftException("ERROR", e.getMessage());
        }
    }

    public String mt2mx(String mtStr, String outPutFilePath, Map<String, Object> extraMap) throws SwiftException {
        init(mtStr);
        AbstractMt2MxCreator creator = getMt2MxCreator();
        Mt2MxContext context = new Mt2MxContext();
        context.set(AbstractMT.class, abstractMT);
        context.set(Mt2MxContextIdentifier.MT_TO_MX_OUTPUT_FILE_PATH, outPutFilePath);
        context.putAll(extraMap);
        creator.setContext(context);
        creator.preProcess();
        List<Mt2MxParseField> parseFields = creator.getParseFieldList();
        for (int i=0; i<parseFields.size(); i++) {
            AbstractMt2MxParseField parseField = (AbstractMt2MxParseField) parseFields.get(i);
            parseField.setContext(context).initJsonMaps();
            parseField.parseField();
        }
        creator.postProcess();
        return (String) context.get(Mt2MxContextIdentifier.MT_TO_MX_XML);
    }

    public AbstractMt2MxCreator getMt2MxCreator() throws SwiftException {
        String messageType = abstractMT.getMessageType();
        if ("103".equals(messageType)) {
            return new Mt2MxPacs008001Creator();
        } else if ("202".equals(messageType) || "205".equals(messageType)) {
            return new Mt2MxPacs009001Creator();
        } else if("196".equals(messageType) || "296".equals(messageType)) {
            return new Mt2MxCamt029001Creator();
        } else {
            throw new SwiftException("ERROR", "Invalid message type");
        }
    }
}
