package com.brilliance.swift.mt2mx.pacs009001.impl;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2mx.pacs009001.AbstractMt2MxPacs009001ParseField;
import com.brilliance.swift.util.StringUtil;
import com.prowidesoftware.swift.model.Tag;
import com.prowidesoftware.swift.model.field.Field56A;
import com.prowidesoftware.swift.model.field.Field56C;
import com.prowidesoftware.swift.model.field.Field56D;
import com.prowidesoftware.swift.model.mt.AbstractMT;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class Pacs009001ParseSeqB56Field extends AbstractMt2MxPacs009001ParseField {

    private static final String NAME_A = "56A";

    private static final String NAME_C = "56C";

    private static final String NAME_D = "56D";

    private static final String SEQUENCE_B = "B";

    @Override
    public void parseField() throws SwiftException {
        AbstractMT abstractMT = context.get(AbstractMT.class);
        if (!abstractMT.getSwiftMessage().isCOV()) {
            return;
        }
        Field56A field56A = null;
        Field56C field56C = null;
        Field56D field56D = null;
        Tag tag = getTagByName(NAME_A, SEQUENCE_B);
        if (tag != null) {
            field56A = (Field56A)tag.asField();
        }
        tag = getTagByName(NAME_C, SEQUENCE_B);
        if (tag != null) {
            field56C = (Field56C)tag.asField();
        }
        tag = getTagByName(NAME_D, SEQUENCE_B);
        if (tag != null) {
            field56D = (Field56D)tag.asField();
        }
        Map<String, Object> intrmyAgt1Maps = null;
        if (undrlygCstmrCdtTrfMaps.containsKey("intrmyAgt1")) {
            intrmyAgt1Maps = (Map<String, Object>) undrlygCstmrCdtTrfMaps.get("intrmyAgt1");
        } else {
            intrmyAgt1Maps = new HashMap<>();
        }
        Map<String, Object> intrmyAgt1AcctMaps = null;
        if (undrlygCstmrCdtTrfMaps.containsKey("intrmyAgt1Acct")) {
            intrmyAgt1AcctMaps = (Map<String, Object>) undrlygCstmrCdtTrfMaps.get("intrmyAgt1Acct");
        } else {
            intrmyAgt1AcctMaps = new HashMap<>();
        }
        String account = "";
        if (field56A != null) {
            String bicCode = field56A.getBIC();
            mt_to_mxBICFI(bicCode, intrmyAgt1Maps);
            if (StringUtil.isNotEmpty(field56A.getComponent1())) {
                account = "/" + field56A.getComponent1();
            }
            if (StringUtil.isNotEmpty(field56A.getComponent2())) {
                account = "/" + field56A.getComponent2();
            }
            if (account.startsWith("//") && !account.startsWith("//CH") && !account.startsWith("//FW") && !account.startsWith("//RT")) {
                Map<String, Object> finInstnIdMaps = null;
                if (intrmyAgt1Maps.containsKey("finInstnId")) {
                    finInstnIdMaps = (Map<String, Object>)intrmyAgt1Maps.get("finInstnId");
                } else {
                    finInstnIdMaps = new HashMap<>();
                    intrmyAgt1Maps.put("finInstnId", finInstnIdMaps);
                }
                Map<String, Object> clrSysMmbIdMaps = null;
                if (finInstnIdMaps.containsKey("clrSysMmbId")) {
                    clrSysMmbIdMaps = (Map<String, Object>)finInstnIdMaps.get("clrSysMmbId");
                } else {
                    clrSysMmbIdMaps = new HashMap<>();
                    finInstnIdMaps.put("clrSysMmbId", clrSysMmbIdMaps);
                }
                mt_to_mxClearingIdentifier(account, clrSysMmbIdMaps);
            } else if (!account.startsWith("//") || account.startsWith("//CH")) {
                mt_to_mxFinancialInstitutionAccount(account, intrmyAgt1AcctMaps);
            }
        } else if (field56C != null) {
            account = field56C.getValue();
            Map<String, Object> finInstnIdMaps = null;
            if (intrmyAgt1Maps.containsKey("finInstnId")) {
                finInstnIdMaps = (Map<String, Object>)intrmyAgt1Maps.get("finInstnId");
            } else {
                finInstnIdMaps = new HashMap<>();
                intrmyAgt1Maps.put("finInstnId", finInstnIdMaps);
            }
            if (account.startsWith("//") && !account.startsWith("//CH") && !account.startsWith("//FW")) {
                if (isMTClearingSystemCodeInList(account)) {
                    Map<String, Object> clrSysMmbIdMaps = null;
                    if (finInstnIdMaps.containsKey("clrSysMmbId")) {
                        clrSysMmbIdMaps = (Map<String, Object>)finInstnIdMaps.get("clrSysMmbId");
                    } else {
                        clrSysMmbIdMaps = new HashMap<>();
                        finInstnIdMaps.put("clrSysMmbId", clrSysMmbIdMaps);
                    }
                    mt_to_mxClearingIdentifier(account, clrSysMmbIdMaps);
                    //name address 设置NOTPROVIDED
                    finInstnIdMaps.put("nm", Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE);
                    Map<String, Object> pstlAdrMaps = null;
                    if (finInstnIdMaps.containsKey("pstlAdr")) {
                        pstlAdrMaps = (Map<String, Object>)finInstnIdMaps.get("pstlAdr");
                    } else {
                        pstlAdrMaps = new HashMap<>();
                        finInstnIdMaps.put("pstlAdr", pstlAdrMaps);
                    }
                    List<String> adrLineList = new ArrayList<>();
                    adrLineList.add(Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE);
                    pstlAdrMaps.put("adrLine", adrLineList);
                } else {
                    mt_to_mxClearingSystemToNameAndAddressLine(account, null, finInstnIdMaps);
                }
            } else if (!account.startsWith("//") || account.startsWith("//CH")) {
                mt_to_mxFinancialInstitutionAccount(account, intrmyAgt1AcctMaps);
                //name address 设置NOTPROVIDED
                finInstnIdMaps.put("nm", Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE);
                Map<String, Object> pstlAdrMaps = null;
                if (finInstnIdMaps.containsKey("pstlAdr")) {
                    pstlAdrMaps = (Map<String, Object>)finInstnIdMaps.get("pstlAdr");
                } else {
                    pstlAdrMaps = new HashMap<>();
                    finInstnIdMaps.put("pstlAdr", pstlAdrMaps);
                }
                List<String> adrLineList = new ArrayList<>();
                adrLineList.add(Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE);
                pstlAdrMaps.put("adrLine", adrLineList);
            }
        } else if (field56D != null) {
            if (StringUtil.isNotEmpty(field56D.getComponent1())) {
                account = "/" + field56D.getComponent1();
            }
            if (StringUtil.isNotEmpty(field56D.getComponent2())) {
                account = "/" + field56D.getComponent2();
            }
            String nameAddress = field56D.getNameAndAddress();
            mt_to_mxFinancialInstitutionNameAndUnstructuredAddress(nameAddress, intrmyAgt1Maps);
            if (account.startsWith("//") && !account.startsWith("//CH") && !account.startsWith("//FW")) {
                Map<String, Object> finInstnIdMaps = null;
                if (intrmyAgt1Maps.containsKey("finInstnId")) {
                    finInstnIdMaps = (Map<String, Object>)intrmyAgt1Maps.get("finInstnId");
                } else {
                    finInstnIdMaps = new HashMap<>();
                    intrmyAgt1Maps.put("finInstnId", finInstnIdMaps);
                }
                Map<String, Object> clrSysMmbIdMaps = null;
                if (finInstnIdMaps.containsKey("clrSysMmbId")) {
                    clrSysMmbIdMaps = (Map<String, Object>)finInstnIdMaps.get("clrSysMmbId");
                } else {
                    clrSysMmbIdMaps = new HashMap<>();
                    finInstnIdMaps.put("clrSysMmbId", clrSysMmbIdMaps);
                }
                mt_to_mxClearingIdentifier(account, clrSysMmbIdMaps);
            } else if (!account.startsWith("//") || account.startsWith("//CH")) {
                mt_to_mxFinancialInstitutionAccount(account, intrmyAgt1AcctMaps);
            }
        }
        if (intrmyAgt1Maps.size() > 0) {
            undrlygCstmrCdtTrfMaps.put("intrmyAgt1", intrmyAgt1Maps);
        }
        if (intrmyAgt1AcctMaps.size() > 0) {
            undrlygCstmrCdtTrfMaps.put("intrmyAgt1Acct", intrmyAgt1AcctMaps);
        }
    }
}
