package com.brilliance.swift.mt2mx.pacs009001.impl;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2mx.pacs009001.AbstractMt2MxPacs009001ParseField;
import com.brilliance.swift.util.StringUtil;
import com.prowidesoftware.swift.model.Tag;
import com.prowidesoftware.swift.model.field.Field57A;
import com.prowidesoftware.swift.model.field.Field57B;
import com.prowidesoftware.swift.model.field.Field57C;
import com.prowidesoftware.swift.model.field.Field57D;
import com.prowidesoftware.swift.model.mt.AbstractMT;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class Pacs009001ParseSeqB57Field extends AbstractMt2MxPacs009001ParseField {

    private static final String NAME_A = "57A";

    private static final String NAME_B = "57B";

    private static final String NAME_C = "57C";

    private static final String NAME_D = "57D";

    private static final String SEQUENCE_B = "B";

    @Override
    public void parseField() throws SwiftException {
        AbstractMT abstractMT = context.get(AbstractMT.class);
        if (!abstractMT.getSwiftMessage().isCOV()) {
            return;
        }
        Field57A field57A = null;
        Field57B field57B = null;
        Field57C field57C = null;
        Field57D field57D = null;
        Tag tag = getTagByName(NAME_A, SEQUENCE_B);
        if (tag != null) {
            field57A = (Field57A)tag.asField();
        }
        tag = getTagByName(NAME_B,  SEQUENCE_B);
        if (tag != null) {
            field57B = (Field57B)tag.asField();
        }
        tag = getTagByName(NAME_C,  SEQUENCE_B);
        if (tag != null) {
            field57C = (Field57C)tag.asField();
        }
        tag = getTagByName(NAME_D,  SEQUENCE_B);
        if (tag != null) {
            field57D = (Field57D)tag.asField();
        }
        Map<String, Object> cdtrAgtMaps = null;
        if (undrlygCstmrCdtTrfMaps.containsKey("cdtrAgt")) {
            cdtrAgtMaps = (Map<String, Object>) undrlygCstmrCdtTrfMaps.get("cdtrAgt");
        } else {
            cdtrAgtMaps = new HashMap<>();
        }
        Map<String, Object> cdtrAgtAcctMaps = null;
        if (undrlygCstmrCdtTrfMaps.containsKey("cdtrAgtAcct")) {
            cdtrAgtAcctMaps = (Map<String, Object>) undrlygCstmrCdtTrfMaps.get("cdtrAgtAcct");
        } else {
            cdtrAgtAcctMaps = new HashMap<>();
        }
        String account = "";
        if (field57A != null) {
            String bicCode = field57A.getBIC();
            mt_to_mxBICFI(bicCode, cdtrAgtMaps);
            if (StringUtil.isNotEmpty(field57A.getComponent1())) {
                account = "/" + field57A.getComponent1();
            }
            if (StringUtil.isNotEmpty(field57A.getComponent2())) {
                account = "/" + field57A.getComponent2();
            }
            if (account.startsWith("//") && !account.startsWith("//CH") && !account.startsWith("//FW") && !account.startsWith("//RT")) {
                Map<String, Object> finInstnIdMaps = null;
                if (cdtrAgtMaps.containsKey("finInstnId")) {
                    finInstnIdMaps = (Map<String, Object>)cdtrAgtMaps.get("finInstnId");
                } else {
                    finInstnIdMaps = new HashMap<>();
                    cdtrAgtMaps.put("finInstnId", finInstnIdMaps);
                }
                Map<String, Object> clrSysMmbIdMaps = null;
                if (finInstnIdMaps.containsKey("clrSysMmbId")) {
                    clrSysMmbIdMaps = (Map<String, Object>)finInstnIdMaps.get("clrSysMmbId");
                } else {
                    clrSysMmbIdMaps = new HashMap<>();
                    finInstnIdMaps.put("clrSysMmbId", clrSysMmbIdMaps);
                }
                mt_to_mxClearingIdentifier(account, clrSysMmbIdMaps);
            } else if (!account.startsWith("//") || account.startsWith("//CH")) {
                mt_to_mxFinancialInstitutionAccount(account, cdtrAgtAcctMaps);
            }
        } else if (field57B != null) {
            if (StringUtil.isNotEmpty(field57B.getComponent1())) {
                account = "/" + field57B.getComponent1();
            }
            if (StringUtil.isNotEmpty(field57B.getComponent2())) {
                account = "/" + field57B.getComponent2();
            }
            String location = field57B.getLocation();
            Map<String, Object> finInstnIdMaps = null;
            if (cdtrAgtMaps.containsKey("finInstnId")) {
                finInstnIdMaps = (Map<String, Object>)cdtrAgtMaps.get("finInstnId");
            } else {
                finInstnIdMaps = new HashMap<>();
                cdtrAgtMaps.put("finInstnId", finInstnIdMaps);
            }
            if (account.startsWith("//") && !account.startsWith("//CH") && !account.startsWith("//FW")) {
                if (isMTClearingSystemCodeInList(account)) {
                    Map<String, Object> clrSysMmbIdMaps = null;
                    if (finInstnIdMaps.containsKey("clrSysMmbId")) {
                        clrSysMmbIdMaps = (Map<String, Object>)finInstnIdMaps.get("clrSysMmbId");
                    } else {
                        clrSysMmbIdMaps = new HashMap<>();
                        finInstnIdMaps.put("clrSysMmbId", clrSysMmbIdMaps);
                    }
                    mt_to_mxClearingIdentifier(account, clrSysMmbIdMaps);
                    //name address 设置NOTPROVIDED
                    finInstnIdMaps.put("nm", Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE);
                    Map<String, Object> pstlAdrMaps = null;
                    if (finInstnIdMaps.containsKey("pstlAdr")) {
                        pstlAdrMaps = (Map<String, Object>)finInstnIdMaps.get("pstlAdr");
                    } else {
                        pstlAdrMaps = new HashMap<>();
                        finInstnIdMaps.put("pstlAdr", pstlAdrMaps);
                    }
                    List<String> adrLineList = new ArrayList<>();
                    adrLineList.add(StringUtil.isEmpty(location)?Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE:location);
                    pstlAdrMaps.put("adrLine", adrLineList);
                } else {
                    mt_to_mxClearingSystemToNameAndAddressLine(account, location, finInstnIdMaps);
                }
            } else if (!account.startsWith("//") || account.startsWith("//CH")) {
                mt_to_mxFinancialInstitutionAccount(account, cdtrAgtAcctMaps);
                //name address 设置NOTPROVIDED
                finInstnIdMaps.put("nm", Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE);
                Map<String, Object> pstlAdrMaps = null;
                if (finInstnIdMaps.containsKey("pstlAdr")) {
                    pstlAdrMaps = (Map<String, Object>)finInstnIdMaps.get("pstlAdr");
                } else {
                    pstlAdrMaps = new HashMap<>();
                    finInstnIdMaps.put("pstlAdr", pstlAdrMaps);
                }
                List<String> adrLineList = new ArrayList<>();
                adrLineList.add(StringUtil.isEmpty(location)?Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE:location);
                pstlAdrMaps.put("adrLine", adrLineList);
            }
        } else if (field57C != null) {
            account = field57C.getValue();
            Map<String, Object> finInstnIdMaps = null;
            if (cdtrAgtMaps.containsKey("finInstnId")) {
                finInstnIdMaps = (Map<String, Object>)cdtrAgtMaps.get("finInstnId");
            } else {
                finInstnIdMaps = new HashMap<>();
                cdtrAgtMaps.put("finInstnId", finInstnIdMaps);
            }
            if (account.startsWith("//") && !account.startsWith("//CH") && !account.startsWith("//FW")) {
                if (isMTClearingSystemCodeInList(account)) {
                    Map<String, Object> clrSysMmbIdMaps = null;
                    if (finInstnIdMaps.containsKey("clrSysMmbId")) {
                        clrSysMmbIdMaps = (Map<String, Object>)finInstnIdMaps.get("clrSysMmbId");
                    } else {
                        clrSysMmbIdMaps = new HashMap<>();
                        finInstnIdMaps.put("clrSysMmbId", clrSysMmbIdMaps);
                    }
                    mt_to_mxClearingIdentifier(account, clrSysMmbIdMaps);
                    //name address 设置NOTPROVIDED
                    finInstnIdMaps.put("nm", Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE);
                    Map<String, Object> pstlAdrMaps = null;
                    if (finInstnIdMaps.containsKey("pstlAdr")) {
                        pstlAdrMaps = (Map<String, Object>)finInstnIdMaps.get("pstlAdr");
                    } else {
                        pstlAdrMaps = new HashMap<>();
                        finInstnIdMaps.put("pstlAdr", pstlAdrMaps);
                    }
                    List<String> adrLineList = new ArrayList<>();
                    adrLineList.add(Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE);
                    pstlAdrMaps.put("adrLine", adrLineList);
                } else {
                    mt_to_mxClearingSystemToNameAndAddressLine(account, null, finInstnIdMaps);
                }
            } else if (!account.startsWith("//") || account.startsWith("//CH")) {
                mt_to_mxFinancialInstitutionAccount(account, cdtrAgtAcctMaps);
                //name address 设置NOTPROVIDED
                finInstnIdMaps.put("nm", Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE);
                Map<String, Object> pstlAdrMaps = null;
                if (finInstnIdMaps.containsKey("pstlAdr")) {
                    pstlAdrMaps = (Map<String, Object>)finInstnIdMaps.get("pstlAdr");
                } else {
                    pstlAdrMaps = new HashMap<>();
                    finInstnIdMaps.put("pstlAdr", pstlAdrMaps);
                }
                List<String> adrLineList = new ArrayList<>();
                adrLineList.add(Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE);
                pstlAdrMaps.put("adrLine", adrLineList);
            }
        } else if (field57D != null) {
            if (StringUtil.isNotEmpty(field57D.getComponent1())) {
                account = "/" + field57D.getComponent1();
            }
            if (StringUtil.isNotEmpty(field57D.getComponent2())) {
                account = "/" + field57D.getComponent2();
            }
            String nameAddress = field57D.getNameAndAddress();
            mt_to_mxFinancialInstitutionNameAndUnstructuredAddress(nameAddress, cdtrAgtMaps);
            if (account.startsWith("//") && !account.startsWith("//CH") && !account.startsWith("//FW")) {
                Map<String, Object> finInstnIdMaps = null;
                if (cdtrAgtMaps.containsKey("finInstnId")) {
                    finInstnIdMaps = (Map<String, Object>)cdtrAgtMaps.get("finInstnId");
                } else {
                    finInstnIdMaps = new HashMap<>();
                    cdtrAgtMaps.put("finInstnId", finInstnIdMaps);
                }
                Map<String, Object> clrSysMmbIdMaps = null;
                if (finInstnIdMaps.containsKey("clrSysMmbId")) {
                    clrSysMmbIdMaps = (Map<String, Object>)finInstnIdMaps.get("clrSysMmbId");
                } else {
                    clrSysMmbIdMaps = new HashMap<>();
                    finInstnIdMaps.put("clrSysMmbId", clrSysMmbIdMaps);
                }
                mt_to_mxClearingIdentifier(account, clrSysMmbIdMaps);
            } else if (!account.startsWith("//") || account.startsWith("//CH")) {
                mt_to_mxFinancialInstitutionAccount(account, cdtrAgtAcctMaps);
            }
        }
        if (cdtrAgtMaps.size() > 0) {
            undrlygCstmrCdtTrfMaps.put("cdtrAgt", cdtrAgtMaps);
        }
        if (cdtrAgtAcctMaps.size() > 0) {
            undrlygCstmrCdtTrfMaps.put("cdtrAgtAcct", cdtrAgtAcctMaps);
        }
    }
}
