package com.brilliance.swift.mt2mx.pacs009001.impl;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2mx.pacs009001.AbstractMt2MxPacs009001ParseField;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.VoSettlementMethodHelper;
import com.prowidesoftware.swift.model.Tag;
import com.prowidesoftware.swift.model.field.Field53A;
import com.prowidesoftware.swift.model.field.Field53B;
import com.prowidesoftware.swift.model.field.Field53D;
import com.prowidesoftware.swift.model.mt.AbstractMT;

import java.util.HashMap;
import java.util.Map;

/**
 * Group Header -> Settlement Information -> Settlement Account
 */
public class Pacs009001ParseSetlAcctField extends AbstractMt2MxPacs009001ParseField {

    private static final String NAME_A = "53A";

    private static final String NAME_B = "53B";

    private static final String NAME_D = "53D";

    @Override
    public void parseField() throws SwiftException {
        //值来源于 Pacs00801ParseSetlMtdField
        VoSettlementMethodHelper setlMtdHelper = context.get(VoSettlementMethodHelper.class);
        if (setlMtdHelper.isTranslateSetlAcctFlag()) {
            Field53A field53A = null;
            Field53B field53B = null;
            Field53D field53D = null;
            AbstractMT abstractMT = context.get(AbstractMT.class);
            Tag tag = abstractMT.getSwiftMessage().getBlock4().getTagByName(NAME_A);
            if (tag != null) {
                field53A = (Field53A)tag.asField();
            }
            tag = abstractMT.getSwiftMessage().getBlock4().getTagByName(NAME_B);
            if (tag != null) {
                field53B = (Field53B) tag.asField();
            }
            tag = abstractMT.getSwiftMessage().getBlock4().getTagByName(NAME_D);
            if (tag != null) {
                field53D = (Field53D)tag.asField();
            }
            String account = "";
            if (field53A != null) {
                if (StringUtil.isNotEmpty(field53A.getComponent1())) {
                    account += "/" + field53A.getComponent1();
                }
                if (StringUtil.isNotEmpty(field53A.getComponent2())) {
                    account += "/" + field53A.getComponent2();
                }
            } else if (field53B != null) {
                if (StringUtil.isNotEmpty(field53B.getComponent1())) {
                    account += "/" + field53B.getComponent1();
                }
                if (StringUtil.isNotEmpty(field53B.getComponent2())) {
                    account += "/" + field53B.getComponent2();
                }
            } else if (field53D != null) {
                if (StringUtil.isNotEmpty(field53D.getComponent1())) {
                    account += "/" + field53D.getComponent1();
                }
                if (StringUtil.isNotEmpty(field53D.getComponent2())) {
                    account += "/" + field53D.getComponent2();
                }
            }
            if (StringUtil.isEmpty(account)) return;
            Map<String, Object> sttlmInfMaps = null;
            if (grpHdrMaps.containsKey("sttlmInf")) {
                sttlmInfMaps = (Map<String, Object>) grpHdrMaps.get("sttlmInf");
            } else {
                sttlmInfMaps = new HashMap<>();
                grpHdrMaps.put("sttlmInf", sttlmInfMaps);
            }
            Map<String, Object> sttlmAcctMaps = null;
            if (sttlmInfMaps.containsKey("sttlmAcct")) {
                sttlmAcctMaps = (Map<String, Object>)sttlmInfMaps.get("sttlmAcct");
            } else {
                sttlmAcctMaps = new HashMap<>();
                sttlmInfMaps.put("sttlmAcct", sttlmAcctMaps);
            }
            mt_to_mxFinancialInstitutionAccount(account, sttlmAcctMaps);
        }
    }
}
