package com.brilliance.swift.mx2map;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.util.StringUtil;

import java.util.Map;
import java.util.Set;

public class DefaultMx2MapCreator extends AbstractMx2MapCreator{

    @Override
    public Map<String, String> mx2Map() throws SwiftException {
        String gsonStr = abstractMX.toJson();
        Map<String, Object> mxGsonMaps = JSON.parseObject(gsonStr);
        parseMxGsonMap(maps, mxGsonMaps, null);
        return maps;
    }

    /**
     * 把mxGsonMaps解析成Map<String, String>，回调函数然后拼接前缀
     * @param maps
     * @param mxGsonMaps
     * @param prefix
     */
    public void parseMxGsonMap(Map<String, String> maps, Map<String, Object> mxGsonMaps, String prefix) {
        Set<String> keys = mxGsonMaps.keySet();
        for (String key : keys) {
            Object object = (Object)mxGsonMaps.get(key);
            if (object == null) continue;
            if (object instanceof JSONArray) {
                if (StringUtil.isEmpty(prefix)) {
                    parseMxGsonArray(maps, (JSONArray)object, key);
                } else {
                    parseMxGsonArray(maps, (JSONArray)object, prefix + "." + key);
                }
            } else if (object instanceof JSONObject) {
                if (StringUtil.isEmpty(prefix)) {
                    parseMxGsonMap(maps, (Map<String, Object>)object, key);
                } else {
                    parseMxGsonMap(maps, (Map<String, Object>)object, prefix + "." + key);
                }
            } else {
                if (StringUtil.isEmpty(prefix)) {
                    maps.put(key, String.valueOf(object));
                } else {
                    maps.put(prefix + "." + key, String.valueOf(object));
                }
            }
        }
    }

    /**
     * jsonArray 是json数组格式 回调函数
     * 如果长度只有1，那么就不需要下标
     * 否则需要下标(0) (1) (2) (3)
     * @param maps
     * @param jsonArray
     * @param prefix
     */
    public void parseMxGsonArray(Map<String, String> maps, JSONArray jsonArray, String prefix) {
        Object[] jsonArrays = jsonArray.toArray();
        if (jsonArrays.length == 1) {
            Object object = jsonArrays[0];
            if (object instanceof JSONArray) {
                parseMxGsonArray(maps, (JSONArray)object, prefix);
            } else if (object instanceof JSONObject) {
                parseMxGsonMap(maps, (Map<String, Object>)object, prefix);
            } else {
                maps.put(prefix, String.valueOf(object));
            }
        } else {
            for (int i=0; i<jsonArrays.length; i++) {
                Object object = jsonArrays[i];
                if (object instanceof JSONArray) {
                    parseMxGsonArray(maps, (JSONArray)object, prefix+"("+i+")");
                } else if (object instanceof JSONObject) {
                    parseMxGsonMap(maps, (Map<String, Object>)object, prefix+"("+i+")");
                } else {
                    maps.put(prefix+"("+i+")", String.valueOf(object));
                }
            }
        }
    }
}
