package com.brilliance.swift.mx2map.camt053;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2map.AbstractMx2MapCreator;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.util.XmlUtil;
import com.brilliance.swift.vo.common.BalanceTypeCode;
import com.brilliance.swift.vo.common.CdtDbtCode;
import org.dom4j.Document;
import org.dom4j.DocumentException;
import org.dom4j.DocumentHelper;

import javax.xml.datatype.XMLGregorianCalendar;
import java.util.Map;

public class Mx2MapCamt053Creator extends AbstractMx2MapCreator {
    @Override
    public Map<String, String> mx2Map() throws SwiftException {
        try {
            Document document = DocumentHelper.parseText(xmlStr);
            Map<String, String> parentElementMaps = XmlUtil.getParentElementMaps(document);
            String appHdrParentElementName = parentElementMaps.get("AppHdr");
            String grpHdrParentElementName = parentElementMaps.get("GrpHdr");
            String bodyParentElementName = parentElementMaps.get("Stmt");
            String sendBic = abstractMX.getAppHdr().from();
            maps.put(getPropertyValue("app.header.sendBic"), sendBic);
            String receiverBic = abstractMX.getAppHdr().to();
            maps.put(getPropertyValue("app.header.receiverBic"), receiverBic);
            String bizMsgId = abstractMX.getAppHdr().reference();
            maps.put(getPropertyValue("app.header.bizMsgId"), bizMsgId);
            String msgDefId = abstractMX.getAppHdr().messageName();
            maps.put(getPropertyValue("app.header.msgDefId"), msgDefId);
            String bizSvc = abstractMX.getAppHdr().serviceName();
            maps.put(getPropertyValue("app.header.bizSvc"), bizSvc);
            XMLGregorianCalendar creDt = abstractMX.getAppHdr().creationDate();
            maps.put(getPropertyValue("app.header.creDt"), creDt.toXMLFormat());
            String statementId = XmlUtil.getXmlNodeValue(document, bodyParentElementName + ".Stmt.Id");
            maps.put(getPropertyValue("statement.id"), statementId);
            String iban = XmlUtil.getXmlNodeValue(document, bodyParentElementName + ".Stmt.Acct.Id.IBAN");
            String acctId = XmlUtil.getXmlNodeValue(document, bodyParentElementName + ".Stmt.Acct.Id.Othr.Id");
            String account = StringUtil.isNotEmpty(iban) ? iban : acctId;
            if (StringUtil.isNotEmpty(account)) {
                maps.put(getPropertyValue("statement.account"), account);
            }
            String elctrncSeqNb = XmlUtil.getXmlNodeValue(document, bodyParentElementName + ".Stmt.LglSeqNb");
            if (StringUtil.isEmpty(elctrncSeqNb) || elctrncSeqNb.length() > 5) {
                elctrncSeqNb = XmlUtil.getXmlNodeValue(document, bodyParentElementName + ".Stmt.ElctrncSeqNb");
            }
            if (StringUtil.isNotEmpty(elctrncSeqNb)) {
                maps.put(getPropertyValue("statement.sequence.number"), elctrncSeqNb);
            }
            String pageNumber = XmlUtil.getXmlNodeValue(document, bodyParentElementName + ".Stmt.StmtPgntn.PgNb");
            if (StringUtil.isNotEmpty(pageNumber)){
                maps.put(getPropertyValue("statement.page.number"), pageNumber);
            }
            int opbdIndex = -1;
            int clbdIndex = -1;
            int balanceCount = XmlUtil.getChildrenCount(document, bodyParentElementName + ".Stmt.Bal", null);
            if (balanceCount > 0) {
                for (int i=0; i<balanceCount; i++) {
                    String balanceType = XmlUtil.getXmlNodeValue(document, bodyParentElementName + ".Stmt.Bal("+i+").Tp.CdOrPrtry.Cd");
                    if (BalanceTypeCode.OPBD.value().equals(balanceType)) {
                        opbdIndex = i;
                    }
                    if (BalanceTypeCode.CLBD.value().equals(balanceType)) {
                        clbdIndex = i;
                    }
                }
            }
            if (opbdIndex > -1) {
                String cdtDbtInd = XmlUtil.getXmlNodeValue(document, bodyParentElementName+ ".Stmt.Bal("+opbdIndex+").CdtDbtInd");
                if (CdtDbtCode.CRDT.value().equals(cdtDbtInd)) {
                   maps.put(Mx2MtConstants.NEW_LINE + getPropertyValue("statement.openingBooked.crdr"), getPropertyValue("credit"));
                } else {//if (CdtDbtCode.DBIT.value().equals(cdtDbtInd)) {
                    maps.put(Mx2MtConstants.NEW_LINE + getPropertyValue("statement.openingBooked.crdr"), getPropertyValue("debit"));
                }
                String dateStr = XmlUtil.getXmlNodeValue(document, bodyParentElementName + ".Stmt.Bal("+opbdIndex+").Dt.Dt");
                if (StringUtil.isNotEmpty(dateStr)) {
                    maps.put(getPropertyValue("statement.openingBooked.date"), dateStr);
                }
                String ccy = XmlUtil.getXmlNodeValue(document, bodyParentElementName + ".Stmt.Bal("+opbdIndex+").Amt@Ccy");
                if (StringUtil.isNotEmpty(ccy)) {
                    maps.put(getPropertyValue("statement.openingBooked.ccy"), ccy);
                }
                String amt = XmlUtil.getXmlNodeValue(document, bodyParentElementName + ".Stmt.Bal("+opbdIndex+").Amt");
                if (StringUtil.isNotEmpty(amt)) {
                    maps.put(getPropertyValue("statement.openingBooked.amt"), amt);
                }
            }
            int entryCount = XmlUtil.getChildrenCount(document, bodyParentElementName + ".Stmt.Ntry", null);
            if (entryCount > 0) {
                for (int i=0; i<entryCount; i++) {
                    String reversalIndicator = XmlUtil.getXmlNodeValue(document, bodyParentElementName + ".Stmt.Ntry("+i+").RvslInd");
                    String creditDebitIndicator = XmlUtil.getXmlNodeValue(document, bodyParentElementName + ".Stmt.Ntry("+i+").CdtDbtInd");
                    if (StringUtil.isNotEmpty(reversalIndicator) && Boolean.valueOf(reversalIndicator)) {
                        if (CdtDbtCode.DBIT.value().equals(creditDebitIndicator)) {
                            maps.put(Mx2MtConstants.NEW_LINE + getPropertyValue("statement.entry.crdr")+"("+(i+1)+")", getPropertyValue("reversal.credit"));
                        } else {
                            maps.put(Mx2MtConstants.NEW_LINE + getPropertyValue("statement.entry.crdr")+"("+(i+1)+")", getPropertyValue("reversal.debit"));
                        }
                    } else {
                        if (CdtDbtCode.DBIT.value().equals(creditDebitIndicator)) {
                            maps.put(Mx2MtConstants.NEW_LINE + getPropertyValue("statement.entry.crdr")+"("+(i+1)+")", getPropertyValue("debit"));
                        } else {
                            maps.put(Mx2MtConstants.NEW_LINE + getPropertyValue("statement.entry.crdr")+"("+(i+1)+")", getPropertyValue("credit"));
                        }
                    }
                    String valueDateStr = XmlUtil.getXmlNodeValue(document, bodyParentElementName + ".Stmt.Ntry("+i+").ValDt.Dt");
                    if (StringUtil.isNotEmpty(valueDateStr)) {
                        maps.put(getPropertyValue("statement.entry.valueDate")+"("+(i+1)+")", valueDateStr);
                    }
                    String amt = XmlUtil.getXmlNodeValue(document, bodyParentElementName + ".Stmt.Ntry("+i+").Amt");
                    String ccy = XmlUtil.getXmlNodeValue(document, bodyParentElementName + ".Stmt.Ntry("+i+").Amt@Ccy");
                    if (StringUtil.isNotEmpty(ccy)) {
                        maps.put(getPropertyValue("statement.entry.ccy")+"("+(i+1)+")", ccy);
                    }
                    if (StringUtil.isNotEmpty(amt)) {
                        maps.put(getPropertyValue("statement.entry.amt")+"("+(i+1)+")", amt);
                    }
                    String endToEndId = XmlUtil.getXmlNodeValue(document, bodyParentElementName + ".Stmt.Ntry("+i+").NtryDtls.TxDtls.Refs.EndToEndId");
                    if (StringUtil.isNotEmpty(endToEndId)) {
                        maps.put(getPropertyValue("statement.entry.endToEndId")+"("+(i+1)+")", endToEndId);
                    }
                }
            }
            if (clbdIndex > -1) {
                String cdtDbtInd = XmlUtil.getXmlNodeValue(document, bodyParentElementName+ ".Stmt.Bal("+clbdIndex+").CdtDbtInd");
                if (CdtDbtCode.CRDT.value().equals(cdtDbtInd)) {
                    maps.put(Mx2MtConstants.NEW_LINE + getPropertyValue("statement.closingBooked.crdr"), getPropertyValue("credit"));
                } else {//if (CdtDbtCode.DBIT.value().equals(cdtDbtInd)) {
                    maps.put(Mx2MtConstants.NEW_LINE + getPropertyValue("statement.closingBooked.crdr"), getPropertyValue("debit"));
                }
                String dateStr = XmlUtil.getXmlNodeValue(document, bodyParentElementName + ".Stmt.Bal("+clbdIndex+").Dt.Dt");
                if (StringUtil.isNotEmpty(dateStr)) {
                    maps.put(getPropertyValue("statement.closingBooked.date"), dateStr);
                }
                String ccy = XmlUtil.getXmlNodeValue(document, bodyParentElementName + ".Stmt.Bal("+clbdIndex+").Amt@Ccy");
                if (StringUtil.isNotEmpty(ccy)) {
                    maps.put(getPropertyValue("statement.closingBooked.ccy"), ccy);
                }
                String amt = XmlUtil.getXmlNodeValue(document, bodyParentElementName + ".Stmt.Bal("+clbdIndex+").Amt");
                if (StringUtil.isNotEmpty(amt)) {
                    maps.put(getPropertyValue("statement.closingBooked.amt"), amt);
                }
            }
        } catch (DocumentException e) {
            throw new SwiftException("ERROR", e.getMessage());
        }
        return maps;
    }
}
