package com.brilliance.swift.mx2map.pacs008;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2map.AbstractMx2MapCreator;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.util.XmlUtil;
import org.dom4j.Document;
import org.dom4j.DocumentException;
import org.dom4j.DocumentHelper;

import javax.xml.datatype.XMLGregorianCalendar;
import java.util.Map;

public class Mx2MapPacs008Creator extends AbstractMx2MapCreator {
    @Override
    public Map<String, String> mx2Map() throws SwiftException {
        try {
            Document document = DocumentHelper.parseText(xmlStr);
            Map<String, String> parentElementMaps = XmlUtil.getParentElementMaps(document);
            String appHdrParentElementName = parentElementMaps.get("AppHdr");
            String grpHdrParentElementName = parentElementMaps.get("GrpHdr");
            String cdtTrfTxInfParentElementName = parentElementMaps.get("cdtTrfTxInf");
            String sendBic = abstractMX.getAppHdr().from();
            maps.put(getPropertyValue("app.header.sendBic"), sendBic);
            String receiverBic = abstractMX.getAppHdr().to();
            maps.put(getPropertyValue("app.header.receiverBic"), receiverBic);
            String bizMsgId = abstractMX.getAppHdr().reference();
            maps.put(getPropertyValue("app.header.bizMsgId"), bizMsgId);
            String msgDefId = abstractMX.getAppHdr().messageName();
            maps.put(getPropertyValue("app.header.msgDefId"), msgDefId);
            String bizSvc = abstractMX.getAppHdr().serviceName();
            maps.put(getPropertyValue("app.header.bizSvc"), bizSvc);
            XMLGregorianCalendar creDt = abstractMX.getAppHdr().creationDate();
            maps.put(getPropertyValue("app.header.creDt"), creDt.toXMLFormat());

            String messageId = XmlUtil.getXmlNodeValue(document, cdtTrfTxInfParentElementName + ".CdtTrfTxInf.PmtId.InstrId");
            if (StringUtil.isEmpty(messageId)) {
                messageId = XmlUtil.getXmlNodeValue(document, grpHdrParentElementName + ".GrpHdr.MsgId");
            }
            if (StringUtil.isEmpty(messageId)) {
                messageId = abstractMX.getAppHdr().reference();
            }
            maps.put(getPropertyValue("message.id"), messageId);
            String endToEndId = XmlUtil.getXmlNodeValue(document, cdtTrfTxInfParentElementName + ".CdtTrfTxInf.PmtId.EndToEndId");
            maps.put(getPropertyValue("endToEnd.id"), endToEndId);
            String uetr = XmlUtil.getXmlNodeValue(document, cdtTrfTxInfParentElementName + ".CdtTrfTxInf.PmtId.uetr");
            if (StringUtil.isNotEmpty(uetr)) {
                maps.put(getPropertyValue("uetr"), uetr);
            }
        } catch (DocumentException e) {
            throw new SwiftException("ERROR", e.getMessage());
        }
        return maps;
    }
}
