package com.brilliance.swift.mx2mt;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.util.*;
import com.brilliance.swift.vo.MxMtReasonCodeInfo;
import com.brilliance.swift.vo.common.*;
import org.dom4j.Document;

import javax.xml.datatype.DatatypeFactory;
import javax.xml.datatype.XMLGregorianCalendar;
import java.math.BigDecimal;
import java.text.ParseException;
import java.util.*;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public abstract class AbstractMx2MtTagsGenerate implements Mx2MtTagsGenerate {

    protected Mx2MtContext context;

    protected Document document = null;

    protected String appHdrParentElementName;

    protected String grpHdrParentElementName;

    protected String bodyHdrParentElementName;

    public Mx2MtContext getContext() {
        return context;
    }

    public AbstractMx2MtTagsGenerate setContext(Mx2MtContext context) {
        this.context = context;
        document = (Document) context.get(Mx2MtContextIdentifier.MX_XMl_DOCUMENT, true);
        appHdrParentElementName = (String) context.get(Mx2MtContextIdentifier.APPHDR_PARENT_ELEMENT_NAME, true);
        grpHdrParentElementName = (String) context.get(Mx2MtContextIdentifier.GRPHDR_PARENT_ELEMENT_NAME, true);
        bodyHdrParentElementName = (String) context.get(Mx2MtContextIdentifier.BODY_PARENT_ELEMENT_NAME, true);
        return this;
    }

    protected String getXmlNodeValue(String parentPath, Document document, String path) {
        if (StringUtil.isNotEmpty(parentPath)) {
            path = parentPath + "." + path;
        }
        return XmlUtil.getXmlNodeValue(document, path);
    }

    protected int getXmlNodeCounts(String parentPath, Document document, String path) {
        if (StringUtil.isNotEmpty(parentPath)) {
            path = parentPath + "." + path;
        }
        return XmlUtil.getChildrenCount(document, path, null);
    }

    //转换函数方法区开始
    /**
     * MX InstructionForCreditorAgent转23域
     * 前提就是code在{HOLD,CHQB,PHOB,TELB}里面
     * @return
     */
    protected List<String> mx_to_mt23E(String code, String instructionInformation) {
        List<String> list = new ArrayList<>();
        String chqbCode = ExternalCreditorAgentInstructionCode.CHQB.value();
        String holdCode = ExternalCreditorAgentInstructionCode.HOLD.value();
        String phobCode = ExternalCreditorAgentInstructionCode.PHOB.value();
        String telbCode = ExternalCreditorAgentInstructionCode.TELB.value();
        if (!chqbCode.equals(code) && !holdCode.equals(code) && !phobCode.equals(code) && !telbCode.equals(code)) {
            return list;
        }
        if (StringUtil.isEmpty(instructionInformation)) {
            list.add(code);
        } else {
            int firstIndexOf = -1;
            int lastIndexOf = -1;
            if (instructionInformation.indexOf("/"+chqbCode+"/") > -1) {
                String tmpCode = chqbCode;
                String tmpCodeText = "";
                firstIndexOf = instructionInformation.indexOf("/"+chqbCode+"/");
                lastIndexOf = instructionInformation.substring(firstIndexOf + 6).indexOf("/"+holdCode+"/");
                if (lastIndexOf == -1) {
                    lastIndexOf = instructionInformation.substring(firstIndexOf + 6).indexOf("/"+phobCode+"/");
                }
                if (lastIndexOf == -1) {
                    lastIndexOf = instructionInformation.substring(firstIndexOf + 6).indexOf("/"+telbCode+"/");
                }
                if (lastIndexOf == -1) {
                    tmpCodeText = instructionInformation.substring(firstIndexOf + 6);
                } else {
                    tmpCodeText = instructionInformation.substring(firstIndexOf + 6, lastIndexOf);
                }
                list.add(tmpCode);
                String remainTxt = instructionInformation.replace("/"+chqbCode+"/"+tmpCodeText, "");
                if (remainTxt.length() > 30) remainTxt = remainTxt.substring(0, 29) + "+";
                if (chqbCode.equals(code)) {
                    list.add(code);
                } else {
                    list.add(code + "/" + remainTxt);
                }
            } else if (instructionInformation.indexOf("/"+holdCode+"/") > -1) {
                String tmpCode = holdCode;
                String tmpCodeText = "";
                firstIndexOf = instructionInformation.indexOf("/"+holdCode+"/");
                lastIndexOf = instructionInformation.substring(firstIndexOf + 6).indexOf("/"+chqbCode+"/");
                if (lastIndexOf == -1) {
                    lastIndexOf = instructionInformation.substring(firstIndexOf + 6).indexOf("/"+phobCode+"/");
                }
                if (lastIndexOf == -1) {
                    lastIndexOf = instructionInformation.substring(firstIndexOf + 6).indexOf("/"+telbCode+"/");
                }
                if (lastIndexOf == -1) {
                    tmpCodeText = instructionInformation.substring(firstIndexOf + 6);
                } else {
                    tmpCodeText = instructionInformation.substring(firstIndexOf + 6, lastIndexOf);
                }
                String remainTxt = instructionInformation.replace("/"+holdCode+"/"+tmpCodeText, "");
                if (tmpCodeText.length() > 30) tmpCodeText = tmpCodeText.substring(0, 29) + "+";
                list.add(tmpCode+"/"+tmpCodeText);
                if (remainTxt.length() > 30) remainTxt = remainTxt.substring(0, 29) + "+";
                if (chqbCode.equals(code)) {
                    list.add(code);
                } else {
                    list.add(code + "/" + remainTxt);
                }
            } else if (instructionInformation.indexOf("/"+phobCode+"/") > -1) {
                String tmpCode = phobCode;
                String tmpCodeText = "";
                firstIndexOf = instructionInformation.indexOf("/"+phobCode+"/");
                lastIndexOf = instructionInformation.substring(firstIndexOf + 6).indexOf("/"+chqbCode+"/");
                if (lastIndexOf == -1) {
                    lastIndexOf = instructionInformation.substring(firstIndexOf + 6).indexOf("/"+holdCode+"/");
                }
                if (lastIndexOf == -1) {
                    lastIndexOf = instructionInformation.substring(firstIndexOf + 6).indexOf("/"+telbCode+"/");
                }
                if (lastIndexOf == -1) {
                    tmpCodeText = instructionInformation.substring(firstIndexOf + 6);
                } else {
                    tmpCodeText = instructionInformation.substring(firstIndexOf + 6, lastIndexOf);
                }
                list.add(tmpCode);
                String remainTxt = instructionInformation.replace("/"+phobCode+"/"+tmpCodeText, "");
                if (remainTxt.length() > 30) remainTxt = remainTxt.substring(0, 29) + "+";
                if (chqbCode.equals(code)) {
                    list.add(code);
                } else {
                    list.add(code + "/" + remainTxt);
                }
            } else if (instructionInformation.indexOf("/"+telbCode+"/") > -1) {
                String tmpCode = telbCode;
                String tmpCodeText = "";
                firstIndexOf = instructionInformation.indexOf("/"+telbCode+"/");
                lastIndexOf = instructionInformation.substring(firstIndexOf + 6).indexOf("/"+chqbCode+"/");
                if (lastIndexOf == -1) {
                    lastIndexOf = instructionInformation.substring(firstIndexOf + 6).indexOf("/"+holdCode+"/");
                }
                if (lastIndexOf == -1) {
                    lastIndexOf = instructionInformation.substring(firstIndexOf + 6).indexOf("/"+phobCode+"/");
                }
                if (lastIndexOf == -1) {
                    tmpCodeText = instructionInformation.substring(firstIndexOf + 6);
                } else {
                    tmpCodeText = instructionInformation.substring(firstIndexOf + 6, lastIndexOf);
                }
                list.add(tmpCode);
                String remainTxt = instructionInformation.replace("/"+telbCode+"/"+tmpCodeText, "");
                if (remainTxt.length() > 30) remainTxt = remainTxt.substring(0, 29) + "+";
                if (chqbCode.equals(code)) {
                    list.add(code);
                } else {
                    list.add(code + "/" + remainTxt);
                }
            }
        }
        return list;
    }


    /**
     * MX InstructionForCreditorAgent转23域
     * 前提就是code不存在，只有instructionInformation
     * @return
     */
    protected List<String> mx_to_mt23E_BIS(String instructionInformation) {
        List<String> list = new ArrayList<>();
        String chqbCode = ExternalCreditorAgentInstructionCode.CHQB.value();
        String holdCode = ExternalCreditorAgentInstructionCode.HOLD.value();
        String phobCode = ExternalCreditorAgentInstructionCode.PHOB.value();
        String telbCode = ExternalCreditorAgentInstructionCode.TELB.value();
        int chqbCodeIndex = instructionInformation.indexOf("/"+chqbCode+"/");
        if (chqbCodeIndex > -1) {
            /*int firstIndex = chqbCodeIndex + 6;
            int lastIndexOf = instructionInformation.substring(firstIndex).indexOf("/"+holdCode+"/");
            if (lastIndexOf == -1) {
                lastIndexOf = instructionInformation.substring(firstIndex).indexOf("/"+phobCode+"/");
            }
            if (lastIndexOf == -1) {
                lastIndexOf = instructionInformation.substring(firstIndex).indexOf("/"+telbCode+"/");
            }*/
            list.add(chqbCode);
        }
        int holdCodeIndex = instructionInformation.indexOf("/"+holdCode+"/");
        if (holdCodeIndex > -1) {
            int firstIndex = holdCodeIndex + 6;
            int lastIndexOf = instructionInformation.substring(firstIndex).indexOf("/"+phobCode+"/");
            if (lastIndexOf == -1) {
                lastIndexOf = instructionInformation.substring(firstIndex).indexOf("/"+telbCode+"/");
            }
            String codeText = "";
            if (lastIndexOf == -1) {
                codeText = instructionInformation.substring(firstIndex);
            } else {
                codeText = instructionInformation.substring(firstIndex, lastIndexOf);
            }
            if (codeText.length() > 30) codeText = codeText.substring(0, 29) + "+";
            list.add(holdCode + "/" + codeText);
        }
        int phobCodeIndex = instructionInformation.indexOf("/"+phobCode+"/");
        if (phobCodeIndex > -1) {
            int firstIndex = phobCodeIndex + 6;
            int lastIndexOf = instructionInformation.substring(firstIndex).indexOf("/"+telbCode+"/");
            String codeText = "";
            if (lastIndexOf == -1) {
                codeText = instructionInformation.substring(firstIndex);
            } else {
                codeText = instructionInformation.substring(firstIndex, lastIndexOf);
            }
            if (codeText.length() > 30) codeText = codeText.substring(0, 29) + "+";
            list.add(phobCode + "/" + codeText);
        }
        int telbCodeIndex = instructionInformation.indexOf("/"+telbCode+"/");
        if (telbCodeIndex > -1) {
            int firstIndex = phobCodeIndex + 6;
            String codeText = instructionInformation.substring(firstIndex);
            if (codeText.length() > 30) codeText = codeText.substring(0, 29) + "+";
            list.add(telbCode + "/" + codeText);
        }
        return list;
    }
    /**
     * 返回代理行下面的bicCode
     * @param agtPath
     * @return
     */
    protected String mx_to_mtBICFI(String agtPath) {
        String bicCode = XmlUtil.getXmlNodeValue(document, agtPath + ".FinInstnId.BICFI");
        return bicCode;
    }
    /**
     * 返回账号行下面的bicCode
     * @param partyPath
     * @return
     */
    protected String mx_to_mtAnyBIC(String partyPath) {
        String bicCode = XmlUtil.getXmlNodeValue(document, partyPath + ".Id.OrgId.AnyBIC");
        return bicCode;
    }
    /**
     *
     * @param settlementMethod
     * @param accountPath
     * @return
     */
    protected String mx_to_mtSettlementAccount(String settlementMethod, String accountPath) {
        String mtAccount = mx_to_mtAccount(accountPath);
        if (StringUtil.isNotEmpty(mtAccount) && SettlementMethodCode.INGA.value().equals(settlementMethod)) {
            mtAccount = "/C" + mtAccount;
        }
        return mtAccount;
    }
    /**
     * 如果CashAccount38.Id.iban有值，account = "/" + CashAccount38.Id.iban
     *    否则 如果CashAccount38.Id.Othr.Id有值，
     *                      如果CashAccount38.Id.Othr.SchmeNm.Cd = CUID 并且 CashAccount38.Id.Othr.Id长度等于6
     *                account = "//CH" + CashAccount38.Id.Othr.Id
     *            否则 account = "/" + CashAccount38.Id.Othr.Id
     * @param accountPath
     * @return
     */
    protected String mx_to_mtAccount(String accountPath) {
        String mtAccount = "";
        String ibanAcct = XmlUtil.getXmlNodeValue(document, accountPath + ".Id.IBAN");
        if (StringUtil.isNotEmpty(ibanAcct)) {
            mtAccount = "/" +  ibanAcct;
        } else {
            String account = XmlUtil.getXmlNodeValue(document, accountPath + ".Id.Othr.Id");
            if (StringUtil.isNotEmpty(account)) {
                String schemeNameType = XmlUtil.getXmlNodeValue(document, accountPath + ".Id.Othr.SchmeNm.Cd");
                if (AcctSehemeTypeCode.CUID.value().equals(schemeNameType) && account.length() == 6) {
                    mtAccount = "//CH" + account;
                } else {
                    mtAccount = "/" + account;
                }
            }
        }
        return mtAccount;
    }

    /**
     * 清算代码逻辑取值，MX_To_MTClearingIdentifier(ClearingSystemMemberIdentification2，BIC)
     * MTClearingSystem取值
     * 1.如果ClearingSystemMemberIdentification2.ClrSysId.Cd能mapping到MT的clearingSystemCode，则取MTClearingSystemCode，否则MTClearingSystemCode直接取ClearingSystemMemberIdentification2.ClrSysId.Cd
     * MTClearingSystem = //+MTClearingSystemCode + ClearingSystemMemberIdentification2.MmbId
     * （MTClearingSytemCode和MXClearingSystemCode Mapping规则参考word文档Annex章节）
     * 2.如果BIC存在，MTClearingSystem包含FW，最终取值为//FW
     *   如果BIC存在，MTClearingSystem包含CP或者RU或者SW，最终取值为空
     * 3.如果BIC不存在，最终取值就是MTClearingSystem
     * @return
     */
    protected String mx_to_mtClearingIdentifier(String agtPath) {
        String mxClearingSystemCode = XmlUtil.getXmlNodeValue(document, agtPath + ".FinInstnId.ClrSysMmbId.ClrSysId.Cd");
        if (StringUtil.isEmpty(mxClearingSystemCode)) {
            return null;
        }
        String mtClearingSystem = "";
        String mxClearingSystemId = XmlUtil.getXmlNodeValue(document, agtPath + ".FinInstnId.ClrSysMmbId.MmbId");
        ClearingSystemMemberCode clearingSystemMemberCode = SwiftTransferUtil.getClsSysMemberByValue(mxClearingSystemCode);
        if (clearingSystemMemberCode != null) {
            mtClearingSystem = "//" + clearingSystemMemberCode.desc() + mxClearingSystemId;
        } else {
            mtClearingSystem = "//" + mxClearingSystemCode + mxClearingSystemId;
        }
        String bicCode = mx_to_mtBICFI(agtPath);
        if (StringUtil.isNotEmpty(bicCode)) {
            if (mtClearingSystem.indexOf("FW") > -1) {
                mtClearingSystem = "//FW";
            } else if (mtClearingSystem.indexOf("CP") > -1
                    || mtClearingSystem.indexOf("RU") > -1
                    || mtClearingSystem.indexOf("SW") > -1) {
                mtClearingSystem = "";
            }
        }
        return mtClearingSystem;
    }

    /**
     * MX_To_MTClearingIdentifierAndChannel（BranchAndFinancialInstitutionIdentification6 agt）
     * 前提是CdtTrfTxInf.PmtTpInf.ClrChanl = RTGS
     *
     * 1.如果agt.FinInstnId.ClrSysMmbId.ClrSysId.Cd能mapping到MT的clearingSystemCode，则取MTClearingSystemCode，否则MTClearingSystemCode直接取agt.FinInstnId.ClrSysMmbId.ClrSysId.Cd
     * MTClearingSystem = //+MTClearingSystemCode + agt.FinInstnId.ClrSysMmbId.MmbId
     * （MTClearingSytemCode和MXClearingSystemCode Mapping规则参考word文档Annex章节）
     * 2如果agt.FinInstnId.BICFI存在，
     *    如果BIC的5-6位等于US，MTAccount=//FW，如果agt.FinInstnId.ClrSysMmbId.ClrSysId.Cd存在，报T20075警告
     *    否则MTAccount=//RT，如果agt.FinInstnId.ClrSysMmbId.ClrSysId.Cd存在，报T20077警告
     *  如果agt.FinInstnId.BICFI不存在，
     *    MTClearingSystem第3-4包含FW，MTAccount=MTClearingSystem
     *    否则如果MTClearingSystem长度小于32，MTAccount=//RT+MTClearingSystem，否则MTAccount=MTClearingSystem
     * @param agtPath
     * @return
     */
    protected String mx_to_mtClearingIdentifierAndChannel(String agtPath) {
        String clearingChannelCode = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.PmtTpInf.ClrChanl");
        if (!ClearingChannelCode.RTGS.value().equals(clearingChannelCode)) {
            return null;
        }
        String mtClearingSystem = "";
        String mxClearingSystemCode = XmlUtil.getXmlNodeValue(document, agtPath + ".FinInstnId.ClrSysMmbId.ClrSysId.Cd");
        if (StringUtil.isNotEmpty(mxClearingSystemCode)) {
            String mxClearingSystemId = XmlUtil.getXmlNodeValue(document, agtPath + ".FinInstnId.ClrSysMmbId.MmbId");
            ClearingSystemMemberCode clearingSystemMemberCode = SwiftTransferUtil.getClsSysMemberByValue(mxClearingSystemCode);
            if (clearingSystemMemberCode != null) {
                mtClearingSystem = "//" + clearingSystemMemberCode.desc() + mxClearingSystemId;
            } else {
                mtClearingSystem = "//" + mxClearingSystemCode + mxClearingSystemId;
            }
        }
        String mtAccount = "";
        String bicCode = mx_to_mtBICFI(agtPath);
        if (StringUtil.isNotEmpty(bicCode)) {
            if ("US".equals(bicCode.substring(4, 6))) {
                mtAccount = "//FW";
            } else {
                mtAccount = "//RT";
            }
        } else {
            if (mtClearingSystem.indexOf("FW") > -1) {
                mtAccount = mtClearingSystem;
            } else if (mtClearingSystem.length() < 32) {
                mtAccount = "//RT" + mtClearingSystem;
            } else {
                mtAccount = mtClearingSystem;
            }
        }
        return mtAccount;
    }

    /**
     * 无结构性地址的取值规则：MX_To_MTFinancialInstitutionNameAndUnstructuredAddress(AgentObj)
     * addressCount =AgentObj.FinInstnId.PostalAddress.AddressLine
     * 1.先组装Name
     *   Name = AgentObj.FinInstnId.Nm
     *   如果Name.length<1,Name = "NOTPROVIDED"
     *   如果addrescount >= 3，并且Name长度大于35，Name只截取到34位，最后一位用+表示
     *   否则 如果Name长度大于70，Name只截取到69位，最后一位用+表示（表示name Address中name最多占2行）
     * 2.再组装address
     *   address = AgentObj.FinInstnId.PostalAddress.AddressLine(i),如果长度超过35位就截取到35位
     * 3.最后name address 组成 4 *35 格式
     * @param nameAddressPrefixPath  名字和地址的前缀路径
     * @return
     */
    protected String mx_to_mtFinancialInstitutionNameAndUnstructuredAddress(String nameAddressPrefixPath) {
        String mxName = XmlUtil.getXmlNodeValue(document, nameAddressPrefixPath + ".Nm");
        if (StringUtil.isEmpty(mxName)) {
            mxName = Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
        }
        int addressLineCount = XmlUtil.getChildrenCount(document, nameAddressPrefixPath + ".PstlAdr.AdrLine", null);
        if (addressLineCount >= 3) {
            if (mxName.length() > 35) mxName = mxName.substring(0, 34) + "+";
        } else {
            if (mxName.length() > 70) mxName = mxName.substring(0, 69) + "+";
        }
        int addressRemainLine = 3;//address剩余的行数
        if (mxName.length() > 35) addressRemainLine = 2;
        String mtNameAddress = StringUtil.getStringByEnter(mxName, 35, 4-addressRemainLine);
        String mxAddress = "";
        if (addressLineCount > 0) {
            for (int i=0; i<addressLineCount; i++) {
                if (i == addressRemainLine) break;
                mxAddress += XmlUtil.getXmlNodeValue(document, nameAddressPrefixPath + ".PstlAdr.AdrLine("+i+")");
            }
        }
        if (mxAddress.length() > 0) {
            mtNameAddress += Mx2MtConstants.NEW_LINE + StringUtil.getStringByEnter(mxAddress, 35, addressRemainLine);
        }
        return mtNameAddress;
    }

    /**
     * 有结构性地址的取值规则
     * MX_To_MTFinancialInstitutionNameAndStructuredAddress(AgentObj)
     * 前提是AgentObj.FinInstnId.PostalAddress.Ctry有值
     * 1.先组装Name
     *   Name = AgentObj.FinInstnId.Nm
     *   如果Name.length<1,Name = "NOTPROVIDED"
     *   如果Name长度大于70，Name只截取到69位，最后一位用+表示（表示name Address中name最多占2行）
     * 2.再组装address
     *   MXTable2[1] = StreetName（AgentObj.FinInstnId.PstlAdr.StrtNm）
     *   MXTable2[2] = BuildingNumber（AgentObj.FinInstnId.PstlAdr.BldgNb）
     *   MXTable2[3] = BuildingName（AgentObj.FinInstnId.PstlAdr.BldgNm）
     *   MXTable2[4] = Floor（AgentObj.FinInstnId.PstlAdr.Flr）
     *   MXTable2[5] = PostBox（AgentObj.FinInstnId.PstlAdr.PstBx）
     *   MXTable2[6] = Room（AgentObj.FinInstnId.PstlAdr.Room）
     *   MXTable2[7] = Department（AgentObj.FinInstnId.PstlAdr.Dept）
     *   MXTable2[8] = SubDepartment（AgentObj.FinInstnId.PstlAdr.SubDept）
     *   MxAddress2 = MXTable2[1] + "," + MXTable2[2] + "," + ... MXTable2[8]
     *
     *   MXTable3[1] = Country（AgentObj.FinInstnId.PstlAdr.Ctry）
     *   MXTable3[2] = TownName（AgentObj.FinInstnId.PstlAdr.TwnNm）
     *   MXTable3[3] = PostCode（AgentObj.FinInstnId.PstlAdr.PstCd）
     *   MXTable3[4] = CountrySubdivision（AgentObj.FinInstnId.PstlAdr.CtrySubDvsn）
     *   MXTable3[5] = TownNameLocation（AgentObj.FinInstnId.PstlAdr.TwnLctnNm）
     *   MXTable3[6] = DistrictName（AgentObj.FinInstnId.PstlAdr.DstrctNm）
     *   MxAddress3 = MXTable3[1] + "/" + MXTable3[2] + "," + MXTable3[3] + ... + MXTable3[6]
     * 3.NameAddress取值规则 4*35
     *   ①如果Name只占一行，
     *      如果MxAddress2存在，MxAddress3最多占2行，MxAddress2最多占2行；如果MxAddress2不存在，直接取MxAddress3
     *   ②如果Name占2行，
     *      如果MxAddress2存在，MxAddress3和MxAddress2最多占1行；如果MxAddress2不存在，直接取MxAddress3
     *   最后按照规则拼接成4*35
     */
    protected String mx_to_mtFinancialInstitutionNameAndStructuredAddress(String nameAddressPrefixPath, boolean mxLeiFlag) {
        String mtNameAddress = "";
        String mxName = XmlUtil.getXmlNodeValue(document, nameAddressPrefixPath + ".Nm");
        if (StringUtil.isEmpty(mxName)) {
            mxName = Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
        }
        int addressRemainLine = 0;//address剩余的行数
        String mxLei = XmlUtil.getXmlNodeValue(document, nameAddressPrefixPath + ".LEI");
        if (StringUtil.isNotEmpty(mxLei) && mxLeiFlag) {
            if (mxName.length() > 33) mxName = "1/" + mxName.substring(0, 32) + "+";
            mtNameAddress = mxName;
            addressRemainLine = 2;
        } else {
            if (mxName.length() > 66) {
                mtNameAddress = "1/" + mxName.substring(0, 33)
                                + Mx2MtConstants.NEW_LINE
                                + "1/" + mxName.substring(33, 65) + "+";
                addressRemainLine = 2;
            } else if (mxName.length() > 33) {
                mtNameAddress = "1/" + mxName.substring(0, 33)
                                + Mx2MtConstants.NEW_LINE
                                + "1/" + mxName.substring(33);
                addressRemainLine = 2;
            } else {
                mtNameAddress = "1/" + mxName;
                addressRemainLine = 3;
            }
        }
        //组装address
        String country = XmlUtil.getXmlNodeValue(document, nameAddressPrefixPath + ".PstlAdr.Ctry");
        if (StringUtil.isNotEmpty(country)) {
            String mxAddress2 = "";
            String mxAddress2StrtNm = XmlUtil.getXmlNodeValue(document, nameAddressPrefixPath + ".PstlAdr.StrtNm");
            if (StringUtil.isNotEmpty(mxAddress2StrtNm)) {
                mxAddress2 += mxAddress2StrtNm + ",";
            }
            String mxAddress2BldgNb = XmlUtil.getXmlNodeValue(document, nameAddressPrefixPath + ".PstlAdr.BldgNb");
            if (StringUtil.isNotEmpty(mxAddress2BldgNb)) {
                mxAddress2 += mxAddress2BldgNb + ",";
            }
            String mxAddress2BldgNm = XmlUtil.getXmlNodeValue(document, nameAddressPrefixPath + ".PstlAdr.BldgNm");
            if (StringUtil.isNotEmpty(mxAddress2BldgNm)) {
                mxAddress2 += mxAddress2BldgNm + ",";
            }
            String mxAddress2Flr = XmlUtil.getXmlNodeValue(document, nameAddressPrefixPath + ".PstlAdr.Flr");
            if (StringUtil.isNotEmpty(mxAddress2Flr)) {
                mxAddress2 += mxAddress2Flr + ",";
            }
            String mxAddress2PstBx = XmlUtil.getXmlNodeValue(document, nameAddressPrefixPath + ".PstlAdr.PstBx");
            if (StringUtil.isNotEmpty(mxAddress2PstBx)) {
                mxAddress2 += mxAddress2PstBx + ",";
            }
            String mxAddress2Room = XmlUtil.getXmlNodeValue(document, nameAddressPrefixPath + ".PstlAdr.Room");
            if (StringUtil.isNotEmpty(mxAddress2Room)) {
                mxAddress2 += mxAddress2Room + ",";
            }
            String mxAddress2Dept = XmlUtil.getXmlNodeValue(document, nameAddressPrefixPath + ".PstlAdr.Dept");
            if (StringUtil.isNotEmpty(mxAddress2Dept)) {
                mxAddress2 += mxAddress2Dept + ",";
            }
            String mxAddress2SubDept = XmlUtil.getXmlNodeValue(document, nameAddressPrefixPath + ".PstlAdr.SubDept");
            if (StringUtil.isNotEmpty(mxAddress2SubDept)) {
                mxAddress2 += mxAddress2SubDept + ",";
            }
            if (mxAddress2.length() > 0) mxAddress2 = mxAddress2.substring(0, mxAddress2.length()-1);

            String mxAddress3 = country;
            String mxAddress3TwnNm = XmlUtil.getXmlNodeValue(document, nameAddressPrefixPath + ".PstlAdr.TwnNm");
            if (StringUtil.isNotEmpty(mxAddress3TwnNm)) {
                mxAddress3 += "/" + mxAddress3TwnNm;
            }
            String mxAddress3PstCd = XmlUtil.getXmlNodeValue(document, nameAddressPrefixPath + ".PstlAdr.PstCd");
            if (StringUtil.isNotEmpty(mxAddress3PstCd)) {
                mxAddress3 += "," + mxAddress3PstCd;
            }
            String mxAddress3CtrySubDvsn = XmlUtil.getXmlNodeValue(document, nameAddressPrefixPath + ".PstlAdr.CtrySubDvsn");
            if (StringUtil.isNotEmpty(mxAddress3CtrySubDvsn)) {
                mxAddress3 += "," + mxAddress3TwnNm;
            }
            String mxAddress3TwnLctnNm = XmlUtil.getXmlNodeValue(document, nameAddressPrefixPath + ".PstlAdr.TwnLctnNm");
            if (StringUtil.isNotEmpty(mxAddress3TwnLctnNm)) {
                mxAddress3 += "," + mxAddress3TwnLctnNm;
            }
            String mxAddress3DstrctNm = XmlUtil.getXmlNodeValue(document, nameAddressPrefixPath + ".PstlAdr.DstrctNm");
            if (StringUtil.isNotEmpty(mxAddress3DstrctNm)) {
                mxAddress3 += "," + mxAddress3DstrctNm;
            }
            //根据剩余行数来拼接mxAddress2和mxAddress3
            String mtAddress2 = "";
            String mtAddress3 = "";
            if (addressRemainLine == 3) {//表示name只占1行
                if (mxAddress2.length() > 0) { //mxAddress2存在，优先计算mxAddress3长度
                    if (mxAddress3.length() > 66) { //mxAddress3最多占2行 mxaddress2最多占1行
                        mtAddress3 = "3/" + mxAddress3.substring(0, 33)
                                + Mx2MtConstants.NEW_LINE
                                + "3/" + mxAddress3.substring(33, 65) + "+";
                        if (mxAddress2.length() > 33) {
                            mtAddress2 = "2/" + mxAddress2.substring(0, 32) + "+";
                        }
                    } else if (mxAddress3.length() > 33) { //mxAddress3占2行 mxaddress2最多占1行
                        mtAddress3 = "3/" + mxAddress3.substring(0, 33)
                                + Mx2MtConstants.NEW_LINE
                                + "3/" + mxAddress3.substring(33);
                        if (mxAddress2.length() > 33) {
                            mtAddress2 = "2/" + mxAddress2.substring(0, 32) + "+";
                        }
                    } else {//mxAddress3占1行 mxaddress2最多占2行
                        mtAddress3 = "3/" + mxAddress3;
                        if (mxAddress2.length() > 66) {
                            mtAddress2 = "2/" + mxAddress2.substring(0, 33)
                                    + Mx2MtConstants.NEW_LINE
                                    + "2/" + mxAddress2.substring(33, 65) + "+";
                        } else if (mxAddress2.length() > 33) {
                            mtAddress2 = "2/" + mxAddress2.substring(0, 33)
                                    + Mx2MtConstants.NEW_LINE
                                    + "2/" + mxAddress2.substring(33);
                        } else {
                            mtAddress2 = "2/" + mxAddress2;
                        }
                    }
                } else { //mxAddress2不存在，只读取mxAddress3
                    if (mxAddress3.length() > 99) {
                        mtAddress3 = "3/" + mxAddress3.substring(0, 33)
                                    + Mx2MtConstants.NEW_LINE
                                    + "3/" + mxAddress3.substring(33, 66)
                                    + Mx2MtConstants.NEW_LINE
                                    + "3/" + mxAddress3.substring(66, 98) + "+";
                    } else if (mxAddress3.length() > 66) {
                        mtAddress3 = "3/" + mxAddress3.substring(0, 33)
                                   + Mx2MtConstants.NEW_LINE
                                   + "3/" + mxAddress3.substring(33, 66)
                                   + Mx2MtConstants.NEW_LINE
                                   + "3/" + mxAddress3.substring(66);
                    } else if (mxAddress3.length() > 33) {
                        mtAddress3 = "3/" + mxAddress3.substring(0, 33)
                                   + Mx2MtConstants.NEW_LINE
                                   + "3/" + mxAddress3.substring(33);
                    } else {
                        mtAddress3 = "3/" + mxAddress3;
                    }
                }
            } else {  //表示name占了2行
                if (mxAddress2.length() > 0) { //mxAddress2存在，mxaddress2和mxaddress3算一行
                    if (mxAddress2.length() > 33) {
                        mtAddress2 = "2/" + mxAddress2.substring(0, 32) + "+";
                    } else {
                        mtAddress2 = "2/" + mxAddress2;
                    }
                    if (mxAddress3.length() > 33) {
                        mtAddress3 = "3/" + mxAddress3.substring(0, 32) + "+";
                    } else {
                        mtAddress3 = "3/" + mxAddress3;
                    }
                } else { //mxAddress2不存在，只读取mxAddress3
                    if (mxAddress3.length() > 66) {
                        mtAddress3 = "3/" + mxAddress3.substring(0, 33)
                                + Mx2MtConstants.NEW_LINE
                                + "3/" + mxAddress3.substring(33, 66)
                                + Mx2MtConstants.NEW_LINE
                                + "3/" + mxAddress3.substring(66);
                    } else if (mxAddress3.length() > 33) {
                        mtAddress3 = "3/" + mxAddress3.substring(0, 33)
                                + Mx2MtConstants.NEW_LINE
                                + "3/" + mxAddress3.substring(33);
                    } else {
                        mtAddress3 = "3/" + mxAddress3;
                    }
                }
            }
            if (mtAddress2.length() > 0) {
                mtNameAddress += Mx2MtConstants.NEW_LINE + mtAddress2;
            }
            if (mtAddress3.length() > 0) {
                mtNameAddress += Mx2MtConstants.NEW_LINE + mtAddress3;
            }
        }
        return mtNameAddress;
    }

    protected String mx_to_mtPartyNameAndStructuredAddress(String nameAddressPrefixPath) {
        return mx_to_mtFinancialInstitutionNameAndStructuredAddress(nameAddressPrefixPath, true);
    }
    /**
     *
     * @param path
     * @return
     */
    protected String mx_to_mt53A(String path) {
        String bicCode = "";
        int pathCount = XmlUtil.getChildrenCount(document, path, null);
        if (pathCount > 0) {
            String mtInstruction = XmlUtil.getXmlNodeValue(document, path + "(0).InstrInf");
            for (int i=0; i<pathCount; i++) {
                if (i == 0) continue;
                String instrInf = XmlUtil.getXmlNodeValue(document, path + "("+i+").InstrInf");
                if (StringUtil.isNotEmpty(instrInf)) {
                    if (instrInf.length() < 35 && !instrInf.matches("/[A-Z0-9]{1,8}/.*")) {
                        mtInstruction += "/TempREC/" + instrInf;
                    } else {
                        mtInstruction += instrInf;
                    }
                }
            }
            String regex = ".*/FIN53/(.*)/[A-Z0-9]{1,8}/.*";
            Pattern p = Pattern.compile(regex);
            Matcher m = p.matcher(mtInstruction);
            if (m.find()) {
                /**
                 * group(0)就是指的整个串，group(1)指的是第一个括号里的东西，group(2)指的第二个括号里的东西
                 */
                bicCode = m.group(1);
            }
        }
        if (StringUtil.isNotEmpty(bicCode) && SwiftTransferUtil.isBIC(bicCode)) {
            return bicCode;
        } else {
            return null;
        }
    }

    /**
     *
     * @param path
     * @return
     */
    protected String mx_to_mt54A(String path) {
        String bicCode = "";
        int pathCount = XmlUtil.getChildrenCount(document, path, null);
        if (pathCount > 0) {
            String mtInstruction = XmlUtil.getXmlNodeValue(document, path + "(0).InstrInf");
            for (int i=0; i<pathCount; i++) {
                if (i == 0) continue;
                String instrInf = XmlUtil.getXmlNodeValue(document, path + "("+i+").InstrInf");
                if (StringUtil.isNotEmpty(instrInf)) {
                    if (instrInf.length() < 35 && !instrInf.matches("/[A-Z0-9]{1,8}/.*")) {
                        mtInstruction += "/TempREC/" + instrInf;
                    } else {
                        mtInstruction += instrInf;
                    }
                }
            }
            String regex = ".*/FIN54/(.*)/[A-Z0-9]{1,8}/.*";
            Pattern p = Pattern.compile(regex);
            Matcher m = p.matcher(mtInstruction);
            if (m.find()) {
                /**
                 * group(0)就是指的整个串，group(1)指的是第一个括号里的东西，group(2)指的第二个括号里的东西
                 */
                bicCode = m.group(1);
            }
        }
        if (StringUtil.isNotEmpty(bicCode) && SwiftTransferUtil.isBIC(bicCode)) {
            return bicCode;
        } else {
            return null;
        }
    }

    /**
     * mtNameAddress取值逻辑:
     * MxLei = party.Id.OrgId.LEI
     * 如果MxLei存在，并且party.PstlAdr.Ctry存在，MtLei = 3/ + party.PstlAdr.Ctry + /LEIC + MxLei;
     * 如果MxLei存在，并且party.PstlAdr.Ctry不存在，MtLei = 3/ + CH + /LEIC + MxLei;
     * mtNameAddress = MX_To_MTPartyNameAndStructuredAddress(party);
     * 如果MX_To_MTPartyNameAndStructuredAddress(party)行数小于4行，那么mtNameAddress = mtNameAddress + (回车换行) + mtNameAddress
     * @param partyPath
     * @return
     */
    protected String mx_to_mtPartyNameAndAddressLEI1(String partyPath) {
        String mtNameAddress = mx_to_mtPartyNameAndStructuredAddress(partyPath);
        String mxLei = XmlUtil.getXmlNodeValue(document, partyPath + ".Id.OrgId.LEI");
        String countryCode = XmlUtil.getXmlNodeValue(document, partyPath + ".PstlAdr.Ctry");
        String mtLei = "";
        if (StringUtil.isNotEmpty(mxLei)) {
            if (StringUtil.isEmpty(countryCode)) countryCode = "CH";
            mtLei = "3/" + countryCode + "/LEIC" + mxLei;
        }
        String[] mtNameAddressLines = mtNameAddress.split(Mx2MtConstants.NEW_LINE);
        if (mtNameAddressLines.length < 4 && StringUtil.isNotEmpty(mtLei)) {
            mtNameAddress += Mx2MtConstants.NEW_LINE + mtLei;
        }
        return mtNameAddress;
    }

    /**
     * 前提是party.PstlAdr.AdrLine是结构性地址，以2/，3/开始。
     * mtNameAddress取值逻辑:
     * MxName = party.Nm
     * 1.如果MxName不存在，MxName = "NOTPROVIDED";
     * 2.找countryCode，找到第一个以3/开始的countryCode，如果找不到countryCode=CH;
     * 3.MtLei = 3/ + countryCode + /LEIC + MxLei;
     * 4.如果party.PstlAdr.AdrLine行数大于等于3
     *   ①如果MxName长度大于33，那么MxName = 1/ + MxName截取到32位，最后一位给 +;
     *   ②否则MxName = 1/ + MxName
     *   mtNameAddress = MxName + party.PstlAdr.AdrLine(取前3行)
     * 5.如果party.PstlAdr.AdrLine行数等于2
     *   ①如果MtLei长度大于0，
     *    如果MxName长度大于33，那么MxName = 1/ + MxName截取到32位，最后一位给 +,否则MxName = 1/ + MxName
     *    mtNameAddress = MxName + party.PstlAdr.AdrLine(取前2行) + MtLei;
     *   ②如果MtLei长度等于0，
     *    如果MxName长度大于66，那么MxName = 1/ + MxName截取到33位 + 回车换行 + 1/ + MxName截取到65位，最后一位给 +;
     *    如果MxName长度大于33，那么MxName = 1/ + MxName截取到33位 + 回车换行 + 1/ + MxName截取到最后一位
     *    否则MxName = 1/ + MxName
     *    mtNameAddress = MxName + party.PstlAdr.AdrLine(取前2行)
     * 6.如果party.PstlAdr.AdrLine行数等于1
     *    如果MxName长度大于66，那么MxName = 1/ + MxName截取到33位 + 回车换行 + 1/ + MxName截取到65位，最后一位给 +;
     *    如果MxName长度大于33，那么MxName = 1/ + MxName截取到33位 + 回车换行 + 1/ + MxName截取到最后一位
     *    否则MxName = 1/ + MxName
     *    如果MtLei长度大于0，
     *    mtNameAddress = MxName + party.PstlAdr.AdrLine(取1行) + MtLei;
     *    否则mtNameAddress = MxName + party.PstlAdr.AdrLine(取1行)
     * @param partyPath
     * @return
     */
    protected String mx_to_mtPartyNameAndAddressLEI2(String partyPath, String leiPrefix) {
        String mtNameAddress = "";
        String mxName = XmlUtil.getXmlNodeValue(document, partyPath + ".Nm");
        if (StringUtil.isEmpty(mxName)) mxName = Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
        String mxLei = XmlUtil.getXmlNodeValue(document, partyPath + ".Id.OrgId.LEI");
        String countryCode = "CH";
        int addressLineCount = XmlUtil.getChildrenCount(document, partyPath + ".PstlAdr.AdrLine", null);
        if (addressLineCount > 0) {
            for (int i=0; i<addressLineCount; i++) {
                String addressLine = XmlUtil.getXmlNodeValue(document, partyPath + ".PstlAdr.AdrLine("+i+")");
                if (addressLine.startsWith("3/")) {
                    String addressCountryCode = addressLine.substring(2, 4);
                    if (addressCountryCode.matches("[A-Z]{2}")) {
                        countryCode = addressCountryCode;
                    }
                    break;
                }
            }
        }
        String mtLei = "";
        if (StringUtil.isNotEmpty(mxLei)) {
            mtLei = leiPrefix + countryCode + "/LEIC" + mxLei;
        }
        if (addressLineCount >= 3) {
            if (mxName.length() > 33) mxName = "1/" + mxName.substring(0, 32) + "+";
            mtNameAddress = mxName + Mx2MtConstants.NEW_LINE
                          + XmlUtil.getXmlNodeValue(document, partyPath + ".PstlAdr.AdrLine("+0+")") + Mx2MtConstants.NEW_LINE
                          + XmlUtil.getXmlNodeValue(document, partyPath + ".PstlAdr.AdrLine("+1+")") + Mx2MtConstants.NEW_LINE
                          + XmlUtil.getXmlNodeValue(document, partyPath + ".PstlAdr.AdrLine("+2+")");
        } else if (addressLineCount == 2){
            if (StringUtil.isNotEmpty(mtLei)) {
                if (mxName.length() > 33) mxName = "1/" + mxName.substring(0, 32) + "+";
                mtNameAddress = mxName + Mx2MtConstants.NEW_LINE
                              + XmlUtil.getXmlNodeValue(document, partyPath + ".PstlAdr.AdrLine("+0+")") + Mx2MtConstants.NEW_LINE
                              + XmlUtil.getXmlNodeValue(document, partyPath + ".PstlAdr.AdrLine("+1+")") + Mx2MtConstants.NEW_LINE
                              + mtLei;
            } else {
                if (mxName.length() > 66) {
                    mxName = "1/" + mxName.substring(0, 33) + Mx2MtConstants.NEW_LINE
                            + "1/" + mxName.substring(33, 65) + "+";
                } else if (mxName.length() > 33) {
                    mxName = "1/" + mxName.substring(0, 33) + Mx2MtConstants.NEW_LINE
                            + "1/" + mxName.substring(33);
                } else {
                    mxName = "1/" + mxName;
                }
                mtNameAddress = mxName + Mx2MtConstants.NEW_LINE
                        + XmlUtil.getXmlNodeValue(document, partyPath + ".PstlAdr.AdrLine("+0+")") + Mx2MtConstants.NEW_LINE
                        + XmlUtil.getXmlNodeValue(document, partyPath + ".PstlAdr.AdrLine("+1+")");
            }
        } else { //addressLineCount == 1
            if (mxName.length() > 66) {
                mxName = "1/" + mxName.substring(0, 33) + Mx2MtConstants.NEW_LINE
                        + "1/" + mxName.substring(33, 65) + "+";
            } else if (mxName.length() > 33) {
                mxName = "1/" + mxName.substring(0, 33) + Mx2MtConstants.NEW_LINE
                        + "1/" + mxName.substring(33);
            } else {
                mxName = "1/" + mxName;
            }
            if (StringUtil.isNotEmpty(mtLei)) {
                mtNameAddress = mxName + Mx2MtConstants.NEW_LINE
                        + XmlUtil.getXmlNodeValue(document, partyPath + ".PstlAdr.AdrLine("+0+")") + Mx2MtConstants.NEW_LINE
                        + mtLei;
            } else {
                mtNameAddress = mxName + Mx2MtConstants.NEW_LINE
                        + XmlUtil.getXmlNodeValue(document, partyPath + ".PstlAdr.AdrLine("+0+")");
            }
        }
      return mtNameAddress;
    }

    /**
     * 该方法用于判断party.PstlAdr.AdrLine是否是结构性地址(以2/，3/开始)
     * 判断条件
     * ①每行开始以2/或者3/
     * ②至少有一行包含3/
     * ③第一行3/后面2个字符必须是countryCode
     * ④2/不能在3/后面
     * 如果都满足以上条件就返回true否则返回false
     * @param partyPath
     * @return
     */
    protected boolean mx_to_mtAddressLineType(String partyPath) {
        boolean flag = true;
        int addressLineCount = XmlUtil.getChildrenCount(document, partyPath + ".PstlAdr.AdrLine", null);
        if (addressLineCount == 0) flag = false;
        String countryCode = "";
        int count = 0;
        for (int i=0; i<addressLineCount; i++) {
            String addressLine = XmlUtil.getXmlNodeValue(document, partyPath + ".PstlAdr.AdrLine("+i+")");
            if (addressLine.startsWith("3/")) {
                countryCode = addressLine.substring(2, 4);
                break;
            }
        }
        if (!countryCode.matches("[A-Z]{2}")) flag = false; //③第一行3/后面2个字符必须是countryCode
        for (int i=0; i<addressLineCount; i++) {
            String addressLine = XmlUtil.getXmlNodeValue(document, partyPath + ".PstlAdr.AdrLine("+i+")");
            if (!addressLine.startsWith("2/") && !addressLine.startsWith("3/")) { //每行开始以2/或者3/
                flag = false;
                break;
            }
            if (addressLine.startsWith("3/")) {
                count++;
                for (int j=i+1; j<addressLineCount; j++) {
                    String addressLineTmp = XmlUtil.getXmlNodeValue(document, partyPath + ".PstlAdr.AdrLine("+j+")");
                    if (addressLineTmp.startsWith("2/")) {
                        flag = false; //④2/不能在3/后面
                        break;
                    }
                }
            }
        }
        if (count == 0) flag = false; //②至少有一行包含3/
        return flag;
    }

    /**
     * MxBic = party.Id.OrgId.AnyBIC
     * MxName = party.Nm
     * MxCountry = party.PstlAdr.Ctry
     * MxTownName = party.PstlAdr.TwnNm
     * MxIden = party.Id.OrgId.Othr.Id  否则 取party.Id.PrvtId.Othr.Id
     * 1.如果MxBic有值，MTUltimateParty = MxBic
     * 2.如果MxName有值
     *    如果MxCountry有值，MTUltimateParty = MxName + "/"+ MxCountry + "/" + MxTownName
     *    否则如果MxIden有值，MTUltimateParty = MxName + "/"+ MxIden
     *    否则 MTUltimateParty = MxName
     * 3.如果MxName没有值  MTUltimateParty = MxIden
     * @param partyPath
     * @return
     */
    protected String mx_to_mtUltimateParty(String partyPath) {
        String bicCode = mx_to_mtAnyBIC(partyPath);
        if (StringUtil.isNotEmpty(bicCode)) {
            return bicCode;
        } else {
            String mtUltimateParty = "";
            String mxIdentification = XmlUtil.getXmlNodeValue(document, partyPath+".Id.OrgId.Othr.Id");
            if (StringUtil.isEmpty(mxIdentification)) {
                mxIdentification = XmlUtil.getXmlNodeValue(document, partyPath+".Id.PrvtId.Othr.Id");
            }
            String mxName = XmlUtil.getXmlNodeValue(document, partyPath+".Nm");
            String mxCountry = XmlUtil.getXmlNodeValue(document, partyPath+".PstlAdr.Ctry");
            String mxTownName = XmlUtil.getXmlNodeValue(document, partyPath+".PstlAdr.TwnNm");
            if (StringUtil.isNotEmpty(mxName)) {
                if (StringUtil.isNotEmpty(mxCountry)) {
                    if (StringUtil.isNotEmpty(mxTownName)) {
                        mtUltimateParty = mxName + "/" + mxCountry + "/" + mxTownName;
                    } else {
                        mtUltimateParty = mxName + "/" + mxCountry;
                    }
                } else {
                    if (StringUtil.isNotEmpty(mxIdentification)) {
                        mtUltimateParty = mxName + "/" + mxIdentification;
                    } else {
                        mtUltimateParty = mxName;
                    }
                }
            } else {
                mtUltimateParty = mxIdentification;
            }
            return mtUltimateParty;
        }
    }

    /**
     * MX_To_MTAgent(BranchAndFinancialInstitutionIdentification6, MXCodeLength)
     * 举例：MxCode = /INTA/   MxCodeLength = 6
     * MTAgent取值逻辑：（最多占2行，换行需要用//拼接）
     * MXBic = agt.FinInstnId.BICFI
     * MxName=agt.FinInstnId.Nm
     * MxCountryCode=agt.FinInstnId.PstlAdr.Ctry
     * MxTownName=agt.FinInstnId.PstlAdr.TwnNm
     * MxClearingId=agt.FinInstnId.ClrSysMmbId
     * 1.如果MxBic存在，MTAgent = MxBic
     * 2.如果MxName存在，格式:Name(Country(TownName
     *     MaxCCNameLength = 35 - MxCodeLength + 33 - 2-2-MxTownName.length
     *     MaxNameLength =  35 - MxCodeLength + 33
     *     ①如果MxCountryCode存在，
     *            如果MxName.Length > MaxCCNameLength，MTAgent = MxName.substring（0，MaxCCNameLength-1），最后一位用+代替 否则MTAgent = MxName
     *            MTAgent = MxName + "(" + MxCountryCode + "(" + MxTownName
     *     ②如果MxCountryCode不存在，
     *            如果MxName.Length > MaxNameLength，MTAgent = MxName.substring（0，MaxNameLength-1），最后一位用+代替 否则MTAgent = MxName
     * 3.如果MxClearingId存在，MTAgent = MxClearingId.ClrSysId.Cd + MxClearingId.MmbId
     * @param agentPath
     * @return
     */
    protected String mx_to_mtAgent(String agentPath, int mxCodeLength) {
        String mtAgent = "";
        String mxBic = XmlUtil.getXmlNodeValue(document, agentPath + ".FinInstnId.BICFI");
        String mxName = XmlUtil.getXmlNodeValue(document, agentPath + ".FinInstnId.Nm");
        String mxCountryCode = XmlUtil.getXmlNodeValue(document, agentPath + ".FinInstnId.PstlAdr.Ctry");
        String mxTownName = XmlUtil.getXmlNodeValue(document, agentPath + ".FinInstnId.PstlAdr.TwnNm");
        String mxClearingCode = XmlUtil.getXmlNodeValue(document, agentPath + ".FinInstnId.ClrSysMmbId.ClrSysId.Cd");
        if (StringUtil.isNotEmpty(mxBic)) {
            mtAgent = mxBic;
        } else if (StringUtil.isNotEmpty(mxName)) {
            int maxCCNameLength = 35 - mxCodeLength + 33 - 2 - 2 - (StringUtil.isNotEmpty(mxTownName)?mxTownName.length():0);
            int maxNameLength =  35 - mxCodeLength + 33;
            if (StringUtil.isNotEmpty(mxCountryCode)) {
                if (mxName.length() > maxCCNameLength) {
                    mtAgent = mxName.substring(0, maxCCNameLength-1) + "+";
                } else {
                    if (StringUtil.isNotEmpty(mxTownName)) {
                        mtAgent = mxName + "(" + mxCountryCode + "(" + mxTownName;
                    } else {
                        mtAgent = mxName + "(" + mxCountryCode;
                    }
                }
            } else {
                if (mxName.length() > maxNameLength) {
                    mtAgent = mxName.substring(0, maxNameLength-1) + "+";
                } else {
                    mtAgent = mxName;
                }
            }
        } else if (StringUtil.isNotEmpty(mxClearingCode)) {
            mtAgent = mxClearingCode + XmlUtil.getXmlNodeValue(document, agentPath + ".FinInstnId.ClrSysMmbId.MmbId");
        }
        return mtAgent;
    }

    /**
     * MTAgent取值逻辑:
     * MXBic = agt.FinInstnId.BICFI
     * MxName=agt.FinInstnId.Nm
     * MxClearingId=agt.FinInstnId.ClrSysMmbId
     * 1.如果MxBic存在，MTAgent = MxBic
     * 2.如果MxName存在
     *     如果MxName.Length > MaxLength，MTAgent = MxName.substring（0，MaxNameLength-1），最后一位用+代替 否则MTAgent = MxName
     * 3.如果MxClearingId存在，MTAgent = MxClearingId.ClrSysId.Cd + MxClearingId.MmbId
     *    如果MTAgent.Length > MaxLength，MTAgent = MTAgent.substring（0，MaxNameLength-1），最后一位用+代替 否则不变
     * @param agentPath
     * @param maxLength
     * @return
     */
    protected String mx_to_mtBICNameAgent(String agentPath, int maxLength) {
        String mtAgent = "";
        String mxBic = XmlUtil.getXmlNodeValue(document, agentPath + ".FinInstnId.BICFI");
        String mxName = XmlUtil.getXmlNodeValue(document, agentPath + ".FinInstnId.Nm");
        String mxClearingCode = XmlUtil.getXmlNodeValue(document, agentPath + ".FinInstnId.ClrSysMmbId.ClrSysId.Cd");
        if (StringUtil.isNotEmpty(mxBic)) {
            mtAgent = mxBic;
        } else if (StringUtil.isNotEmpty(mxName)) {
            mtAgent = mxName;
        } else if (StringUtil.isNotEmpty(mxClearingCode)) {
            mtAgent = mxClearingCode + XmlUtil.getXmlNodeValue(document, agentPath + ".FinInstnId.ClrSysMmbId.MmbId");
        }
        if (StringUtil.isNotEmpty(mtAgent)) {
            if (mtAgent.length() > maxLength) {
                mtAgent = mtAgent.substring(0, maxLength-1) + "+";
            }
        }
        return mtAgent;
    }

    /**
     * subfunctionInstructionForNextAgent取值逻辑:
     * 1.将所有存在的InstrInf值加起来，注意如果InstrInf不以/[A-Z0-9]{1,8}/开始并且上一条InstrInf长度小于35，那么中间需要加/TempREC/
     * 2.如果结果1中存在/FIN53/BIC，则需要删掉/FIN53/BIC
     * 3.将结果2中的/TempREC/xxx，全部拿出来组装在一起(mtNoCode)，并删除掉/TempREC/xxx
     * 4.如果InstrInf中包含/REC/,需要将mtNoCode放在REC后面；否则在InstrInf后面加/REC/mtNoCode
     * @param agentPath
     * @return
     */
    protected String subFunctionInstructionForNextAgent(String agentPath, String settlementMethod) {
        String tmpRec = "/TempREC/";
        String mtInstrInf = "";
        int instrCount = XmlUtil.getChildrenCount(document, agentPath, null);
        if (instrCount > 0) {
            String mxInstrInf = "";
            for (int i=0; i<instrCount; i++) {
                String instrInf = XmlUtil.getXmlNodeValue(document, agentPath + "("+i+").InstrInf");
                if (StringUtil.isNotEmpty(instrInf)) {
                    if (i == 0) {
                        mxInstrInf += instrInf;
                    } else {
                        String lastInstrInf = XmlUtil.getXmlNodeValue(document, agentPath + "("+(i-1)+").InstrInf");
                        if (StringUtil.isNotEmpty(lastInstrInf)
                                && lastInstrInf.length() < 35
                                && !instrInf.matches("/[A-Z0-9]{1,8}/.*")) {
                            mxInstrInf += tmpRec + instrInf;
                        } else {
                            mxInstrInf += instrInf;
                        }
                    }
                }
            }
            boolean bicCodeFlag = false;
            String bicCode = ""; //找53的bicCode
            String regex = ".*/FIN53/(.*)/[A-Z0-9]{1,8}/.*";
            Pattern p = Pattern.compile(regex);
            Matcher m = p.matcher(mxInstrInf);
            if (m.find()) {
                /**
                 * group(0)就是指的整个串，group(1)指的是第一个括号里的东西，group(2)指的第二个括号里的东西
                 */
                bicCode = m.group(1);
            }

            if (SwiftTransferUtil.isBIC(bicCode)
                    && (SettlementMethodCode.INGA.value().equals(settlementMethod)
                        || SettlementMethodCode.INDA.value().equals(settlementMethod))) {
                String acccount = mx_to_mtAccount(grpHdrParentElementName + ".GrpHdr.SttlmInf.SttlmAcct");
                if (StringUtil.isEmpty(acccount)) {
                    String senderBic = (String)context.get(Mx2MtContextIdentifier.MX_SENDER_BIC, true);
                    String receiverBic = (String)context.get(Mx2MtContextIdentifier.MX_RECEIVER_BIC, true);
                    if ((StringUtil.isNotEmpty(senderBic) && senderBic.substring(0, 6).equals(bicCode.substring(0, 6)))
                       || (StringUtil.isNotEmpty(receiverBic) && receiverBic.substring(0, 6).equals(bicCode.substring(0, 6)))) {
                        bicCodeFlag = true;
                    }
                } else {
                    bicCodeFlag = true;
                }
            }
            if (bicCodeFlag) { //表示能够找到fin53的bicCode,然后删掉
                mxInstrInf =  mxInstrInf.replace("/FIN53/"+bicCode, "");
            }
            if (!mxInstrInf.matches("/[A-Z0-9]{1,8}/.*")) {
                mxInstrInf = tmpRec + mxInstrInf;
            }
            String totalNoCodeInstrInf = "";
            String[] tmpRecs = mxInstrInf.split(tmpRec);
            for (int i=0; i<tmpRecs.length; i++) {
                String str = tmpRecs[i];
                if (StringUtil.isEmpty(str)) continue;
                p = Pattern.compile("(.*)/[A-Z0-9]{1,8}/.*");
                m = p.matcher(str);
                String noCodeInstrInf = "";
                if (m.find()) {
                    /**
                     * group(0)就是指的整个串，group(1)指的是第一个括号里的东西，group(2)指的第二个括号里的东西
                     */
                    noCodeInstrInf = m.group(1);
                } else {
                    noCodeInstrInf = str;
                }
                totalNoCodeInstrInf += noCodeInstrInf;
                mxInstrInf =  mxInstrInf.replace(tmpRec+noCodeInstrInf, "");
            }
            if (StringUtil.isNotEmpty(totalNoCodeInstrInf)) {
                //找到是否包含/REC/
                if (mxInstrInf.indexOf("/REC/") > -1) {
                    p = Pattern.compile(".*/REC/(.*)/[A-Z0-9]{1,8}/.*");
                    m = p.matcher(mxInstrInf);
                    if (m.find()) {
                        /**
                         * group(0)就是指的整个串，group(1)指的是第一个括号里的东西，group(2)指的第二个括号里的东西
                         */
                        String recInstrInf = m.group(1);
                        String newRecInstrInf = recInstrInf + totalNoCodeInstrInf;
                        mtInstrInf = mxInstrInf.replace("/REC/"+recInstrInf, "/REC/"+newRecInstrInf);
                    }
                } else {
                    mtInstrInf = mxInstrInf + "/REC/" + totalNoCodeInstrInf;
                }
            } else {
                mtInstrInf = mxInstrInf;
            }
        }
        return mtInstrInf;
    }

    /**
     * 提取PHOB,TELB,UDLC和无CODE的instrInfo
     * @param agentPath
     * @return
     */
    protected String subFunctionInstructionForCreditorAgent(String agentPath) {
        int creditorAgentCount = XmlUtil.getChildrenCount(document, agentPath, null);
        String mtInstrInf = "";
        if (creditorAgentCount > 0) {
            //UDLC PHOB TELB
            String accInstrInf = "/ACC/";
            String phobInstrInf = "/PHONBEN/";
            String telbInstrInf = "/TELEBEN/";
            for (int i=0; i<creditorAgentCount; i++) {
                if (i == 2) break;
                String code = XmlUtil.getXmlNodeValue(document, agentPath + "("+i+").Cd");
                String instrInf = XmlUtil.getXmlNodeValue(document, agentPath + "("+i+").InstrInf");
                if (StringUtil.isEmpty(code)) {
                    accInstrInf += instrInf;
                }
                if (ExternalCreditorAgentInstructionCode.PHOB.value().equals(code)) {
                    phobInstrInf += instrInf;
                }
                if (ExternalCreditorAgentInstructionCode.TELB.value().equals(code)) {
                    telbInstrInf += instrInf;
                }
            }
            String mxInstrInf = "";
            if (accInstrInf.length() > 5) { //accInstrInf = /ACC/xxx
                mxInstrInf += accInstrInf;
            }
            if (phobInstrInf.length() > 9) { //phobInstrInf = /PHONBEN/xxx
                mxInstrInf += phobInstrInf;
            }
            if (telbInstrInf.length() > 9) { //telbInstrInf = /TELEBEN/xxx
                mxInstrInf += telbInstrInf;
            }
            String regex = ".*/UDLC/(.*)/[A-Z0-9]{1,8}/.*";
            Pattern p = Pattern.compile(regex);
            Matcher m = p.matcher(mxInstrInf);
            if (m.find()) {
                mtInstrInf += "/UDLC/" + m.group(1);
            }
            regex = ".*/ACC/(.*)/[A-Z0-9]{1,8}/.*";
            p = Pattern.compile(regex);
            m = p.matcher(mxInstrInf);
            if (m.find()) {
                mtInstrInf += "/ACC/" + m.group(1);
            }
            regex = ".*/PHONBEN/(.*)/[A-Z0-9]{1,8}/.*";
            p = Pattern.compile(regex);
            m = p.matcher(mxInstrInf);
            if (m.find()) {
                mtInstrInf += "/PHONBEN/" + m.group(1);
            }
            regex = ".*/TELEBEN/(.*)/[A-Z0-9]{1,8}/.*";
            p = Pattern.compile(regex);
            m = p.matcher(mxInstrInf);
            if (m.find()) {
                mtInstrInf += "/TELEBEN/" + m.group(1);
            }
        }
        return mtInstrInf;
    }

    /**
     * pacs008001转MT103 70域的第5个参数使用
     * 提取CHQB 和无CODE的instrInfo
     * @param agentPath
     * @return
     */
    protected String subFunctionInstructionForCreditorAgentAndJP(String agentPath) {
        int creditorAgentCount = XmlUtil.getChildrenCount(document, agentPath, null);
        String mtInstrInf = "";
        if (creditorAgentCount > 0) {
            //CHQB
            String accInstrInf = "/ACC/";
            String chqbInstrInf = "/CHQB/";
            for (int i=0; i<creditorAgentCount; i++) {
                if (i == 2) break;
                String code = XmlUtil.getXmlNodeValue(document, agentPath + "("+i+").Cd");
                String instrInf = XmlUtil.getXmlNodeValue(document, agentPath + "("+i+").InstrInf");
                if (StringUtil.isEmpty(code)) {
                    accInstrInf += instrInf;
                }
                if (ExternalCreditorAgentInstructionCode.CHQB.value().equals(code)) {
                    chqbInstrInf += instrInf;
                }
            }
            String mxInstrInf = "";
            if (accInstrInf.length() > 5) { //accInstrInf = /ACC/xxx
                mxInstrInf += accInstrInf;
            }
            if (chqbInstrInf.length() > 6) { //chqbInstrInf = /CHQB/xxx
                mxInstrInf += chqbInstrInf;
            }
            String regex = ".*/ACC/(.*)/[A-Z0-9]{1,8}/.*";
            Pattern p = Pattern.compile(regex);
            Matcher m = p.matcher(mxInstrInf);
            if (m.find()) {
                mtInstrInf += "/ACC/" + m.group(1);
            }
            regex = ".*/CHQB/(.*)/[A-Z0-9]{1,8}/.*";
            p = Pattern.compile(regex);
            m = p.matcher(mxInstrInf);
            if (m.find()) {
                mtInstrInf += "/CHQB/" + m.group(1);
            }
        }
        return mtInstrInf;
    }

    /**
     * 取值逻辑：
     * 1.mxRemitInfo = CdtTrfTxInf.RmtInf.Ustrd(0),取第一条记录
     * 2.提取/BNF/xxxx，作为bnfInfo，并在mxRemitInfo删除掉对应的内容
     * 3.提取/TSU/xxxx，作为tsuInfo，并在mxRemitInfo删除掉对应的内容
     * 4.如果bnfInfo存在，那么直接在后面加上mxRemitInfo剩余的内容；否则bnfInfo = /BNF/ + mxRemitInfo剩余的内容
     * 5.MT72 = bnfInfo + tsuInfo
     * @param remittanceInfoPath
     * @return
     */
    protected String subFunctionRemittanceInformation(String remittanceInfoPath) {
        String mtRemittanceInfo = "";
        int remitInfoUstrdCount = XmlUtil.getChildrenCount(document, remittanceInfoPath + ".Ustrd", null);
        if (remitInfoUstrdCount > 0) {
            String mxRemittanceInfo = XmlUtil.getXmlNodeValue(document, remittanceInfoPath + ".Ustrd(0)");
            String bnfInfo = "";
            String regex = ".*/BNF/(.*)/TSU/.*";
            Pattern p = Pattern.compile(regex);
            Matcher m = p.matcher(mxRemittanceInfo);
            if (m.find()) {
                bnfInfo += "/BNF/" + m.group(1);
                mxRemittanceInfo.replace(bnfInfo, "");
            }
            String tsuInfo = "";
            regex = ".*/TSU/(.*)/BNF/.*";
            p = Pattern.compile(regex);
            m = p.matcher(mxRemittanceInfo);
            if (m.find()) {
                tsuInfo += "/TSU/" + m.group(1);
                mxRemittanceInfo.replace(tsuInfo, "");
            }
            if (StringUtil.isNotEmpty(bnfInfo)) {
                bnfInfo += mxRemittanceInfo;
            } else {
                bnfInfo += "/BNF/" + mxRemittanceInfo;
            }
            mtRemittanceInfo = bnfInfo + tsuInfo;
        }
        return mtRemittanceInfo;
    }

    //mx格式日期转化为mt格式
    protected String mXToMTDate(String xmlDate){
        try {
            XMLGregorianCalendar dateDt = DatatypeFactory.newInstance().newXMLGregorianCalendar(xmlDate);
            return DateUtil.format(dateDt, "yyMMdd");
        }catch (Exception e){
            e.printStackTrace();
        }
        return "日期格式转化失败";
    }

    /**
     * 判断xml节点的值如果值包含"pacs.008"则该字段赋值为"103",
     * 包含"pacs.003"则赋值为"104",包含"MT10[0-9]{1}"，
     * 则根据正则表达式,截取3位为"10X",(X的取值为0-9)，
     * 值包含"pasc.009"，赋值为"202"，值包含"pasc.010"则赋值为"204"，
     * 包含"MT20[0-9]{1}"，则根据正则表达式,截取3位为"20X",(X的取值为0-9)，
     * 最后如果上述条件均不满足则直接赋值为"202"。1类型的交给192处理，2类型的交给292处理
     * 这是11s域的第一部分。
     * @param mtType
     * @return
     */
    protected String getMtMsg(String mtType) {
        if(StringUtil.isNotEmpty(mtType)){
            if(mtType.startsWith("pacs.008")){
                return "103";
            }else if(mtType.startsWith("pacs.003")){
                return "104";
            }else if(mtType.startsWith("pacs.009")){
                return "202";
            }else if(mtType.startsWith("pacs.010")){
                return "204";
            }else if(mtType.matches("MT10[0-9]{1}")){
                return mtType.substring(2);
            }else if(mtType.matches("MT20[0-9]{1}")){
                return mtType.substring(2);
            }else {
                return "202";
            }
        }else {
            return "没有找到指定的类型";
        }
    }

    /**
     *MX_To_MT79CANC（MXOriginalUETR,MXCancellationReasonInformation）
     *  参数一：MXOriginalUETR对应的xml节点
     *  FIToFIPmtCxlReq/Undrlyg/TxInf/OrgnlUETR
     *  参数二： MXCancellationReasonInformation对应的xml节点FIToFIPmtCxlReq/Undrlyg/TxInf/CxlRsnInf
     *  参数二下/AddtlInf值的取值规则为 这是个集合，第一行数据存在则直接赋值，第二行存在且第一行长度大于104就直接与第一行直接拼接，
     *  小于的话则中间加一个空格再与第二行拼接  79String = Concatenate(“/”,MXReasonCode,”/’,MXAdditioanlInformation)
     *  MXReasonCoded的值对应的xml节点为FIToFIPmtCxlReq/Undrlyg/TxInf/CxlRsnInf/Rsn/Cd
     *  MXAdditioanlInformation的值对应的节点 FIToFIPmtCxlReq/Undrlyg/TxInf/CxlRsnInf/AddtlInf
     *  拼接之后为/MXReasonCode/MXAdditioanlInformation
     *  如果需要下一行，则必须以" // "开头，后面有多行都是以"//"开头
     *  字段79的结构如下:35*50x，其中:
     * Line 1 : /4!c/[AdditionalInformation]
     * Line 2-35 //Continuation of Additional Information
     * Line [Last] : /UETR/UETRNumber最后一行的如果决定不将UETR转换为Field79, 那么最后一行将被初始化为一个空字符串
     * 否则最后一行为"/UETR/参数一的值"
     * @param uetr
     * @param xmlNote
     * @return
     */
    protected String mXToMT79CANC(String uetr,String xmlNote){
        String additioanlInformation = getAdditioanlInformation(xmlNote);
        String reasonCoded = getXmlNodeValue(bodyHdrParentElementName, document, xmlNote+".Rsn.Cd");
        String filed79String = "/"+reasonCoded+"/"+ additioanlInformation;
        filed79String = appendComplexMT79(filed79String, uetr);
        return filed79String;
    }

    protected String getAdditioanlInformation(String xmlNote){
        String addtlInf = xmlNote + ".AddtlInf";
        int count = getXmlNodeCounts(bodyHdrParentElementName, document, addtlInf);
        String additioanlInformation = "";
        if(count>0){
            for (int i = 0; i < count; i++) {
                String additioanl = getXmlNodeValue(bodyHdrParentElementName, document, addtlInf+"("+i+")");
                if(i==0){
                    additioanlInformation = additioanl;
                }
                if(i==1){
                    if(additioanlInformation.length()>104){
                        additioanlInformation = additioanlInformation + additioanl;
                    }else {
                        additioanlInformation = additioanlInformation + " "+additioanl;
                    }
                }
            }
        }
        return additioanlInformation;
    }
    protected String appendComplexMT79(String filed79, String uetr){
        StringBuilder sb = new StringBuilder();
        if (filed79.length()>0){
            int count = filed79.length()/50;
            int countInt = filed79.length()%50;
            if(count==0){
                sb.append(filed79);
                sb.append(Mx2MtConstants.NEW_LINE).append("/UETR/").append(uetr);
            }else {
                for (int i = 0; i < count; i++) {
                    if(i==0){
                        String substring = filed79.substring(0, 50);
                        sb.append(substring).append(Mx2MtConstants.NEW_LINE);
                    }
                    if(i==1){
                        String substring = filed79.substring(50, 98);
                        sb.append("//").append(substring).append(Mx2MtConstants.NEW_LINE);
                    }
                    if(i>1){
                        String substring = filed79.substring(98+(i-2)*48, 98+(i-1)*48);
                        sb.append("//").append(substring).append(Mx2MtConstants.NEW_LINE);
                    }
                    if(i+1 == count&&countInt!=0){
                        String substring = filed79.substring(98+(i-1)*48);
                        sb.append("//").append(substring).append(Mx2MtConstants.NEW_LINE);
                    }
                }
                sb.append("/UETR/").append(uetr);
            }
        }
        return sb.toString();
    }

    /**
     *MX_To_MT76RCANC (MXStatus, MXCancellationStatusReasonInformation, MXUETR; MT76, MT77A)
     *  MXStatus对应的xml节点的值RsltnOfInvstgtn/Sts/conf
     *  MXCancellationStatusReasonInformation对应xml节点的值  RsltnOfInvstgtn/CxlDtls/TxInfAndSts/CxlStsRsnInf
     *  MXUETR对应的xml节点的值 RsltnOfInvstgtn/CxlDtls/TxInfAndSts/OrgnlUETR
     *  RsltnOfInvstgtn/CxlDtls/TxInfAndSts/CxlStsRsnInf/Rsn/Cd 节点值值存在则赋值给MXReasonCode
     *  RsltnOfInvstgtn/CxlDtls/TxInfAndSts/CxlStsRsnInf/AddtlInf节点下的值 是个集合。赋值给MXAdditionalInformation
     *  第一行数据存在则直接赋值，第二行存在且第一行长度大于104就直接与第一行直接拼接，小于的话则中间加一个空格再与第二行拼接
     *  MXReasonCode和MXAdditionalInformation值都存在/MXStatus/MXReasonCode/MXAdditionalInformation
     *  MXReasonCode和MXAdditionalInformation值都不存在  /MXStatus/
     *  其中有一个值存在/MXStatus/MXReasonCode(MXReasonCode的值存在)
     *  /MXStatus/MXAdditionalInformation(MXAdditionalInformation的值存在)
     *  MXString76每行最大为35，延续行以"//"开头
     *  76域最大为6*35,如果超过过则是使用77A域赋值格式为
     *  / MXUETR/(超出部分的值)
     * @param sts
     * @param xmlNote
     * @param uetr
     * @return
     */
    protected List<String> mXToMT76RCANC(String sts, String uetr,String xmlNote){
        String additioanlInformation = getAdditioanlInformation(xmlNote);
        String reasonCoded = getXmlNodeValue(bodyHdrParentElementName, document, xmlNote+".Rsn.Cd");
        String string76 = "/" + sts + "/";
        if(StringUtil.isNotEmpty(reasonCoded)){
            if(StringUtil.isNotEmpty(additioanlInformation)){
                string76 = string76 +reasonCoded+"/"+additioanlInformation;
            }else {
                string76 = string76 + reasonCoded;
            }
        }else{
            if(StringUtil.isNotEmpty(additioanlInformation)){
                string76 = string76 + additioanlInformation;
            }
        }
        return splitInLines(string76, uetr);
    }

    protected List<String> splitInLines(String filed76, String uetr){
        List<String> list = new ArrayList<>();
        StringBuilder sb76 = new StringBuilder();
        StringBuilder sb77A = new StringBuilder();
        if (filed76.length()>0){
            int count = filed76.length()/35;
            int countInt = filed76.length()%35;
            if(count>1){
                count = (filed76.length()-35)/33+1;
                countInt = (filed76.length()-35)%33;
            }
            if(count==0){
                sb76.append(filed76);
                String str = "/UETR/" + uetr;
                if(str.length()>35){
                    sb77A.append(str.substring(0, 35)).append(Mx2MtConstants.NEW_LINE).append("//").append(str.substring(35));
                }
            }else{
                for (int i = 0; i < count; i++) {
                    if (i == 0) {
                        String substring = filed76.substring(0, 35);
                        sb76.append(substring);
                    }
                    if (i == 1) {
                        String substring = filed76.substring(35, 68);
                        sb76.append(Mx2MtConstants.NEW_LINE).append("//").append(substring);
                    }
                    if (i > 1 && i<6) {
                        String substring = filed76.substring(68 + (i - 2) * 33, 68 + (i - 1) * 33);
                        sb76.append(Mx2MtConstants.NEW_LINE).append("//").append(substring);
                    } else if (i > 5) {
                        String substring = filed76.substring(68 + (i - 2) * 33, 68 + (i - 1) * 33);
                        sb77A.append(Mx2MtConstants.NEW_LINE).append("//").append(substring);
                    }
                    if (i + 1 == count && countInt != 0) {
                        String substring = filed76.substring(68 + (i - 1) * 33);
                        if (count <= 5) {
                             sb76.append(Mx2MtConstants.NEW_LINE).append("//").append(substring);
                        } else {
                            sb77A.append(Mx2MtConstants.NEW_LINE).append("//").append(substring);
                        }
                    }
                }
                if(StringUtil.isNotEmpty(uetr)){
                    if(sb77A.toString().length()>0){
                        sb77A.append(Mx2MtConstants.NEW_LINE);
                    }
                    String str = "/UETR/" + uetr;
                    if(str.length()>35){
                        sb77A.append(str.substring(0, 35)).append(Mx2MtConstants.NEW_LINE).append("//").append(str.substring(35));
                    }
                }
            }
        }
        list.add(sb76.toString());
        list.add(sb77A.toString());
        return list;
    }

    protected String mx_to_mtFATFIdentification(String partyPath) {
        String identificationPath = partyPath + ".Id";
        String countryCode = XmlUtil.getXmlNodeValue(document, partyPath+".PstlAdr.Ctry");
        String countryOfResidence = XmlUtil.getXmlNodeValue(document, partyPath+".CtryOfRes");
        boolean successfulFATF = false;
        String mxCode = "";
        String mxIssuer = "";
        String mtIdentifier = "";
        String mtCountryCode = "";
        String mtSchemeCode = "";
        String mtIssuer = "";
        int orgIdenOtherCount = XmlUtil.getChildrenCount(document, identificationPath + ".OrgId.Othr", null);
        if (orgIdenOtherCount > 0) {
            for (int i=0; i<orgIdenOtherCount; i++) {
                mxCode = XmlUtil.getXmlNodeValue(document, identificationPath + ".OrgId.Othr("+i+").SchmeNm.Cd");
                mxIssuer = XmlUtil.getXmlNodeValue(document, identificationPath + ".OrgId.Othr("+i+").Issr");
                mtIdentifier = XmlUtil.getXmlNodeValue(document, identificationPath + ".OrgId.Othr("+i+").Id");
                if (StringUtil.isNotEmpty(mxIssuer)) {
                    if (mxIssuer.matches("[A-Z]{2}")) { //国家代号
                        mtCountryCode = mxIssuer;
                        mxIssuer = "";
                    } else if (mxIssuer.length() > 4){
                        String subMxIssuer = mxIssuer.substring(0, 2);
                        if (subMxIssuer.matches("[A-Z]{2}")
                                && "/".equals(mxIssuer.substring(2, 3))) {
                            mtCountryCode = subMxIssuer;
                            mxIssuer = mxIssuer.substring(3);
                        }
                    }
                }
                if (OrganisationIdentificationCode.GS1G.value().equals(mxCode)
                        || OrganisationIdentificationCode.DUNS.value().equals(mxCode)) {
                    mtSchemeCode = "CUST";
                    if (mxIssuer.length() > 0) {
                        mtIssuer = mxCode + " " + mxIssuer;
                    } else {
                        mtIssuer = mxCode;
                    }
                    if (StringUtil.isNotEmpty(mtCountryCode)) {
                        successfulFATF = true;
                        break;
                    }
                } else if (OrganisationIdentificationCode.TXID.value().equals(mxCode)) {
                    if (StringUtil.isNotEmpty(mtCountryCode)
                            && Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE.equals(mtIdentifier)) {
                        if (StringUtil.isNotEmpty(mtCountryCode)) {
                            successfulFATF = true;
                            break;
                        }
                    }
                } else if (SwiftTransferUtil.getOrganisationIdentificationCodeByCode(mxCode) != null
                        && !OrganisationIdentificationCode.CUST.value().equals(mxCode)
                        && !OrganisationIdentificationCode.EMPL.value().equals(mxCode)
                        && !OrganisationIdentificationCode.TXID.value().equals(mxCode)) {
                    mtSchemeCode = "CUST";
                    if (mxIssuer.length() > 0) {
                        mtIssuer = mxCode + " " + mxIssuer;
                    } else {
                        mtIssuer = mxCode;
                    }
                    if (StringUtil.isNotEmpty(mtCountryCode)) {
                        successfulFATF = true;
                        break;
                    }
                } else if (OrganisationIdentificationCode.CUST.value().equals(mxCode) || OrganisationIdentificationCode.EMPL.value().equals(mxCode)) {
                    mtSchemeCode = mxCode;
                    if (StringUtil.isEmpty(mxIssuer)) {
                        mtIssuer = Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
                    } else {
                        mtIssuer = mxIssuer;
                    }
                    if (StringUtil.isNotEmpty(mtCountryCode)) {
                        successfulFATF = true;
                        break;
                    }
                } else if (OrganisationIdentificationCode.TXID.value().equals(mxCode)) {
                    mtSchemeCode = mxCode;
                    mtIssuer = "";
                    if (StringUtil.isNotEmpty(mtCountryCode)) {
                        if (Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE.equals(mtIdentifier)) {
                            if (StringUtil.isNotEmpty(countryCode)) {
                                mtCountryCode = countryCode;
                                successfulFATF = true;
                                break;
                            }
                        } else {
                            successfulFATF = true;
                            break;
                        }
                    }
                }
            }
        } else {
            int privateIdenOtherCount = XmlUtil.getChildrenCount(document, identificationPath + ".PrvtId.Othr", null);
            if (privateIdenOtherCount > 0) {
                for (int i=0; i<privateIdenOtherCount; i++) {
                    mtSchemeCode = XmlUtil.getXmlNodeValue(document, identificationPath + ".PrvtId.Othr("+i+").SchmeNm.Cd");
                    mtIssuer = XmlUtil.getXmlNodeValue(document, identificationPath + ".PrvtId.Othr("+i+").Issr");
                    mtIdentifier = XmlUtil.getXmlNodeValue(document, identificationPath + ".PrvtId.Othr("+i+").Id");
                    PersonIdentificationCode personIdenCode = SwiftTransferUtil.getPersonIdentificationCodeByCode(mtSchemeCode);
                    if (personIdenCode != null) {
                        if (StringUtil.isNotEmpty(mtIssuer)) {
                            if (mtIssuer.matches("[A-Z]{2}")) { //国家代号
                                mtCountryCode = mtIssuer;
                                mtIssuer = "";
                                successfulFATF = true;
                                break;
                            } else if (mtIssuer.length() > 4){
                                String subMxIssuer = mtIssuer.substring(0, 2);
                                if (subMxIssuer.matches("[A-Z]{2}")
                                        && "/".equals(mtIssuer.substring(2, 3))) {
                                    mtCountryCode = subMxIssuer;
                                    mtIssuer = mtIssuer.substring(3);
                                    successfulFATF = true;
                                    break;
                                }
                            }
                        }
                        if (StringUtil.isNotEmpty(countryCode)) {
                            mtCountryCode = countryCode;
                            successfulFATF = true;
                        } else if (StringUtil.isNotEmpty(countryOfResidence)) {
                            mtCountryCode = countryOfResidence;
                            successfulFATF = true;
                        }
                    }
                }
                if (PersonIdentificationCode.ARNU.value().equals(mtSchemeCode)
                        || PersonIdentificationCode.CCPT.value().equals(mtSchemeCode)
                        || PersonIdentificationCode.NIDN.value().equals(mtSchemeCode)
                        || PersonIdentificationCode.SOSE.value().equals(mtSchemeCode)
                        || PersonIdentificationCode.TXID.value().equals(mtSchemeCode)) {
                    mtIssuer = "";
                } else if (PersonIdentificationCode.TELE.value().equals(mtSchemeCode)) {
                    if (mtIssuer.length() > 0) {
                        mtIssuer = mtSchemeCode + " " + mtIssuer;
                    } else {
                        mtIssuer = mtSchemeCode;
                    }
                    mtSchemeCode = "CUST";
                } else if (PersonIdentificationCode.CUST.value().equals(mtSchemeCode)
                        || PersonIdentificationCode.DRLC.value().equals(mtSchemeCode)
                        || PersonIdentificationCode.EMPL.value().equals(mtSchemeCode)) {
                    if (StringUtil.isEmpty(mtIssuer)) {
                        mtIssuer = Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
                    }
                }
            }
        }
        if (successfulFATF) {
            String mtFATFId = "";
            if (StringUtil.isEmpty(mtIssuer)) {
                mtFATFId = mtSchemeCode + "/" + mtCountryCode + "/" + mtIdentifier;
            } else if (Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE.equals(mtIssuer)) {
                mtFATFId = mtSchemeCode + "/" + mtCountryCode + "//" + mtIdentifier;
            } else {
                mtFATFId = mtSchemeCode + "/" + mtCountryCode + "/" + mtIssuer + "/" + mtIdentifier;
            }
            if ("EMPL".equals(mtSchemeCode)
                    || "CUST".equals(mtSchemeCode)
                    || "DRLC".equals(mtSchemeCode)) {
                if (mtFATFId.length() > 68) {
                    int issuerLength = 59 - mtIdentifier.length();
                    mtIssuer = mtIssuer.substring(0, issuerLength-1) + "+";
                    mtFATFId = mtSchemeCode + "/" + mtCountryCode + "/" + mtIssuer + "/" + mtIdentifier;
                }
            }
            return mtFATFId;
        }
        return null;
    }

    /**
     * 有2部分组成
     * 4/ + Id.PrvtId.DtAndPlcOfBirth.BirthDt
     * 5/ + Id.PrvtId.DtAndPlcOfBirth.CtryOfBirth + / + Id.PrvtId.DtAndPlcOfBirth.CityOfBirth
     * @param partyPath
     * @return
     */
    protected String[] mx_to_mtBirthInformation(String partyPath) {
        try {
            String mxBirthDateStr = XmlUtil.getXmlNodeValue(document, partyPath  + ".Id.PrvtId.DtAndPlcOfBirth.BirthDt");
            String mxBirthPlace = XmlUtil.getXmlNodeValue(document, partyPath  + ".Id.PrvtId.DtAndPlcOfBirth.CityOfBirth");
            String mxBirthCountry = XmlUtil.getXmlNodeValue(document, partyPath  + ".Id.PrvtId.DtAndPlcOfBirth.CtryOfBirth");
            String mtBirthDate = "";
            if (StringUtil.isNotEmpty(mxBirthDateStr)) {
                Date mxBirthDate = DateUtil.parseDate(mxBirthDateStr, "yyyy-MM-dd");
                mtBirthDate = "4/" + DateUtil.format(mxBirthDate, "yyyyMMdd");
            }
            if (StringUtil.isNotEmpty(mxBirthPlace)) {
                if (mxBirthPlace.length() > 30) {
                    mxBirthPlace = mxBirthPlace.substring(0, 29) + "+";
                }
            }
            String mtCountryandPlaceOfBirth = "5/" + mxBirthCountry + "/" + mxBirthPlace;
            if (StringUtil.isNotEmpty(mtBirthDate) && StringUtil.isNotEmpty(mtCountryandPlaceOfBirth)) {
                return new String[]{mtBirthDate, mtCountryandPlaceOfBirth};
            }
            return null;
        } catch (ParseException e) {
            throw new SwiftException("ERROR", e.getMessage());
        }
    }

    /**
     *
     * @param partyPath
     * @return
     */
    protected Map<String, String> mx_to_mtFATFID_CUST_NIDN(String partyPath) {
        Map<String, String> maps = new HashMap<>();
        int index6 = -1;
        int index7 = -1;
        String countryCode = XmlUtil.getXmlNodeValue(document, partyPath+".PstlAdr.Ctry");
        String countryOfResidence = XmlUtil.getXmlNodeValue(document, partyPath+".CtryOfRes");
        String identificationPath = partyPath + ".Id";
        int privateIdenOtherCount = XmlUtil.getChildrenCount(document, identificationPath + ".PrvtId.Othr", null);
        if (privateIdenOtherCount > 0) {
            for (int i=0; i<privateIdenOtherCount; i++) {
                String mxSchemeCode = XmlUtil.getXmlNodeValue(document, identificationPath + ".PrvtId.Othr("+i+").SchmeNm.Cd");
                if (PersonIdentificationCode.CUST.value().equals(mxSchemeCode)) {
                    index6 = i;
                }
                if (PersonIdentificationCode.NIDN.value().equals(mxSchemeCode)) {
                    index7 = i;
                }
            }
        }
        String mtCode6 = "";
        if (index6 > -1) {
            boolean successfulFATF = false;
            String mxIssuer = XmlUtil.getXmlNodeValue(document, identificationPath + ".PrvtId.Othr("+index6+").Issr");
            String mxIdentifier = XmlUtil.getXmlNodeValue(document, identificationPath + ".PrvtId.Othr("+index6+").Id");
            if (StringUtil.isNotEmpty(mxIdentifier)
                    && !("/" + Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE).equals(mxIdentifier)
                    && !mxIdentifier.startsWith("CUST")) {
                String mtCountryCode = "";
                String mtIssuer = "";
                if (StringUtil.isNotEmpty(mxIssuer)) {
                    if (mxIssuer.matches("[A-Z]{2}")) {
                        mtCountryCode = mxIssuer;
                        successfulFATF = true;
                    } else if (mxIssuer.length() >= 4 && mxIssuer.substring(0, 2).matches("[A-Z]{2}") && "/".equals(mxIssuer.substring(2, 3))) {
                        mtCountryCode = mxIssuer.substring(0, 2);
                        mtIssuer = mxIssuer.substring(3);
                        successfulFATF = true;
                    } else {
                        mtIssuer = mxIssuer;
                        if (StringUtil.isNotEmpty(countryCode)) {
                            mtCountryCode = countryCode;
                            successfulFATF = true;
                        } else if (StringUtil.isNotEmpty(countryOfResidence)) {
                            mtCountryCode = countryOfResidence;
                            successfulFATF = true;
                        }
                    }
                }
                if (successfulFATF) {
                    mtCode6 = "6/" + mtCountryCode + "/" + mtIssuer + "/" + mxIdentifier;
                    if (mtCode6.length() > 35) mtCode6 = mtCode6.substring(0, 34) + "+";
                    maps.put("MTCODE6", mtCode6);
                }
            }
        }
        String mtCode7 = "";
        if (index7 > -1) {
            boolean successfulFATF = false;
            String mxIssuer = XmlUtil.getXmlNodeValue(document, identificationPath + ".PrvtId.Othr("+index7+").Issr");
            String mxIdentifier = XmlUtil.getXmlNodeValue(document, identificationPath + ".PrvtId.Othr("+index7+").Id");
            if (StringUtil.isNotEmpty(mxIdentifier)
                    && !("/" + Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE).equals(mxIdentifier)
                    && !mxIdentifier.startsWith("NIDN")) {
                String mtCountryCode = "";
                if (StringUtil.isNotEmpty(mxIssuer)) {
                    if (mxIssuer.matches("[A-Z]{2}")) {
                        mtCountryCode = mxIssuer;
                        successfulFATF = true;
                    }
                } else {
                    if (StringUtil.isNotEmpty(countryCode)) {
                        mtCountryCode = countryCode;
                        successfulFATF = true;
                    } else if (StringUtil.isNotEmpty(countryOfResidence)) {
                        mtCountryCode = countryOfResidence;
                        successfulFATF = true;
                    }
                }
                if (successfulFATF) {
                    mtCode7 = "7/" + mtCountryCode + "/" + mxIdentifier;
                    if (mtCode7.length() > 35) mtCode7 = mtCode7.substring(0, 34) + "+";
                    maps.put("MTCODE7", mtCode7);
                }
            }
        }
        return maps;
    }

    /**
     *
     * @param partyPath
     * @return
     */
    protected String mx_to_mtFATFNameAndAddress(String partyPath) {
        String mtNameAndAddress = mx_to_mtPartyNameAndStructuredAddress(partyPath);
        String mtPartyIdentifier = mx_to_mtFATFIdentification(partyPath);
        String mtCode8 = "";
        if (StringUtil.isNotEmpty(mtPartyIdentifier) && mtPartyIdentifier.length() > 35) {
            mtCode8 = "8/" + mtPartyIdentifier.substring(35);
        }
        String mtCode4 = "";
        String mtCode5 = "";
        String[] mtBrithInfos = mx_to_mtBirthInformation(partyPath);
        if (mtBrithInfos != null && mtBrithInfos.length == 2) {
            mtCode4 = mtBrithInfos[0];
            mtCode5 = mtBrithInfos[1];
        }
        String mtCode6 = "";
        String mtCode7 = "";
        Map<String, String> maps = mx_to_mtFATFID_CUST_NIDN(partyPath);
        if (maps != null) {
            mtCode6 = maps.get("MTCODE6");
            mtCode7 = maps.get("MTCODE7");
        }
        String mxLei = XmlUtil.getXmlNodeValue(document, partyPath + ".Id.OrgId.LEI");
        if (StringUtil.isNotEmpty(mxLei)) {
            String countryCode = XmlUtil.getXmlNodeValue(document, partyPath + ".PstlAdr.Ctry");
            if (StringUtil.isEmpty(countryCode)) {
                countryCode = "CH";
            }
            mtCode6 = "6/" + countryCode + "/LEIC" + mxLei;
        }
        if (StringUtil.isNotEmpty(mtNameAndAddress)) {
            int remainLines = 4 - mtNameAndAddress.split(Mx2MtConstants.NEW_LINE).length;
            if (remainLines > 0) {
                int addLines = 0;
                if (StringUtil.isNotEmpty(mtCode4) && StringUtil.isNotEmpty(mtCode5) && addLines < remainLines && remainLines >=2) {
                    mtNameAndAddress += Mx2MtConstants.NEW_LINE + mtCode4 + Mx2MtConstants.NEW_LINE + mtCode5;
                    addLines += 2;
                }
                if (StringUtil.isNotEmpty(mtCode6) && addLines < remainLines) {
                    addLines++;
                    mtNameAndAddress += Mx2MtConstants.NEW_LINE + mtCode6;
                }
                if (StringUtil.isNotEmpty(mtCode7) && addLines < remainLines) {
                    addLines++;
                    mtNameAndAddress += Mx2MtConstants.NEW_LINE + mtCode7;
                }
                if (StringUtil.isNotEmpty(mtCode8) && addLines < remainLines) {
                    addLines++;
                    mtNameAndAddress += Mx2MtConstants.NEW_LINE + mtCode8;
                }
            }
        }
        return mtNameAndAddress;
    }

    protected String mx_to_mtFATFNameAndAddress2(String partyPath) {
        String mtNameAndAddress = mx_to_mtPartyNameAndAddressLEI2(partyPath, "6/");
        String mtPartyIdentifier = mx_to_mtFATFIdentification(partyPath);
        String mtCode8 = "";
        if (StringUtil.isNotEmpty(mtPartyIdentifier) && mtPartyIdentifier.length() > 35) {
            mtCode8 = "8/" + mtPartyIdentifier.substring(35);
        }
        String mtCode4 = "";
        String mtCode5 = "";
        String[] mtBrithInfos = mx_to_mtBirthInformation(partyPath);
        if (mtBrithInfos != null && mtBrithInfos.length == 2) {
            mtCode4 = mtBrithInfos[0];
            mtCode5 = mtBrithInfos[1];
        }
        String mtCode6 = "";
        String mtCode7 = "";
        Map<String, String> maps = mx_to_mtFATFID_CUST_NIDN(partyPath);
        if (maps != null) {
            mtCode6 = maps.get("MTCODE6");
            mtCode7 = maps.get("MTCODE7");
        }
        if (StringUtil.isNotEmpty(mtNameAndAddress)) {
            int remainLines = 4 - mtNameAndAddress.split(Mx2MtConstants.NEW_LINE).length;
            if (remainLines > 0) {
                int addLines = 0;
                if (StringUtil.isNotEmpty(mtCode4) && StringUtil.isNotEmpty(mtCode5) && addLines < remainLines && remainLines >=2) {
                    mtNameAndAddress += Mx2MtConstants.NEW_LINE + mtCode4 + Mx2MtConstants.NEW_LINE + mtCode5;
                    addLines += 2;
                }
                if (StringUtil.isNotEmpty(mtCode6) && addLines < remainLines) {
                    addLines++;
                    mtNameAndAddress += Mx2MtConstants.NEW_LINE + mtCode6;
                }
                if (StringUtil.isNotEmpty(mtCode7) && addLines < remainLines) {
                    addLines++;
                    mtNameAndAddress += Mx2MtConstants.NEW_LINE + mtCode7;
                }
                if (StringUtil.isNotEmpty(mtCode8) && addLines < remainLines) {
                    addLines++;
                    mtNameAndAddress += Mx2MtConstants.NEW_LINE + mtCode8;
                }
            }
        }
        return mtNameAndAddress;
    }

    protected String subFunctionReasonCodeTranslation(String mxReasonCode, List<MxMtReasonCodeInfo> mxMtReasonCodeInfos) {
        String mtFixedCode = "/XT99/";
        String mtReasonCode = "";
        boolean isMtErrorCodePresent = false;
        if (mxMtReasonCodeInfos != null && mxMtReasonCodeInfos.size() > 0) {
            for (int i=0; i<mxMtReasonCodeInfos.size(); i++) {
                MxMtReasonCodeInfo mxMtReasonCodeInfo = mxMtReasonCodeInfos.get(i);
                if (mxReasonCode.equals(mxMtReasonCodeInfo.getIsoCode())) {
                    isMtErrorCodePresent = mxMtReasonCodeInfo.isMtErrorCodePresent();
                    mtReasonCode = mxMtReasonCodeInfo.getMtCode();
                    break;
                }
            }
        }
        if (isMtErrorCodePresent) {
            return "/" + mtReasonCode + "/";
        } else {
            return mtFixedCode + mxReasonCode + "/";
        }
    }

    protected String subFunctionIDTruncation(String mxId) {
        if (StringUtil.isEmpty(mxId)) {
            return Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
        }
        if (mxId.length() > 16) {
            mxId = mxId.substring(0, 15) + "+";
        }
        String mtId = mxId;
        if (mtId.startsWith("/") || mtId.endsWith("/") || mtId.contains("//")) {
            mtId = Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
        }
        return mtId;
    }

    protected String subFunctionChargeCalculation(String chargesInfoPath) {
        BigDecimal totalAmt = BigDecimal.ZERO;
        String ccy = "";
        int chrgsInfCount = XmlUtil.getChildrenCount(document, chargesInfoPath, null);
        if (chrgsInfCount > 0) {
            ccy = XmlUtil.getXmlNodeValue(document, chargesInfoPath + "(0).Amt@Ccy");
            String amt = XmlUtil.getXmlNodeValue(document, chargesInfoPath + "(0).Amt");
            totalAmt = totalAmt.add(new BigDecimal(amt));
            if (chrgsInfCount > 1) {
                for (int i = 1; i < chrgsInfCount; i++) {
                    if (ccy.equals(getXmlNodeValue(bodyHdrParentElementName, document, "TxInf.ChrgsInf(" + i + ").Amt@Ccy"))) {
                        BigDecimal tmpAmt = new BigDecimal(getXmlNodeValue(bodyHdrParentElementName, document, "TxInf.ChrgsInf(" + i + ").Amt"));
                        totalAmt = totalAmt.add(tmpAmt);
                    }
                }
            }
        }
        if (totalAmt.compareTo(BigDecimal.ZERO) > 0) {
            return "/CHGS/" + ccy + NumberUtil.formatAmt(totalAmt, ccy);
        } else {
            return null;
        }
    }
    //转换函数方法区结束
}
