package com.brilliance.swift.mx2mt.mt103;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtCreator;
import com.brilliance.swift.mx2mt.Mx2MtContextIdentifier;
import com.brilliance.swift.mx2mt.Mx2MtTagsGenerate;
import com.brilliance.swift.mx2mt.mt103.impl.*;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.util.XmlUtil;
import com.brilliance.swift.vo.common.ServiceLevelCode;
import com.prowidesoftware.swift.model.SwiftBlock3;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;
import com.prowidesoftware.swift.model.field.*;
import org.dom4j.Document;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

public class Mx2Mt103Creator extends AbstractMx2MtCreator {

    @Override
    public void preProcess() {
        super.preProcess();
        Document document = (Document)context.get(Mx2MtContextIdentifier.MX_XMl_DOCUMENT, true);
        Map<String, String> parentElementMaps = XmlUtil.getParentElementMaps(document);
        context.set(Mx2MtContextIdentifier.APPHDR_PARENT_ELEMENT_NAME, parentElementMaps.get("AppHdr"));
        context.set(Mx2MtContextIdentifier.GRPHDR_PARENT_ELEMENT_NAME, parentElementMaps.get("GrpHdr"));
        context.set(Mx2MtContextIdentifier.BODY_PARENT_ELEMENT_NAME, parentElementMaps.get("CdtTrfTxInf"));
    }

    @Override
    public void withBlock3() throws SwiftException {
        super.withBlock3();
        SwiftBlock3 block3 = context.get(SwiftMessage.class).getBlock3();
        Document document = (Document)context.get(Mx2MtContextIdentifier.MX_XMl_DOCUMENT, true);
        String bodyParentPath = (String)context.get(Mx2MtContextIdentifier.BODY_PARENT_ELEMENT_NAME, true);
        String serviceType = "";
        int serviceLevelCount = getXmlNodeCounts(bodyParentPath, document, "CdtTrfTxInf.PmtTpInf.SvcLvl");
        if (serviceLevelCount > 0) {
            for (int i=0; i<serviceLevelCount; i++) {
                String serviceLevelCode = getXmlNodeValue(bodyParentPath, document, "CdtTrfTxInf.PmtTpInf.SvcLvl("+i+").Cd");
                if (ServiceLevelCode.G001.value().equals(serviceLevelCode)
                        || ServiceLevelCode.G002.value().equals(serviceLevelCode)
                        || ServiceLevelCode.G003.value().equals(serviceLevelCode)
                        || ServiceLevelCode.G004.value().equals(serviceLevelCode)) {
                    serviceType = serviceLevelCode.substring(1);
                    break;
                }
            }
        }
        if (StringUtil.isNotEmpty(serviceType)) {
            Field111 field111 = new Field111(serviceType);
            block3.builder().setField111(field111);
        }
        String uetr = getXmlNodeValue(bodyParentPath, document, "CdtTrfTxInf.PmtId.UETR");
        if (StringUtil.isNotEmpty(uetr)) {
            Field121 field121 = new Field121(uetr);
            block3.builder().setField121(field121);
        }
    }

    @Override
    public List<Mx2MtTagsGenerate> getGenerateTagList() {
        List<Mx2MtTagsGenerate> fieldsGenerateList = new ArrayList<>();
        fieldsGenerateList.add(new Field20Generate());
        fieldsGenerateList.add(new Field13CGenerate());
        fieldsGenerateList.add(new Field23BGenerate());
        fieldsGenerateList.add(new Field23EGenerate());
        fieldsGenerateList.add(new Field26TGenerate());
        fieldsGenerateList.add(new Field32AGenerate());
        fieldsGenerateList.add(new Field33BGenerate());
        fieldsGenerateList.add(new Field36Generate());
        fieldsGenerateList.add(new Field50AGenerate());
        fieldsGenerateList.add(new Field51AGenerate());
        fieldsGenerateList.add(new Field52AGenerate());
        fieldsGenerateList.add(new Field53AGenerate());
        fieldsGenerateList.add(new Field54AGenerate());
        fieldsGenerateList.add(new Field55AGenerate());
        fieldsGenerateList.add(new Field56AGenerate());
        fieldsGenerateList.add(new Field57AGenerate());
        fieldsGenerateList.add(new Field59Generate());
        fieldsGenerateList.add(new Field70Generate());
        fieldsGenerateList.add(new Field71AGenerate());
        fieldsGenerateList.add(new Field72Generate());
        fieldsGenerateList.add(new Field77BGenerate());
        return fieldsGenerateList;
    }

    @Override
    public void postProcess() throws SwiftException {
        if (isStp()) {
            SwiftMessage swiftMessage = (SwiftMessage)context.get(SwiftMessage.class);
            Field119 field119 = new Field119("STP");
            swiftMessage.getBlock3().builder().setField119(field119);
        }
        super.postProcess();
    }

    @Override
    protected String getMtType() {
        return Mx2MtConstants.MT_TYPE_103;
    }

    private boolean isStp() {
        boolean stpFlag = true;
        SwiftMessage swiftMessage = context.get(SwiftMessage.class);
        //所有代理行都是optionA
        List<Tag> tags = swiftMessage.getBlock4().getTags();
        for (int i=0; i<tags.size(); i++) {
            Tag tag = tags.get(i);
            if ("52D".equals(tag.getName())) {
                stpFlag = false;
                break;
            }
            if ("53D".equals(tag.getName())) {
                stpFlag = false;
                break;
            }
            if ("54D".equals(tag.getName())) {
                stpFlag = false;
                break;
            }
            if ("55D".equals(tag.getName())) {
                stpFlag = false;
                break;
            }
            if ("56D".equals(tag.getName())) {
                stpFlag = false;
                break;
            }
            if ("57D".equals(tag.getName())) {
                stpFlag = false;
                break;
            }
            if ("59".equals(tag.getName())) {
                Field59 field59 = (Field59)tag.asField();
                if (StringUtil.isEmpty(field59.getAccount())) {
                    stpFlag = false;
                    break;
                }
            }
            if ("59A".equals(tag.getName())) {
                Field59A field59A = (Field59A)tag.asField();
                if (StringUtil.isEmpty(field59A.getAccount())) {
                    stpFlag = false;
                    break;
                }
            }
            if ("59F".equals(tag.getName())) {
                Field59F field59F = (Field59F)tag.asField();
                if (StringUtil.isEmpty(field59F.getAccount())) {
                    stpFlag = false;
                    break;
                }
            }
        }
        Document document = (Document)context.get(Mx2MtContextIdentifier.MX_XMl_DOCUMENT, true);
        String bodyHdrParentElementName = (String)context.get(Mx2MtContextIdentifier.BODY_PARENT_ELEMENT_NAME, true);
        int svcLvlCount = getXmlNodeCounts(bodyHdrParentElementName, document, "CdtTrfTxInf.PmtTpInf.SvcLvl");
        if (svcLvlCount > 0) {
            for (int i=0; i<svcLvlCount; i++) {
                String svcLvlProprietary = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.PmtTpInf.SvcLvl(" + i + ").Prtry");
                if (StringUtil.isNotEmpty(svcLvlProprietary)) {
                    stpFlag = false;
                    break;
                }
            }
        }
        String localInstrumentProprietary = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.PmtTpInf.LclInstrm.Prtry");
        if (StringUtil.isNotEmpty(localInstrumentProprietary)) {
            stpFlag = false;
        }
        String ctgyPurpProprietary = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.PmtTpInf.CtgyPurp.Prtry");
        if (StringUtil.isNotEmpty(ctgyPurpProprietary)) {
            stpFlag = false;
        }
        String proprietary = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.Purp.Prtry");
        if (StringUtil.isNotEmpty(proprietary)) {
            stpFlag = false;
        }
        int instrForCdtrAgtCount = getXmlNodeCounts(bodyHdrParentElementName, document, "CdtTrfTxInf.InstrForCdtrAgt");
        if (instrForCdtrAgtCount > 0 ) {
            stpFlag = false;
        }
        int instrForNxtAgtCount = getXmlNodeCounts(bodyHdrParentElementName, document, "CdtTrfTxInf.InstrForNxtAgt");
        if (instrForNxtAgtCount > 0 ) {
            stpFlag = false;
        }
        int rmtInfStrdCount = getXmlNodeCounts(bodyHdrParentElementName, document, "CdtTrfTxInf.RmtInf.Strd");
        if (rmtInfStrdCount > 0 ) {
            stpFlag = false;
        }
        return stpFlag;
    }
}
