package com.brilliance.swift.mx2mt.mt103.impl;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtTagsGenerate;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.common.SettlementMethodCode;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;

import java.util.List;

/**
 *对于所有代理行，如果xml报文中有代理行的bic，并且账户和清算代码都存在，则MT账号取账户；
 *  * 如果代理行没有bic，MT账号优先取清算代码，没有的话再取账户。
 */
public class Field53AGenerate extends AbstractMx2MtTagsGenerate {

    private static String name_A = "53A";

    private static String name_B = "53B";

    private static String name_D = "53D";

    @Override
    public void tagGenerate() throws SwiftException {
        SwiftMessage swiftMessage = context.get(SwiftMessage.class);
        List<Tag> tags = swiftMessage.getBlock4().getTags();
        String settlementMethod = getXmlNodeValue(grpHdrParentElementName, document, "GrpHdr.SttlmInf.SttlmMtd");
        String value = "";
        if (SettlementMethodCode.INGA.value().equals(settlementMethod)
           || SettlementMethodCode.INDA.value().equals(settlementMethod)) {
           String bicCode = mx_to_mt53A(bodyHdrParentElementName + ".CdtTrfTxInf.InstrForNxtAgt");
           String account = mx_to_mtSettlementAccount(settlementMethod, grpHdrParentElementName+".GrpHdr.SttlmInf.SttlmAcct");
           if (StringUtil.isNotEmpty(bicCode)) {
                if (StringUtil.isNotEmpty(account)) {
                    value = account + Mx2MtConstants.NEW_LINE + bicCode;
                } else {
                    value = bicCode;
                }
                tags.add(new Tag(name_A, value));
           } else {
               if (StringUtil.isNotEmpty(account)) {
                   value = account;
                   tags.add(new Tag(name_B, value));
               }
           }
        } else {
            String bicCode = mx_to_mtBICFI(grpHdrParentElementName + ".GrpHdr.SttlmInf.InstgRmbrsmntAgt");
            String account = mx_to_mtAccount(grpHdrParentElementName + ".GrpHdr.SttlmInf.InstgRmbrsmntAgtAcct");
            String mtClearSystemId = mx_to_mtClearingIdentifier(grpHdrParentElementName + ".GrpHdr.SttlmInf.InstgRmbrsmntAgt");
            String mtAccount = "";
            if (StringUtil.isNotEmpty(bicCode)) {
                if (StringUtil.isNotEmpty(account)) {
                    mtAccount = account;
                } else {
                    mtAccount = mtClearSystemId;
                }
                if (StringUtil.isNotEmpty(mtAccount)) {
                    value = mtAccount + Mx2MtConstants.NEW_LINE + bicCode;
                } else {
                    value = bicCode;
                }
                tags.add(new Tag(name_A, value));
            } else {
                String name = getXmlNodeValue(grpHdrParentElementName, document, "GrpHdr.SttlmInf.InstgRmbrsmntAgt.FinInstnId.Nm");
                String countryCode = getXmlNodeValue(grpHdrParentElementName, document, "GrpHdr.SttlmInf.InstgRmbrsmntAgt.FinInstnId.PstlAdr.Ctry");
                int addressLineCount = getXmlNodeCounts(grpHdrParentElementName, document, "GrpHdr.SttlmInf.InstgRmbrsmntAgt.FinInstnId.PstlAdr.AdrLine");
                String mtNameAddress = "";
                if (addressLineCount > 0) {
                    mtNameAddress = mx_to_mtFinancialInstitutionNameAndUnstructuredAddress(grpHdrParentElementName+ ".GrpHdr.SttlmInf.InstgRmbrsmntAgt.FinInstnId");
                } else if (StringUtil.isNotEmpty(countryCode)) {
                    mtNameAddress = mx_to_mtFinancialInstitutionNameAndStructuredAddress(grpHdrParentElementName+ ".GrpHdr.SttlmInf.InstgRmbrsmntAgt.FinInstnId", false);
                } else if (StringUtil.isNotEmpty(name)) {
                    mtNameAddress = mx_to_mtFinancialInstitutionNameAndUnstructuredAddress(grpHdrParentElementName+ ".GrpHdr.SttlmInf.InstgRmbrsmntAgt.FinInstnId");
                }
                if (StringUtil.isEmpty(mtNameAddress)) return;//如果name和地址不存在，返回。
                if (StringUtil.isNotEmpty(mtClearSystemId)) {
                    mtAccount = mtClearSystemId;
                } else {
                    mtAccount = account;
                }
                if (StringUtil.isNotEmpty(mtAccount)) {
                    value = mtAccount + Mx2MtConstants.NEW_LINE + mtNameAddress;
                } else {
                    value = mtNameAddress;
                }
                tags.add(new Tag(name_D, value));
            }
        }

    }
}
