package com.brilliance.swift.mx2mt.mt103Retn.impl;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtTagsGenerate;
import com.brilliance.swift.util.StringUtil;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;

import java.util.List;

/**
 *
 */
public class Field50AGenerate extends AbstractMx2MtTagsGenerate {

    private static String name_A = "50A";

    private static String name_F = "50F";

    private static String name_K = "50K";

    @Override
    public void tagGenerate() throws SwiftException {
        SwiftMessage swiftMessage = context.get(SwiftMessage.class);
        List<Tag> tags = swiftMessage.getBlock4().getTags();
        String value = "";
        String agtPath = bodyHdrParentElementName + ".TxInf.RtrChain.Dbtr.Agt";
        String bicCode = mx_to_mtBICFI(agtPath);
        String countryCode = getXmlNodeValue(bodyHdrParentElementName, document, "TxInf.RtrChain.Dbtr.Agt.FinInstnId.PstlAdr.Ctr");
        String agtName = getXmlNodeValue(bodyHdrParentElementName, document, "TxInf.RtrChain.Dbtr.Agt.FinInstnId.Nm");
        String clearingMemberId = getXmlNodeValue(bodyHdrParentElementName, document, "TxInf.RtrChain.Dbtr.Agt.FinInstnId.Nm");
        int addressLineCount = getXmlNodeCounts(bodyHdrParentElementName, document, "TxInf.RtrChain.Dbtr.Agt.FinInstnId.ClrSysMmbId.MmbId");
        if (StringUtil.isNotEmpty(bicCode)) {
            value = bicCode;
            tags.add(new Tag(name_A, value));
        } else if (StringUtil.isNotEmpty(countryCode)) {
            value = mx_to_mtFinancialInstitutionNameAndStructuredAddress(agtPath + ".FinInstnId", false);
            tags.add(new Tag(name_K, value));
        } else if (addressLineCount > 0 || StringUtil.isNotEmpty(agtName)) {
            value = mx_to_mtFinancialInstitutionNameAndUnstructuredAddress(agtPath + ".FinInstnId");
            tags.add(new Tag(name_K, value));
        } else if (StringUtil.isNotEmpty(clearingMemberId)) {
            value = Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE + Mx2MtConstants.NEW_LINE + mx_to_mtClearingIdentifier(agtPath);
            tags.add(new Tag(name_K, value));
        }
        if (StringUtil.isEmpty(value)) {
            String partyPath = bodyHdrParentElementName + ".TxInf.RtrChain.Dbtr.Pty";
            bicCode = mx_to_mtAnyBIC(partyPath);
            countryCode = getXmlNodeValue(bodyHdrParentElementName, document, "TxInf.RtrChain.Dbtr.Pty.PstlAdr.Ctry");
            String name = getXmlNodeValue(bodyHdrParentElementName, document, "TxInf.RtrChain.Dbtr.Pty.Nm");
            addressLineCount = getXmlNodeCounts(bodyHdrParentElementName, document, "TxInf.RtrChain.Dbtr.Pty.PstlAdr.AdrLine");
            if (StringUtil.isNotEmpty(bicCode)) {
                tags.add(new Tag(name_A, bicCode));
            } else if (StringUtil.isNotEmpty(countryCode)) {
                String nameAddress = mx_to_mtFATFNameAndAddress(partyPath);
                String account = mx_to_mtFATFIdentification(partyPath);
                if (StringUtil.isNotEmpty(account) && account.length() > 35) {
                    account = account.substring(0, 35);
                }
                if (StringUtil.isEmpty(account)) {
                    account = "/" + Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
                }
                value = account + Mx2MtConstants.NEW_LINE + nameAddress;
                tags.add(new Tag(name_F, value));
            } else if (addressLineCount > 0) {
                boolean structuredAddressIndicator = mx_to_mtAddressLineType(partyPath);
                if (structuredAddressIndicator) {
                    String nameAddress = mx_to_mtFATFNameAndAddress2(partyPath);
                    String account = mx_to_mtFATFIdentification(partyPath);
                    if (StringUtil.isNotEmpty(account) && account.length() > 35) {
                        account = account.substring(0, 35);
                    }
                    if (StringUtil.isEmpty(account)) {
                        account = "/" + Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
                    }
                    value = account + Mx2MtConstants.NEW_LINE + nameAddress;
                    tags.add(new Tag(name_F, value));
                } else {
                    String mtNameAddress = mx_to_mtFinancialInstitutionNameAndUnstructuredAddress(partyPath);
                    tags.add(new Tag(name_K, mtNameAddress));
                }
            } else if (StringUtil.isNotEmpty(name)) {
                String mtNameAddress = mx_to_mtFinancialInstitutionNameAndUnstructuredAddress(partyPath);
                tags.add(new Tag(name_K, mtNameAddress));
            } else {
                tags.add(new Tag(name_K, Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE));
            }
        }
    }
}
