package com.brilliance.swift.mx2mt.mt196296;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtCreator;
import com.brilliance.swift.mx2mt.Mx2MtContextIdentifier;
import com.brilliance.swift.mx2mt.Mx2MtTagsGenerate;
import com.brilliance.swift.mx2mt.mt196296.impl.Field11RGenerate;
import com.brilliance.swift.mx2mt.mt196296.impl.Field20Generate;
import com.brilliance.swift.mx2mt.mt196296.impl.Field21Generate;
import com.brilliance.swift.mx2mt.mt196296.impl.Field76Generate;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.util.XmlUtil;
import com.prowidesoftware.swift.model.SwiftBlock3;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;
import com.prowidesoftware.swift.model.field.Field121;
import org.dom4j.Document;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

public class Mx2Mtn96Creator extends AbstractMx2MtCreator {

    @Override
    public void preProcess() {
        super.preProcess();
        Document document = (Document)context.get(Mx2MtContextIdentifier.MX_XMl_DOCUMENT, true);
        Map<String, String> parentElementMaps = XmlUtil.getParentElementMaps(document);
        context.set(Mx2MtContextIdentifier.APPHDR_PARENT_ELEMENT_NAME, parentElementMaps.get("AppHdr"));
        context.set(Mx2MtContextIdentifier.GRPHDR_PARENT_ELEMENT_NAME, parentElementMaps.get("GrpHdr"));
        context.set(Mx2MtContextIdentifier.BODY_PARENT_ELEMENT_NAME, parentElementMaps.get("CxlDtls"));
    }

    @Override
    public void withBlock3() throws SwiftException {
        super.withBlock3();
        SwiftBlock3 block3 = context.get(SwiftMessage.class).getBlock3();
        Document document = (Document)context.get(Mx2MtContextIdentifier.MX_XMl_DOCUMENT, true);
        String bodyParentPath = (String)context.get(Mx2MtContextIdentifier.BODY_PARENT_ELEMENT_NAME, true);
        String uetr = getXmlNodeValue(bodyParentPath, document, "CxlDtls.TxInfAndSts.OrgnlUETR");
        if (StringUtil.isNotEmpty(uetr)) {
            Field121 field121 = new Field121(uetr);
            block3.builder().setField121(field121);
        }
    }

    @Override
    public List<Mx2MtTagsGenerate> getGenerateTagList() {
        List<Mx2MtTagsGenerate> fieldsGenerateList = new ArrayList<>();
        fieldsGenerateList.add(new Field20Generate());
        fieldsGenerateList.add(new Field21Generate());
        fieldsGenerateList.add(new Field76Generate());
        fieldsGenerateList.add(new Field11RGenerate());
        return fieldsGenerateList;
    }

    @Override
    protected String getMtType() {
        Document document = (Document)context.get(Mx2MtContextIdentifier.MX_XMl_DOCUMENT, true);
        String bodyParentPath = (String)context.get(Mx2MtContextIdentifier.BODY_PARENT_ELEMENT_NAME, true);
        String orgMsgNameIdentification = getXmlNodeValue(bodyParentPath, document, "CxlDtls.TxInfAndSts.OrgnlGrpInf.OrgnlMsgNmId");
        String mtType = Mx2MtConstants.MT_TYPE_296;
        if (StringUtil.isNotEmpty(orgMsgNameIdentification)) {
            if (orgMsgNameIdentification.startsWith("pacs.008")
                    || orgMsgNameIdentification.startsWith("pacs.003")) {
                mtType = Mx2MtConstants.MT_TYPE_196;
            } else if (orgMsgNameIdentification.startsWith("pacs.009")
                    || orgMsgNameIdentification.startsWith("pacs.010")) {
                mtType = Mx2MtConstants.MT_TYPE_296;
            } else if (orgMsgNameIdentification.matches("MT10[0-9]{1}")) {
                mtType = Mx2MtConstants.MT_TYPE_196;
            } else if (orgMsgNameIdentification.matches("MT20[0-9]{1}")) {
                mtType = Mx2MtConstants.MT_TYPE_296;
            }
        }
        return mtType;
    }
}
