package com.brilliance.swift.mx2mt.mt202Retn.impl;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtTagsGenerate;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.util.SwiftTransferUtil;
import com.brilliance.swift.vo.MxMtReasonCodeInfo;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;

import java.util.ArrayList;
import java.util.List;

/**
 MX_To_MT72RETN(MT1)
 取值逻辑：MTLine1,MTLine2,MTLine3,MTLine4,MTLine5,MTLine6
 MXAdditionalInformation = TxInf.RtrRsnInf.AddtlInf 全部加起来
 MTLine1 = /RETN/99
 MTLine3 = /MREF/ + SubfunctionIDTruncation(TxInf.OrgnlInstrId);
 MTLine4 = /TREF/ + SubfunctionIDTruncation(TxInf.OrgnlEndToEndId);(选填的)
 MTLine5 = SubfunctionChargeCalculation()
 MTLine2的取值逻辑：
 MXReasonCode = TxInf.RtrRsnInf.Rsn.Cd
 1.如果 MXReasonCode = NARR, MTLine2 等于 SubfunctionNARRSpecificScenario(MXAdditionalInformation)输出的MTReasonCode
 2.否则 MTLine2 = SubfunctionReasonCodeTranslation(MXReasonCode)
 3.如果 MXAdditionalInformation 长度大于 35 - MTLine2的长度，MTLine2 = MTLine2 + MXAdditionalInformation截取到29位，剩余的放在 MTLine6
 否则 MTLine2 = MTLine2 + MXAdditionalInformation
 */
public class Field72Generate extends AbstractMx2MtTagsGenerate {

    private static String name = "72";

    @Override
    public void tagGenerate() throws SwiftException {
        SwiftMessage swiftMessage = context.get(SwiftMessage.class);
        List<Tag> tags = swiftMessage.getBlock4().getTags();
        List<String> mt72List = new ArrayList<>();
        List<MxMtReasonCodeInfo> mxMtReasonCodeInfos = SwiftTransferUtil.getMxMtReasonCodes();
        String mxAddtlInf = "";
        int addtlInfCount = getXmlNodeCounts(bodyHdrParentElementName, document, "TxInf.RtrRsnInf.AddtlInf");
        if (addtlInfCount > 0) {
            mxAddtlInf = getXmlNodeValue(bodyHdrParentElementName, document, "TxInf.RtrRsnInf.AddtlInf(0)");
            if (addtlInfCount > 1) {
                for (int i=1; i<addtlInfCount; i++) {
                    if (i == 2) break; //最多只取2行数据
                    String tmpAddtlInf = getXmlNodeValue(bodyHdrParentElementName, document, "TxInf.RtrRsnInf.AddtlInf(" + i + ")");
                    if (mxAddtlInf.length() > 104) {
                        mxAddtlInf += tmpAddtlInf;
                    } else {
                        mxAddtlInf += " " + tmpAddtlInf;
                    }
                }
            }
        }
        mt72List.add("/RETN/99");
        String mtLine2 = "";
        String mtLine6 = "";
        String mxReasonCode = getXmlNodeValue(bodyHdrParentElementName, document, "TxInf.RtrRsnInf.Rsn.Cd");
        if (StringUtil.isNotEmpty(mxReasonCode)) {
            boolean isNARRSpecificScenario = false;
            if ("NARR".equals(mxReasonCode) && mxAddtlInf.length() >= 4) {
                String reasonCode = mxAddtlInf.substring(0, 4);
                if (reasonCode.matches("[0-9A-Z]{2}[0-9]{2}")) {
                    for (int i=0; i<mxMtReasonCodeInfos.size(); i++) {
                        if (reasonCode.equals(mxMtReasonCodeInfos.get(i).getMtCode())) {
                            isNARRSpecificScenario = true;
                            break;
                        }
                    }
                    if (reasonCode.matches("X[0-9A-Z]{1}[0-9]{2}")) {
                        isNARRSpecificScenario = true;
                    }
                }
                if (isNARRSpecificScenario) {
                    mtLine2 = "/" + reasonCode + "/";
                    if (mxAddtlInf.length() >= 5 && mxAddtlInf.substring(4, 5).equals("/")) {
                        mxAddtlInf = mxAddtlInf.substring(5);
                    } else {
                        mxAddtlInf = mxAddtlInf.substring(4);
                    }
                }
            }
            if (!isNARRSpecificScenario) {
                mtLine2 = subFunctionReasonCodeTranslation(mxReasonCode, mxMtReasonCodeInfos);
            }
            mtLine2 += mxAddtlInf;
            if (mtLine2.length() > 35) {
                mtLine6 = "/TEXT/" + mtLine2.substring(35);
                mtLine2 = mtLine2.substring(0, 35);
            }
        }
        if (StringUtil.isNotEmpty(mtLine2)) {
            mt72List.add(mtLine2);
        }
        String orgInstructionId = getXmlNodeValue(bodyHdrParentElementName, document, "TxInf.OrgnlInstrId");
        String mtLine3 = "/MREF/" + subFunctionIDTruncation(orgInstructionId);
        mt72List.add(mtLine3);
        String orgEndToEndId = getXmlNodeValue(bodyHdrParentElementName, document, "TxInf.OrgnlEndToEndId");
        if (StringUtil.isNotEmpty(orgEndToEndId)) {
            String mtLine4 = "/TREF/" + subFunctionIDTruncation(orgEndToEndId);
            mt72List.add(mtLine4);
        }
        String mtLine5 = subFunctionChargeCalculation(bodyHdrParentElementName + ".TxInf.ChrgsInf");
        if (StringUtil.isNotEmpty(mtLine5)) {
            mt72List.add(mtLine5);
        }
        if (StringUtil.isNotEmpty(mtLine6)) {
            mt72List.add(mtLine6);
        }
        if (mt72List.size() > 0) {
            List<String> list = new ArrayList<>();
            for (int i=0; i<mt72List.size(); i++) {
                String mt72FullField = mt72List.get(i);
                List<String> tmplist = StringUtil.outStringList(mt72FullField, 35, "//");
                list.addAll(tmplist);
            }
            String value = "";
            for (int i=0; i<list.size(); i++) {
                if (i == 6) break;
                if (i == 0) {
                    value = list.get(i);
                } else {
                    value += Mx2MtConstants.NEW_LINE + list.get(i);
                }
            }
            tags.add(new Tag(name, value));
        }
    }
}
