package com.brilliance.swift.mx2mt.mt210;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtCreator;
import com.brilliance.swift.mx2mt.Mx2MtContextIdentifier;
import com.brilliance.swift.mx2mt.Mx2MtTagsGenerate;
import com.brilliance.swift.mx2mt.mt210.impl.*;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.util.XmlUtil;
import com.prowidesoftware.swift.model.SwiftBlock3;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.field.Field121;
import org.dom4j.Document;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

public class Mx2Mt210Creator extends AbstractMx2MtCreator {

    @Override
    public void preProcess() {
        super.preProcess();
        Document document = (Document)context.get(Mx2MtContextIdentifier.MX_XMl_DOCUMENT, true);
        Map<String, String> parentElementMaps = XmlUtil.getParentElementMaps(document);
        context.set(Mx2MtContextIdentifier.APPHDR_PARENT_ELEMENT_NAME, parentElementMaps.get("AppHdr"));
        context.set(Mx2MtContextIdentifier.GRPHDR_PARENT_ELEMENT_NAME, parentElementMaps.get("GrpHdr"));
        context.set(Mx2MtContextIdentifier.BODY_PARENT_ELEMENT_NAME, parentElementMaps.get("Ntfctn"));
    }

    @Override
    public List<Mx2MtTagsGenerate> getGenerateTagList() {
        List<Mx2MtTagsGenerate> fieldsGenerateList = new ArrayList<>();
        fieldsGenerateList.add(new Field20Generate());
        fieldsGenerateList.add(new Field25Generate());
        fieldsGenerateList.add(new Field30Generate());
        fieldsGenerateList.add(new Field21Generate());
        fieldsGenerateList.add(new Field32BGenerate());
        fieldsGenerateList.add(new Field50aGenerate());
        fieldsGenerateList.add(new Field52aGenerate());
        fieldsGenerateList.add(new Field56aGenerate());

        return fieldsGenerateList;
    }
    @Override
    public void withBlock3() throws SwiftException {
        super.withBlock3();
        SwiftBlock3 block3 = context.get(SwiftMessage.class).getBlock3();
        Document document = (Document)context.get(Mx2MtContextIdentifier.MX_XMl_DOCUMENT, true);
        String bodyParentPath = (String)context.get(Mx2MtContextIdentifier.BODY_PARENT_ELEMENT_NAME, true);
        String uetr = getXmlNodeValue(bodyParentPath, document, "Ntfctn.Itm("+0+").UETR");
        if (StringUtil.isNotEmpty(uetr)) {
            Field121 field121 = new Field121(uetr);
            block3.builder().setField121(field121);
        }
    }

    @Override
    protected String getMtType() {
        return Mx2MtConstants.MT_TYPE_210;
    }
}
