package com.brilliance.swift.mx2mt.mt900910.impl;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtTagsGenerate;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.util.NumberUtil;
import com.brilliance.swift.util.StringUtil;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;

import javax.xml.datatype.DatatypeConfigurationException;
import javax.xml.datatype.DatatypeFactory;
import javax.xml.datatype.XMLGregorianCalendar;
import java.math.BigDecimal;
import java.util.List;

/**
 * <Ntfctn><Ntry><ValDt><Dt>
 * <Ntfctn><Ntry><Amt Ccy="XXX">
 */
public class Field32AGenerate extends AbstractMx2MtTagsGenerate {

    private static String name = "32A";

    @Override
    public void tagGenerate() throws SwiftException {
        try {
            SwiftMessage swiftMessage = context.get(SwiftMessage.class);
            List<Tag> tags = swiftMessage.getBlock4().getTags();
            String intrBkSttlmDtStr = "";
            String intrBkSttlmAmt = "";
            String intrBkSttlmccy = "";
            String intrBkSttlmDtValue = getXmlNodeValue(bodyHdrParentElementName, document, "Ntfctn.Ntry.ValDt.Dt");
            if (StringUtil.isEmpty(intrBkSttlmDtValue)) {
                intrBkSttlmDtValue = getXmlNodeValue(bodyHdrParentElementName, document, "Ntfctn.Ntry.NtryDtls.TxDtls.RltdDts.IntrBkSttlmDt");
            }
            if (StringUtil.isNotEmpty(intrBkSttlmDtValue)) {
                XMLGregorianCalendar intrBkSttlmDt = DatatypeFactory.newInstance().newXMLGregorianCalendar(intrBkSttlmDtValue);
                intrBkSttlmDtStr = DateUtil.format(intrBkSttlmDt, "yyMMdd");
            }
            String amt = getXmlNodeValue(bodyHdrParentElementName, document, "Ntfctn.Ntry.Amt");
            String ccy = getXmlNodeValue(bodyHdrParentElementName, document, "Ntfctn.Ntry.Amt@Ccy");
            if (StringUtil.isNotEmpty(amt) && StringUtil.isNotEmpty(ccy)) {
                intrBkSttlmAmt = NumberUtil.formatAmt(new BigDecimal(amt), ccy);
                intrBkSttlmccy = ccy;
            }
            tags.add(new Tag(name, intrBkSttlmDtStr+intrBkSttlmccy+intrBkSttlmAmt));
        } catch (DatatypeConfigurationException e) {
            throw new SwiftException("ERROR", e.getMessage());
        }

    }

}
