package com.brilliance.swift.mx2mt.mt940950.impl;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtTagsGenerate;
import com.brilliance.swift.mx2mt.Mx2MtContextIdentifier;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.util.NumberUtil;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.common.CdtDbtCode;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;

import javax.xml.datatype.DatatypeConfigurationException;
import javax.xml.datatype.DatatypeFactory;
import javax.xml.datatype.XMLGregorianCalendar;
import java.math.BigDecimal;
import java.util.List;

/**
 * <Stmt><Ntry>[j]<ValDt><Dt>
 * <Stmt><Ntry>[j]<BookgDt><Dt>
 * <Stmt><Ntry>[j]<CdtDbtInd>
 * <Stmt><Ntry>[j]<RvslInd>
 * <Stmt><Ntry>[j]<Sts>
 * <Stmt><Ntry>[j]<Amt Ccy=“XXX”>
 * <Stmt><Ntry>[j]<BkTxCd><Prtry><Cd>
 * <Stmt><Ntry>[j]<NtryDtls><TxDtls><Refs><EndToEndId>
 * <Stmt><Ntry>[j]<AcctSvcrRef>
 * <Stmt><Ntry>[j]<NtryDtls><TxDtls><AddtlTxInf>
 */
public class Field61Generate extends AbstractMx2MtTagsGenerate {

    private static String name_61 = "61";

    private static String name_86 = "86";

    @Override
    public void tagGenerate() throws SwiftException{
        try {
            SwiftMessage swiftMessage = context.get(SwiftMessage.class);
            List<Tag> tags = swiftMessage.getBlock4().getTags();
            int entryCount = getXmlNodeCounts(bodyHdrParentElementName, document, "Stmt.Ntry");
            if (entryCount > 0) {
                for (int i=0; i<entryCount; i++) {
                    String value = "";
                    String valueDateStr = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Ntry("+i+").ValDt.Dt");
                    if (StringUtil.isNotEmpty(valueDateStr)) {
                        XMLGregorianCalendar valueDate = DatatypeFactory.newInstance().newXMLGregorianCalendar(valueDateStr);
                        value += DateUtil.format(valueDate, "yyMMdd");
                    }
                    String bookDateStr = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Ntry("+i+").BookgDt.Dt");
                    if (StringUtil.isNotEmpty(bookDateStr)) {
                        XMLGregorianCalendar bookDate = DatatypeFactory.newInstance().newXMLGregorianCalendar(bookDateStr);
                        value += DateUtil.format(bookDate, "MMdd");
                    }
                    String reversalIndicator = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Ntry("+i+").RvslInd");
                    String creditDebitIndicator = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Ntry("+i+").CdtDbtInd");
                    if (StringUtil.isNotEmpty(reversalIndicator) && Boolean.valueOf(reversalIndicator)) {
                        if (CdtDbtCode.DBIT.value().equals(creditDebitIndicator)) {
                            value += "RC";
                        } else {
                            value += "RD";
                        }
                    } else {
                        if (CdtDbtCode.DBIT.value().equals(creditDebitIndicator)) {
                            value += "D";
                        } else {
                            value += "C";
                        }
                    }
                    String amt = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Ntry("+i+").Amt");
                    String ccy = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Ntry("+i+").Amt@Ccy");
                    if (StringUtil.isNotEmpty(amt) && StringUtil.isNotEmpty(ccy)) {
                        value += NumberUtil.formatAmt(new BigDecimal(amt), ccy);
                    }
                    value += "NTRF";
                    String endToEndId = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Ntry("+i+").NtryDtls.TxDtls.Refs.EndToEndId");
                    if (StringUtil.isNotEmpty(endToEndId)) {
                       /* if (endToEndId.length() > 16) {
                            endToEndId = endToEndId.substring(0, 15) + "+";
                        }*/ //邮储的版本前置需要950的61进行对账，需要完整的endToEndId
                        value += endToEndId;
                    } else {
                        value += Mx2MtConstants.MT_21_DEFAULT_VALUE;
                    }
                    String accountServicerReference = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Ntry("+i+").AcctSvcrRef");
                    if (StringUtil.isNotEmpty(accountServicerReference)) {
                        if (accountServicerReference.length() > 16) {
                            accountServicerReference = accountServicerReference.substring(0, 15) + "+";
                        }
                        value += "//" + accountServicerReference;
                    }
                    String additionalInformation = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Ntry("+i+").NtryDtls.TxDtls.AddtlTxInf");
                    if (StringUtil.isNotEmpty(additionalInformation)) {
                        if (additionalInformation.length() > 34) {
                            additionalInformation = additionalInformation.substring(0, 33) + "+";
                        }
                        value += Mx2MtConstants.NEW_LINE + additionalInformation;
                    }
                    tags.add(new Tag(name_61, value));

                    String additionalEntryInformation = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Ntry("+i+").AddtlNtryInf");
                    if (StringUtil.isNotEmpty(additionalEntryInformation)) {
                        if (additionalEntryInformation.length() > 390) {
                            additionalEntryInformation = additionalEntryInformation.substring(0, 389) + "+";
                        }
                        String value86 = StringUtil.getStringByEnter(additionalEntryInformation, 65, 6);
                        tags.add(new Tag(name_86, value86));
                        context.set(Mx2MtContextIdentifier.MT_TYPE_940_FLAG, Mx2MtConstants.YES);
                    }
                }
            }
        } catch (DatatypeConfigurationException e) {
            throw new SwiftException("ERROR", e.getMessage());
        }
    }
}
