package com.brilliance.swift.mx2mt.mt940950.impl;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtTagsGenerate;
import com.brilliance.swift.mx2mt.Mx2MtContextIdentifier;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.util.NumberUtil;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.common.BalanceTypeCode;
import com.brilliance.swift.vo.common.CdtDbtCode;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;

import javax.xml.datatype.DatatypeConfigurationException;
import javax.xml.datatype.DatatypeFactory;
import javax.xml.datatype.XMLGregorianCalendar;
import java.math.BigDecimal;
import java.util.List;

/**
 *
 */
public class Field65Generate extends AbstractMx2MtTagsGenerate {

    private static String name = "65";

    @Override
    public void tagGenerate() throws SwiftException{
        SwiftMessage swiftMessage = context.get(SwiftMessage.class);
        List<Tag> tags = swiftMessage.getBlock4().getTags();
        int balanceTypeCount = getXmlNodeCounts(bodyHdrParentElementName, document, "Stmt.Bal");
        if (balanceTypeCount > 0) {
            for (int i=0; i<balanceTypeCount; i++) {
                String balanceType = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Bal("+i+").Tp.CdOrPrtry.Cd");
                if (BalanceTypeCode.FWAV.value().equals(balanceType)) {
                    try {
                        String crdr = "";
                        String cdtDbtInd = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Bal("+i+").CdtDbtInd");
                        if (CdtDbtCode.CRDT.value().equals(cdtDbtInd)) {
                            crdr = "C";
                        } else {//if (CdtDbtCode.DBIT.value().equals(cdtDbtInd)) {
                            crdr = "D";
                        }
                        String balanceDate = "";
                        String dateStr = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Bal("+i+").Dt.Dt");
                        if (StringUtil.isNotEmpty(dateStr)) {
                            XMLGregorianCalendar date = DatatypeFactory.newInstance().newXMLGregorianCalendar(dateStr);
                            balanceDate = DateUtil.format(date, "yyMMdd");
                        }
                        String balanceAmt = "";
                        String balanceCcy = "";
                        String amt = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Bal("+i+").Amt");
                        String ccy = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Bal("+i+").Amt@Ccy");
                        if (StringUtil.isNotEmpty(amt) && StringUtil.isNotEmpty(ccy)) {
                            balanceAmt = NumberUtil.formatAmt(new BigDecimal(amt), ccy);
                            balanceCcy = ccy;
                        }
                        String value = crdr + balanceDate + balanceCcy + balanceAmt;
                        tags.add(new Tag(name, value));
                        context.set(Mx2MtContextIdentifier.MT_TYPE_940_FLAG, Mx2MtConstants.YES);
                    } catch (DatatypeConfigurationException e) {
                        throw new SwiftException("ERROR", e.getMessage());
                    }
                }
            }
        }
    }
}
