package com.brilliance.swift.mx2mt.mt941942.impl;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtTagsGenerate;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.util.NumberUtil;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.common.BalanceTypeCode;
import com.brilliance.swift.vo.common.CdtDbtCode;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;

import javax.xml.datatype.DatatypeConfigurationException;
import javax.xml.datatype.DatatypeFactory;
import javax.xml.datatype.XMLGregorianCalendar;
import java.math.BigDecimal;
import java.util.List;

/**

 */
public class Field60FGenerate extends AbstractMx2MtTagsGenerate {

    private static String name = "60F";

    @Override
    public void tagGenerate() throws SwiftException {
        SwiftMessage swiftMessage = context.get(SwiftMessage.class);
        List<Tag> tags = swiftMessage.getBlock4().getTags();
        int balanceTypeCount = getXmlNodeCounts(bodyHdrParentElementName, document, "Rpt.Bal");
        int index = -1;
        if (balanceTypeCount > 0) {
            for (int i=0; i<balanceTypeCount; i++) {
                String balanceType = getXmlNodeValue(bodyHdrParentElementName, document, "Rpt.Bal("+i+").Tp.CdOrPrtry.Cd");
                if (BalanceTypeCode.OPBD.value().equals(balanceType)) {
                    index = i;
                    break;
                }
            }
        }
        if (index > -1) {
            try {
                String crdr = "";
                String cdtDbtInd = getXmlNodeValue(bodyHdrParentElementName, document, "Rpt.Bal("+index+").CdtDbtInd");
                if (CdtDbtCode.CRDT.value().equals(cdtDbtInd)) {
                    crdr = "C";
                } else {//if (CdtDbtCode.DBIT.value().equals(cdtDbtInd)) {
                    crdr = "D";
                }
                String balanceDate = "";
                String dateStr = getXmlNodeValue(bodyHdrParentElementName, document, "Rpt.Bal("+index+").Dt.Dt");
                if (StringUtil.isNotEmpty(dateStr)) {
                    XMLGregorianCalendar date = DatatypeFactory.newInstance().newXMLGregorianCalendar(dateStr);
                    balanceDate = DateUtil.format(date, "yyMMdd");
                }
                String balanceAmt = "";
                String balanceCcy = "";
                String amt = getXmlNodeValue(bodyHdrParentElementName, document, "Rpt.Bal("+index+").Amt");
                String ccy = getXmlNodeValue(bodyHdrParentElementName, document, "Rpt.Bal("+index+").Amt@Ccy");
                if (StringUtil.isNotEmpty(amt) && StringUtil.isNotEmpty(ccy)) {
                    balanceAmt = NumberUtil.formatAmt(new BigDecimal(amt), ccy);
                    balanceCcy = ccy;
                }
                String value = crdr + balanceDate + balanceCcy + balanceAmt;
                tags.add(new Tag(name, value));
            } catch (DatatypeConfigurationException e) {
                throw new SwiftException("ERROR", e.getMessage());
            }
        }
    }
}
