package com.brilliance.swift.mx2swiftdto;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2swiftdto.bankcdbcdnf.Mx2SwiftDtoBTCDCNCreator;
import com.brilliance.swift.mx2swiftdto.bankcusta.Mx2SwiftDtoBTCSCreator;
import com.brilliance.swift.mx2swiftdto.custcdttsf.Mx2SwiftDtoCCTCreator;
import com.brilliance.swift.mx2swiftdto.fininstcdttsf.Mx2SwiftDtoFICTCreator;
import com.brilliance.swift.vo.SwiftDto;
import com.prowidesoftware.swift.model.mx.AbstractMX;
import org.dom4j.Document;
import org.dom4j.DocumentException;
import org.dom4j.DocumentHelper;

import java.util.Map;

public class Mx2SwiftDtoCreatorManager {

    private String msgType = "";

    private String version = "";

    private Object mxObj = null;

    private String xmlStr = "";

    public void init(String xmlStr) {
        AbstractMX abstractMX = AbstractMX.parse(xmlStr);
        msgType = (abstractMX.getMxId().getBusinessProcess().name()
                + "."
                + abstractMX.getMxId().getFunctionality()
                + "."
                + abstractMX.getMxId().getVariant())
                //+ abstractMX.getMxId().getVersion())
                .trim();
        mxObj = abstractMX;
        this.xmlStr = xmlStr;
        version = abstractMX.getMxId().getVersion();
    }

    public SwiftDto convert(String xmlStr, String outPutFilePath, Map<String, Object> extraMap) throws SwiftException {
        try {
            init(xmlStr);
            Mx2SwiftDtoContext context = new Mx2SwiftDtoContext();
            context.set(Mx2SwiftDtoContextIdentifier.MX_TO_SWIFTDTO_OUTPUT_FILE_PATH, outPutFilePath);
            context.putAll(extraMap);
            Document document = DocumentHelper.parseText(xmlStr);
            context.set(Mx2SwiftDtoContextIdentifier.MX_XMl_DOCUMENT, document);
            context.set(Mx2SwiftDtoContextIdentifier.MX_OBJ, mxObj);
            context.set(Mx2SwiftDtoContextIdentifier.MX_VERSION, version);
            context.set(Mx2SwiftDtoContextIdentifier.MX_MESSAGETYPE, msgType);
            AbstractMx2SwiftDtoCreator creator = getMx2SwiftDtoCreator(msgType);
            creator.setContext(context);
            creator.preProcess();
            creator.appHeader();
            creator.groupHeader();
            creator.messageBody();
            creator.postProcess();
            return (SwiftDto) context.get(Mx2SwiftDtoContextIdentifier.MX_TO_SWIFTDTO_OBJ);
        } catch (DocumentException e) {
            throw new SwiftException("ERROR", e.getMessage());
        }
    }

    public AbstractMx2SwiftDtoCreator getMx2SwiftDtoCreator(String msgType) throws SwiftException {
        if ("pacs.008.001".equals(msgType)) {
            return new Mx2SwiftDtoCCTCreator();
        } else if ("pacs.009.001".equals(msgType)){
            return new Mx2SwiftDtoFICTCreator();
        }else if("camt.054.001".equals(msgType)){
            return new Mx2SwiftDtoBTCDCNCreator();
        } else if("camt.053.001".equals(msgType)){
            return new Mx2SwiftDtoBTCSCreator();
        } else {
            throw new SwiftException("Invalid message type");
        }
    }
}
