package com.brilliance.swift.swiftdto2mt.mt940950.impl;


import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.swiftdto2mt.AbstractSwiftDto2MtTagGenerate;
import com.brilliance.swift.swiftdto2mt.SwiftDto2MtContextIdentifier;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.util.NumberUtil;
import com.brilliance.swift.vo.BankToCustomerStatement;
import com.brilliance.swift.vo.common.BalanceTypeCode;
import com.brilliance.swift.vo.common.CashBalance;
import com.brilliance.swift.vo.common.CcyFormatAmount;
import com.brilliance.swift.vo.common.CdtDbtCode;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;
import com.prowidesoftware.swift.model.mx.dic.CreditDebitCode;

import java.util.List;

import static com.brilliance.swift.constants.Mx2MtConstants.DRCRMARK_C;
import static com.brilliance.swift.constants.Mx2MtConstants.DRCRMARK_D;

public class Tag60aGenerate extends AbstractSwiftDto2MtTagGenerate {

    private String name_F = "60F";

    private String name_M = "60M";

    @Override
    public void tagGenerate() throws SwiftException {
        try {
            BankToCustomerStatement bankToCustomerStatement = (BankToCustomerStatement)context.get(SwiftDto2MtContextIdentifier.SWIFT_DTO_OBJ, true);
            SwiftMessage swiftMessage = context.get(SwiftMessage.class);
            List<Tag> tags = swiftMessage.getBlock4().getTags();
            CashBalance openingBalance = bankToCustomerStatement.getOpeningBalance();
            if(openingBalance != null){
                String value = "";
                String dcMark = "";
                if(CdtDbtCode.CRDT.equals(openingBalance.getCdtDbtCode())){
                    dcMark = DRCRMARK_C;
                }else if(CreditDebitCode.DBIT.equals(openingBalance.getCdtDbtCode())){
                    dcMark = DRCRMARK_D;
                }
                String dateStr = "";
                if (openingBalance.getDate() != null) {
                    dateStr = DateUtil.format(openingBalance.getDate(), "yyMMdd");
                }
                CcyFormatAmount ccyFormatAmount = openingBalance.getAmt();
                String ccy = "";
                String amtStr = "";
                if (ccyFormatAmount != null) {
                    ccy = ccyFormatAmount.getCcy();
                    amtStr = NumberUtil.formatAmt(ccyFormatAmount.getAmt(), ccyFormatAmount.getCcy());
                }
                value = dcMark + dateStr + ccy + amtStr;
                if (BalanceTypeCode.PRCD.equals(openingBalance.getCode())) {
                    tags.add(new Tag(name_F, value));
                } else if (BalanceTypeCode.ITBD.equals(openingBalance.getCode())) {
                    tags.add(new Tag(name_M, value));
                }
            }
        }catch (Exception e){
            throw new SwiftException("ERROR", e.getMessage());
        }
    }
}
