package com.brilliance.swift.swiftdto2mx.camt053001.v08;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.swiftdto2mx.AbstractSwiftDto2MxCreator;
import com.brilliance.swift.swiftdto2mx.SwiftDto2MxContextIdentifier;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.BankToCustomerStatement;
import com.brilliance.swift.vo.SwiftHeader;
import com.brilliance.swift.vo.common.*;
import com.prowidesoftware.swift.model.mx.BusinessAppHdrV02;
import com.prowidesoftware.swift.model.mx.MxCamt05300108;
import com.prowidesoftware.swift.model.mx.dic.*;

import javax.xml.datatype.XMLGregorianCalendar;
import java.io.File;
import java.math.BigDecimal;
import java.util.List;

/**
 * @author zh
 * @create 2022-04-26 11:44
 */
public class SwiftDto2MxCamt053001Creator extends AbstractSwiftDto2MxCreator {
    @Override
    public void create() throws SwiftException {
        try {
            BankToCustomerStatement bankToCustomerStatement = (BankToCustomerStatement)context.get(SwiftDto2MxContextIdentifier.SWIFT_DTO_OBJ, true);
            if (bankToCustomerStatement == null) {
                return;
            }
            SwiftHeader swiftHeader = bankToCustomerStatement.getSwiftHeader();
            MxCamt05300108 mxCamt05300108 = new MxCamt05300108();
            //set AppHdr
            BusinessAppHdrV02 businessAppHdrV02 = new BusinessAppHdrV02();
            //fr
            Party44Choice fr = new Party44Choice();
            BranchAndFinancialInstitutionIdentification6 fiId = new BranchAndFinancialInstitutionIdentification6();
            FinancialInstitutionIdentification18 finInstnId = new FinancialInstitutionIdentification18();
            finInstnId.setBICFI(swiftHeader.getSenderBic());
            fiId.setFinInstnId(finInstnId);
            fr.setFIId(fiId);
            businessAppHdrV02.setFr(fr);
            //to
            Party44Choice to = new Party44Choice();
            BranchAndFinancialInstitutionIdentification6 toFiId = new BranchAndFinancialInstitutionIdentification6();
            FinancialInstitutionIdentification18 toFinInstnId = new FinancialInstitutionIdentification18();
            toFinInstnId.setBICFI(swiftHeader.getReceiverBic());
            toFiId.setFinInstnId(toFinInstnId);
            to.setFIId(toFiId);
            businessAppHdrV02.setTo(to);
            //
            XMLGregorianCalendar creDt = DateUtil.parseXMLGregorianCalendar(swiftHeader.getCreateDate());
            businessAppHdrV02.setCreDt(creDt);

            if (MessagePriority.NORM.equals(swiftHeader.getMessagePriority())) {
                businessAppHdrV02.setPrty(Priority2Code.NORM.value());
            } else if (MessagePriority.HIGH.equals(swiftHeader.getMessagePriority())) {
                businessAppHdrV02.setPrty(Priority2Code.HIGH.value());
            }
            businessAppHdrV02.setMsgDefIdr(swiftHeader.getMessageDefId());
            businessAppHdrV02.setBizMsgIdr(swiftHeader.getMessageId());
            businessAppHdrV02.setBizSvc(swiftHeader.getBusinessService());
            mxCamt05300108.setAppHdr(businessAppHdrV02);
            //grpHdr
            BankToCustomerStatementV08 bkToCstmrStmt = new BankToCustomerStatementV08();
            mxCamt05300108.setBkToCstmrStmt(bkToCstmrStmt);
            GroupHeader81 grpHdr = new GroupHeader81();
            grpHdr.setMsgId(swiftHeader.getMessageId());
            grpHdr.setCreDtTm(DateUtil.parseXMLGregorianCalendar(swiftHeader.getCreateDate()));
            bkToCstmrStmt.setGrpHdr(grpHdr);
            //AccountStatement
            AccountStatement9 stmt = new AccountStatement9();
            bkToCstmrStmt.addStmt(stmt);

            PartyAccount partyAccount = bankToCustomerStatement.getAccount();
            String pgNb = bankToCustomerStatement.getPgNb();
            String elctrncSeqNb = bankToCustomerStatement.getElctrncSeqNb();
            CashBalance openingBalance = bankToCustomerStatement.getOpeningBalance();
            if (openingBalance != null) {
                stmt.addBal(convertCashBalance8(openingBalance));
            }
            CashBalance closingBalance = bankToCustomerStatement.getClosingBalance();
            if (closingBalance != null) {
                stmt.addBal(convertCashBalance8(closingBalance));
            }
            CashBalance closingAvailableBalance = bankToCustomerStatement.getClosingAvailableBalance();
            if (closingAvailableBalance != null) {
                stmt.addBal(convertCashBalance8(closingAvailableBalance));
            }
            List<CashBalance> forwardAvailableBalances = bankToCustomerStatement.getForwardAvailableBalances();
            if (forwardAvailableBalances.size() > 0) {
                for(CashBalance forwardAvailableBalance : forwardAvailableBalances) {
                    stmt.addBal(convertCashBalance8(forwardAvailableBalance));
                }
            }
            if(partyAccount != null){
                String ibanAcct = partyAccount.getIbanAcct();
                String account = partyAccount.getAccount();
                if (StringUtil.isNotEmpty(ibanAcct) || StringUtil.isNotEmpty(account)) {
                    CashAccount39 cashAccount39 = new CashAccount39();
                    cashAccount39.setCcy(partyAccount.getAcctCcy());
                    cashAccount39.setNm(partyAccount.getAcctName());
                    AccountIdentification4Choice id = new AccountIdentification4Choice();
                    if (StringUtil.isNotEmpty(account)) {
                        GenericAccountIdentification1 othr = new GenericAccountIdentification1();
                        othr.setId(account);
                        AcctSchemeType acctSehemeType = partyAccount.getAcctSehemeType();
                        if (acctSehemeType != null) {
                            AccountSchemeName1Choice schmeNm = new AccountSchemeName1Choice();
                            if (acctSehemeType.getCode() != null) {
                                schmeNm.setCd(acctSehemeType.getCode().value());
                            }
                            schmeNm.setPrtry(acctSehemeType.getProprietary());
                            othr.setSchmeNm(schmeNm);
                        }
                        id.setOthr(othr);
                    }
                    if (StringUtil.isNotEmpty(ibanAcct)) {
                        id.setIBAN(ibanAcct);
                    }
                    cashAccount39.setId(id);
                    AcctType acctType = partyAccount.getAcctType();
                    if (acctType != null) {
                        CashAccountType2Choice tp = new CashAccountType2Choice();
                        if (acctType.getCode() != null) {
                            tp.setCd(acctType.getCode().value());
                        }
                        tp.setPrtry(acctType.getProprietary());
                        cashAccount39.setTp(tp);
                    }
                    stmt.setAcct(cashAccount39);
                }
            }
            if(StringUtil.isNotEmpty(pgNb)){
                Pagination1 msgPgntn = new Pagination1();
                grpHdr.setMsgPgntn(msgPgntn);
                msgPgntn.setPgNb(pgNb);
            }
            if(StringUtil.isNotEmpty(elctrncSeqNb)){
                stmt.setElctrncSeqNb(new BigDecimal(elctrncSeqNb));
            }
            List<ReportEntry> reportEntries = bankToCustomerStatement.getReportEntries();
            if(reportEntries.size()>0){
                for (int i = 0; i < reportEntries.size(); i++) {
                    ReportEntry reportEntry = reportEntries.get(i);
                    ReportEntry10 ntry = new ReportEntry10();
                    stmt.addNtry(ntry);
                    DateAndDateTime2Choice valDt = new DateAndDateTime2Choice();
                    ntry.setValDt(valDt);
                    XMLGregorianCalendar dt1 = DateUtil.parseXMLGregorianCalendar(reportEntry.getValueDate());
                    valDt.setDt(dt1);
                    DateAndDateTime2Choice bookgDt = new DateAndDateTime2Choice();
                    ntry.setBookgDt(bookgDt);
                    XMLGregorianCalendar dt2 = DateUtil.parseXMLGregorianCalendar(reportEntry.getBookDate());
                    bookgDt.setDt(dt2);
                    if (reportEntry.getCdtDbtCode() != null) {
                        ntry.setCdtDbtInd(CreditDebitCode.valueOf(reportEntry.getCdtDbtCode().value()));
                    }
                    System.out.println(reportEntry.getReversalIndicator());
                    ntry.setRvslInd(reportEntry.getReversalIndicator());
                    CcyFormatAmount ccyFormatAmount = reportEntry.getAmt();
                    if (ccyFormatAmount != null) {
                        ActiveOrHistoricCurrencyAndAmount amt = new ActiveOrHistoricCurrencyAndAmount();
                        amt.setValue(ccyFormatAmount.getAmt());
                        amt.setCcy(ccyFormatAmount.getCcy());
                        ntry.setAmt(amt);
                    }
                    BankTransactionCodeStructure bankTransactionCodeStructure = reportEntry.getBankTransactionCodeStructure();
                    if (bankTransactionCodeStructure != null) {
                        BankTransactionCodeStructure4 bkTxCd = new BankTransactionCodeStructure4();
                        if (StringUtil.isNotEmpty(bankTransactionCodeStructure.getDomianCode())
                            && StringUtil.isNotEmpty(bankTransactionCodeStructure.getFamilyCode())
                                && StringUtil.isNotEmpty(bankTransactionCodeStructure.getSubFamilyCode())){
                            BankTransactionCodeStructure5 domn = new BankTransactionCodeStructure5();
                            domn.setCd(bankTransactionCodeStructure.getDomianCode());
                            BankTransactionCodeStructure6 fmly = new BankTransactionCodeStructure6();
                            fmly.setCd(bankTransactionCodeStructure.getFamilyCode());
                            fmly.setSubFmlyCd(bankTransactionCodeStructure.getSubFamilyCode());
                            domn.setFmly(fmly);
                            bkTxCd.setDomn(domn);
                        }
                        if (StringUtil.isNotEmpty(bankTransactionCodeStructure.getCode())
                                || StringUtil.isNotEmpty(bankTransactionCodeStructure.getIssuer())){
                            ProprietaryBankTransactionCodeStructure1 prtry = new ProprietaryBankTransactionCodeStructure1();
                            prtry.setCd(bankTransactionCodeStructure.getCode());
                            prtry.setIssr(bankTransactionCodeStructure.getIssuer());
                            bkTxCd.setPrtry(prtry);
                        }
                        ntry.setBkTxCd(bkTxCd);
                    }
                    EntryDetails9 ntryDtls = new EntryDetails9();
                    ntry.addNtryDtls(ntryDtls);
                    EntryTransaction10 txDtls = new EntryTransaction10();
                    ntryDtls.addTxDtls(txDtls);
                    TransactionReferences6 refs = new TransactionReferences6();
                    TransactionReference txnRef = bankToCustomerStatement.getTxnRef();
                    if (txnRef != null) {
                        refs.setUETR(txnRef.getUetr());
                    }
                    refs.setEndToEndId(reportEntry.getEndToEndId());
                    txDtls.setRefs(refs);
                    ntry.setAcctSvcrRef(reportEntry.getAcctSvcrRef());
                    txDtls.setAddtlTxInf(reportEntry.getAddtlTxInf());
                    ntry.setAddtlNtryInf(reportEntry.getAddtlNtryInf());
                }
            }
            stmt.setAddtlStmtInf(bankToCustomerStatement.getAdditionalStatementInformation());

            String xmlStr = mxCamt05300108.message();
            context.set(SwiftDto2MxContextIdentifier.MX_XML, xmlStr);
            String outputFilePath = (String)context.get(SwiftDto2MxContextIdentifier.MX_OUTPUT_FILE_PATH, true);
            if (StringUtil.isNotEmpty(outputFilePath)) {
                mxCamt05300108.write(new File(outputFilePath));
            }
        } catch (Exception e) {
            throw new SwiftException("ERROR", e.getMessage());
        }

    }
}
