package com.brilliance.swift.swiftdto2mx.pacs009001.v09;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.swiftdto2mx.AbstractSwiftDto2MxCreator;
import com.brilliance.swift.swiftdto2mx.SwiftDto2MxContextIdentifier;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.SwiftHeader;
import com.brilliance.swift.vo.VoCustomerCreditTransfer;
import com.brilliance.swift.vo.VoFinancialInstitutionCreditTransfer;
import com.brilliance.swift.vo.common.*;
import com.prowidesoftware.swift.model.mx.BusinessAppHdrV02;
import com.prowidesoftware.swift.model.mx.MxPacs00900109;
import com.prowidesoftware.swift.model.mx.dic.*;

import javax.xml.datatype.DatatypeConfigurationException;
import javax.xml.datatype.XMLGregorianCalendar;
import java.io.File;
import java.io.IOException;
import java.text.ParseException;

public class SwiftDto2MxPacs009001Creator extends AbstractSwiftDto2MxCreator {
    @Override
    public void create() throws SwiftException {
        try {
            VoFinancialInstitutionCreditTransfer financialInstitutionCreditTransfer = (VoFinancialInstitutionCreditTransfer)context.get(SwiftDto2MxContextIdentifier.SWIFT_DTO_OBJ, true);
            if (financialInstitutionCreditTransfer == null) {
                return;
            }
            MxPacs00900109 mxPacs00900109 = new MxPacs00900109();
            PartyDto instructingReimbursementParty = financialInstitutionCreditTransfer.getInstgAgtParty();//53
            PartyDto instructedReimbursementParty = financialInstitutionCreditTransfer.getInstdAgtParty();//54
            PartyDto dbtrParty = financialInstitutionCreditTransfer.getDebitParty();//52
            PartyDto intrmyAgt1Party = financialInstitutionCreditTransfer.getIntrmyAgtParty();//56
            PartyDto cdtrAgtParty = financialInstitutionCreditTransfer.getCreditAgtParty();//57
            PartyDto cdtrParty = financialInstitutionCreditTransfer.getCreditParty();//58
            //set AppHdr
            SwiftHeader swiftHeader = financialInstitutionCreditTransfer.getSwiftHeader();
            BusinessAppHdrV02 businessAppHdrV02 = new BusinessAppHdrV02();
            Party44Choice fr = new Party44Choice();
            BranchAndFinancialInstitutionIdentification6 frFiId = new BranchAndFinancialInstitutionIdentification6();
            FinancialInstitutionIdentification18 frFinInstnId = new FinancialInstitutionIdentification18();
            frFinInstnId.setBICFI(swiftHeader.getSenderBic());
            frFiId.setFinInstnId(frFinInstnId);
            fr.setFIId(frFiId);
            businessAppHdrV02.setFr(fr);

            Party44Choice to = new Party44Choice();
            BranchAndFinancialInstitutionIdentification6 toFiId = new BranchAndFinancialInstitutionIdentification6();
            FinancialInstitutionIdentification18 toFinInstnId = new FinancialInstitutionIdentification18();
            toFinInstnId.setBICFI(swiftHeader.getSenderBic());
            toFiId.setFinInstnId(toFinInstnId);
            to.setFIId(toFiId);
            businessAppHdrV02.setTo(to);

            XMLGregorianCalendar creDt = DateUtil.parseXMLGregorianCalendar(swiftHeader.getCreateDate());
            businessAppHdrV02.setCreDt(creDt);

            if (MessagePriority.NORM.equals(swiftHeader.getMessagePriority())) {
                businessAppHdrV02.setPrty(Priority2Code.NORM.value());
            } else if (MessagePriority.HIGH.equals(swiftHeader.getMessagePriority())) {
                businessAppHdrV02.setPrty(Priority2Code.HIGH.value());
            }
            businessAppHdrV02.setMsgDefIdr(swiftHeader.getMessageDefId());
            businessAppHdrV02.setBizMsgIdr(swiftHeader.getMessageId());
            businessAppHdrV02.setBizSvc(swiftHeader.getBusinessService());
            mxPacs00900109.setAppHdr(businessAppHdrV02);
            FinancialInstitutionCreditTransferV09 fiCdtTrf = new FinancialInstitutionCreditTransferV09();
            mxPacs00900109.setFICdtTrf(fiCdtTrf);
            //set GroupHeader
            GroupHeader93 grpHdr = new GroupHeader93();
            grpHdr.setMsgId(swiftHeader.getMessageId());
            grpHdr.setCreDtTm(DateUtil.parseXMLGregorianCalendar(swiftHeader.getCreateDate()));
            grpHdr.setNbOfTxs("1");
            SettlementInstruction7 sttlmInf = new SettlementInstruction7();
            sttlmInf.setSttlmMtd(SettlementMethod1Code.INDA);
            if (instructingReimbursementParty != null) {
                BranchAndFinancialInstitutionIdentification6 instgRmbrsmntAgt = partyDtoConvertAgt(instructingReimbursementParty);
                sttlmInf.setInstgRmbrsmntAgt(instgRmbrsmntAgt);
                CashAccount38 instgRmbrsmntAgtAcct = partyDtoConvertAgtAccount(instructingReimbursementParty.getPartyAcct());
                sttlmInf.setInstgRmbrsmntAgtAcct(instgRmbrsmntAgtAcct);
            }
            if (instructedReimbursementParty != null) {
                BranchAndFinancialInstitutionIdentification6 instdRmbrsmntAgt = partyDtoConvertAgt(instructedReimbursementParty);
                sttlmInf.setInstdRmbrsmntAgt(instdRmbrsmntAgt);
                CashAccount38 instdRmbrsmntAgtAcct = partyDtoConvertAgtAccount(instructedReimbursementParty.getPartyAcct());
                sttlmInf.setInstdRmbrsmntAgtAcct(instdRmbrsmntAgtAcct);
            }
            grpHdr.setSttlmInf(sttlmInf);
            fiCdtTrf.setGrpHdr(grpHdr);
            //set CdtTrfTxInf
            CreditTransferTransaction44 cdtTrfTxInf = new CreditTransferTransaction44();
            fiCdtTrf.addCdtTrfTxInf(cdtTrfTxInf);
            //PmtId
            TransactionReference txnRef = financialInstitutionCreditTransfer.getTxnRef();
            PaymentIdentification13 pmtId = new PaymentIdentification13();
            pmtId.setInstrId(txnRef.getInstructionId());
            pmtId.setEndToEndId(txnRef.getEndToEndId());
            pmtId.setUETR(txnRef.getUetr());
            cdtTrfTxInf.setPmtId(pmtId);
            //SttlmTmIndctn SttlmTmReq
            SettlementDateTimeIndication1 sttlmTmIndctn = null;
            XMLGregorianCalendar debitDt = DateUtil.parseXMLGregorianCalendar(financialInstitutionCreditTransfer.getDebitDate());
            if (debitDt != null) {
                if (sttlmTmIndctn == null) {
                    sttlmTmIndctn = new SettlementDateTimeIndication1();
                }
                sttlmTmIndctn.setDbtDtTm(debitDt);
            }
            XMLGregorianCalendar creditDt = DateUtil.parseXMLGregorianCalendar(financialInstitutionCreditTransfer.getCreditDate());
            if (creditDt != null) {
                if (sttlmTmIndctn == null) {
                    sttlmTmIndctn = new SettlementDateTimeIndication1();
                }
                sttlmTmIndctn.setCdtDtTm(creditDt);
            }
            cdtTrfTxInf.setSttlmTmIndctn(sttlmTmIndctn);

            SettlementTimeRequest2 sttlmTmReq = null;
            XMLGregorianCalendar clsDt = DateUtil.parseXMLGregorianCalendar(financialInstitutionCreditTransfer.getClsDate());
            if (clsDt != null) {
                sttlmTmReq = new SettlementTimeRequest2();
                sttlmTmReq.setCLSTm(clsDt);
            }
            cdtTrfTxInf.setSttlmTmReq(sttlmTmReq);

            //IntrBkSttlmAmt
            CcyFormatAmount settledCfa = financialInstitutionCreditTransfer.getSettledCcyFormatAmount();
            if (settledCfa != null) {
                ActiveCurrencyAndAmount intrBkSttlmAmt = new ActiveCurrencyAndAmount();
                intrBkSttlmAmt.setCcy(settledCfa.getCcy());
                intrBkSttlmAmt.setValue(settledCfa.getAmt());
                cdtTrfTxInf.setIntrBkSttlmAmt(intrBkSttlmAmt);
            }

            //IntrBkSttlmDt
            XMLGregorianCalendar xmlValueDate = DateUtil.parseXMLGregorianCalendar(financialInstitutionCreditTransfer.getSettledDate());
            if (xmlValueDate != null) {
                cdtTrfTxInf.setIntrBkSttlmDt(xmlValueDate);
            }

            //Dbtr DbtrAcct
            if (dbtrParty != null) {
                BranchAndFinancialInstitutionIdentification6 dbtr = partyDtoConvertAgt(dbtrParty);
                cdtTrfTxInf.setDbtr(dbtr);
                CashAccount38 dbtrAcct = partyDtoConvertAgtAccount(dbtrParty.getPartyAcct());
                cdtTrfTxInf.setDbtrAcct(dbtrAcct);
            }

            //IntrmyAgt1 IntrmyAgt1Acct
            if (intrmyAgt1Party != null) {
                BranchAndFinancialInstitutionIdentification6 intrmyAgt1 = partyDtoConvertAgt(intrmyAgt1Party);
                cdtTrfTxInf.setIntrmyAgt1(intrmyAgt1);
                CashAccount38 intrmyAgt1Acct = partyDtoConvertAgtAccount(intrmyAgt1Party.getPartyAcct());
                cdtTrfTxInf.setIntrmyAgt1Acct(intrmyAgt1Acct);
            }

            //CdtrAgt CdtrAgtAcct
            if (cdtrAgtParty != null) {
                BranchAndFinancialInstitutionIdentification6 cdtrAgt = partyDtoConvertAgt(cdtrAgtParty);
                cdtTrfTxInf.setCdtrAgt(cdtrAgt);
                CashAccount38 cdtrAgtAcct = partyDtoConvertAgtAccount(cdtrAgtParty.getPartyAcct());
                cdtTrfTxInf.setCdtrAgtAcct(cdtrAgtAcct);
            }

            //Cdtr CdtrAcct
            if (cdtrParty != null) {
                BranchAndFinancialInstitutionIdentification6 cdtr = partyDtoConvertAgt(cdtrParty);
                cdtTrfTxInf.setCdtr(cdtr);
                CashAccount38 cdtrAcct = partyDtoConvertAgtAccount(cdtrParty.getPartyAcct());
                cdtTrfTxInf.setCdtrAcct(cdtrAcct);
            }

            //PrvsInstgAgt1 InstrForCdtrAgt InstrForNxtAgt
            PartyDto preInstgAgtPartyDto = financialInstitutionCreditTransfer.getPreInstgAgtParty();
            if (preInstgAgtPartyDto != null) {
                BranchAndFinancialInstitutionIdentification6 prvsInstgAgt1 = new BranchAndFinancialInstitutionIdentification6();
                FinancialInstitutionIdentification18 finInstnId = new FinancialInstitutionIdentification18();
                finInstnId.setBICFI(preInstgAgtPartyDto.getPartyBic());
                finInstnId.setNm(preInstgAgtPartyDto.getPartyName());
                prvsInstgAgt1.setFinInstnId(finInstnId);
                cdtTrfTxInf.setPrvsInstgAgt1(prvsInstgAgt1);
            }
            InstructionForCreditAgent instForCrdAgt = financialInstitutionCreditTransfer.getInstForCrdAgt();
            if (instForCrdAgt != null) {
                InstructionForCreditorAgent3 instructionForCreditorAgent3 = new InstructionForCreditorAgent3();
                instructionForCreditorAgent3.setCd(instForCrdAgt.getCode().value());
                instructionForCreditorAgent3.setInstrInf(instForCrdAgt.getInstrInf());
                cdtTrfTxInf.addInstrForCdtrAgt(instructionForCreditorAgent3);
            }
            InstructionForNextAgent instForNxtAgt = financialInstitutionCreditTransfer.getInstForNxtAgt();
            if (instForNxtAgt != null) {
                InstructionForNextAgent1 instructionForNextAgent1 = new InstructionForNextAgent1();
                instructionForNextAgent1.setCd(instForNxtAgt.getCode());
                instructionForNextAgent1.setInstrInf(instForNxtAgt.getInstrInf());
                cdtTrfTxInf.addInstrForNxtAgt(instructionForNextAgent1);
            }
            //cover
            VoCustomerCreditTransfer customerCreditTransfer = financialInstitutionCreditTransfer.getUnderCustomerCreditTransfer();
            if (customerCreditTransfer != null) {
                CreditTransferTransaction45 undrlygCstmrCdtTrf = new CreditTransferTransaction45();
                cdtTrfTxInf.setUndrlygCstmrCdtTrf(undrlygCstmrCdtTrf);
                PartyDto underDbtrParty = customerCreditTransfer.getDebitParty();//50
                PartyDto underDbtrAgtParty = customerCreditTransfer.getDebitAgtParty();//52
                PartyDto underIntrmyAgt1Party = customerCreditTransfer.getIntrmyAgtParty();//56
                PartyDto underCdtrAgtParty = customerCreditTransfer.getCreditAgtParty();//57
                PartyDto underCdtrParty = customerCreditTransfer.getCreditParty();//59

                //InstdAmt
                CcyFormatAmount instructedCfa = customerCreditTransfer.getInstructedCcyFormatAmount();
                if (instructedCfa != null) {
                    ActiveOrHistoricCurrencyAndAmount instdAmt = new ActiveOrHistoricCurrencyAndAmount();
                    instdAmt.setCcy(instructedCfa.getCcy());
                    instdAmt.setValue(instructedCfa.getAmt());
                    undrlygCstmrCdtTrf.setInstdAmt(instdAmt);
                }

                //Dbtr DbtrAcct
                if (underDbtrParty != null) {
                    PartyIdentification135 dbtr = partyDtoConvertTr(underDbtrParty);
                    undrlygCstmrCdtTrf.setDbtr(dbtr);
                    CashAccount38 dbtrAcct = partyDtoConvertAgtAccount(underDbtrParty.getPartyAcct());
                    undrlygCstmrCdtTrf.setDbtrAcct(dbtrAcct);
                }

                //DbtrAgt DbtrAgtAcct
                if (underDbtrAgtParty != null) {
                    BranchAndFinancialInstitutionIdentification6 dbtrAgt = partyDtoConvertAgt(underDbtrAgtParty);
                    undrlygCstmrCdtTrf.setDbtrAgt(dbtrAgt);
                    CashAccount38 dbtrAgtAcct = partyDtoConvertAgtAccount(underDbtrAgtParty.getPartyAcct());
                    undrlygCstmrCdtTrf.setDbtrAgtAcct(dbtrAgtAcct);
                }

                //IntrmyAgt1 IntrmyAgt1Acct
                if (underIntrmyAgt1Party != null) {
                    BranchAndFinancialInstitutionIdentification6 intrmyAgt1 = partyDtoConvertAgt(underIntrmyAgt1Party);
                    undrlygCstmrCdtTrf.setIntrmyAgt1(intrmyAgt1);
                    CashAccount38 intrmyAgt1Acct = partyDtoConvertAgtAccount(underIntrmyAgt1Party.getPartyAcct());
                    undrlygCstmrCdtTrf.setIntrmyAgt1Acct(intrmyAgt1Acct);
                }

                //CdtrAgt CdtrAgtAcct
                if (underCdtrAgtParty != null) {
                    BranchAndFinancialInstitutionIdentification6 cdtrAgt = partyDtoConvertAgt(underCdtrAgtParty);
                    undrlygCstmrCdtTrf.setCdtrAgt(cdtrAgt);
                    CashAccount38 cdtrAgtAcct = partyDtoConvertAgtAccount(underCdtrAgtParty.getPartyAcct());
                    undrlygCstmrCdtTrf.setCdtrAgtAcct(cdtrAgtAcct);
                }

                //Cdtr CdtrAcct
                if (underCdtrParty != null) {
                    PartyIdentification135 cdtr = partyDtoConvertTr(underCdtrParty);
                    undrlygCstmrCdtTrf.setCdtr(cdtr);
                    CashAccount38 cdtrAcct = partyDtoConvertAgtAccount(underCdtrParty.getPartyAcct());
                    undrlygCstmrCdtTrf.setCdtrAcct(cdtrAcct);
                }
                //RmtInf
                RemittanceInformation remittanceInfo1 = customerCreditTransfer.getRemittanceInfo();
                if (remittanceInfo1 != null && remittanceInfo1.getUnstructured().size() > 0) {
                    RemittanceInformation16 rmtInf = new RemittanceInformation16();
                    for (String remittanceInfo : remittanceInfo1.getUnstructured()) {
                        rmtInf.addUstrd(remittanceInfo);
                    }
                    undrlygCstmrCdtTrf.setRmtInf(rmtInf);
                }
                //PrvsInstgAgt1 InstrForCdtrAgt InstrForNxtAgt
                PartyDto underPreInstgAgtPartyDto = customerCreditTransfer.getPreInstgAgtParty();
                if (underPreInstgAgtPartyDto != null) {
                    BranchAndFinancialInstitutionIdentification6 prvsInstgAgt1 = new BranchAndFinancialInstitutionIdentification6();
                    FinancialInstitutionIdentification18 finInstnId = new FinancialInstitutionIdentification18();
                    finInstnId.setBICFI(underPreInstgAgtPartyDto.getPartyBic());
                    finInstnId.setNm(underPreInstgAgtPartyDto.getPartyName());
                    prvsInstgAgt1.setFinInstnId(finInstnId);
                    undrlygCstmrCdtTrf.setPrvsInstgAgt1(prvsInstgAgt1);
                }
                InstructionForCreditAgent underInstForCrdAgt = customerCreditTransfer.getInstForCrdAgt();
                if (underInstForCrdAgt != null) {
                    InstructionForCreditorAgent3 instructionForCreditorAgent3 = new InstructionForCreditorAgent3();
                    instructionForCreditorAgent3.setCd(underInstForCrdAgt.getCode().value());
                    instructionForCreditorAgent3.setInstrInf(underInstForCrdAgt.getInstrInf());
                    undrlygCstmrCdtTrf.addInstrForCdtrAgt(instructionForCreditorAgent3);
                }
                InstructionForNextAgent underInstForNxtAgt = customerCreditTransfer.getInstForNxtAgt();
                if (underInstForNxtAgt != null) {
                    InstructionForNextAgent1 instructionForNextAgent1 = new InstructionForNextAgent1();
                    instructionForNextAgent1.setCd(underInstForNxtAgt.getCode());
                    instructionForNextAgent1.setInstrInf(underInstForNxtAgt.getInstrInf());
                    undrlygCstmrCdtTrf.addInstrForNxtAgt(instructionForNextAgent1);
                }
            }


            String xmlStr = mxPacs00900109.message();
            context.set(SwiftDto2MxContextIdentifier.MX_XML, xmlStr);
            String outputFilePath = (String)context.get(SwiftDto2MxContextIdentifier.MX_OUTPUT_FILE_PATH, true);
            if (StringUtil.isNotEmpty(outputFilePath)) {
                mxPacs00900109.write(new File(outputFilePath));
            }
        } catch (ParseException | DatatypeConfigurationException | IOException e) {
            throw new SwiftException("ERROR", e.getMessage());
        }
    }
}
