package com.brilliance.swift.util;

import com.brilliance.swift.exception.SwiftException;

import java.io.IOException;
import java.io.InputStream;
import java.math.BigDecimal;
import java.text.DecimalFormat;
import java.text.FieldPosition;
import java.util.Properties;


public class NumberUtil {

    private static Properties properties = null;

    public static String decimalFormat(String decimal) {

        return NumberUtil.decimalFormat(decimal, 2);
    }

    public static String decimalFormat(String decimal, int num) {
        String string = "#0." + StringUtil.repeat("0", num);
        DecimalFormat df = new DecimalFormat(string);
        StringBuffer stringBuffer = new StringBuffer("");
        df.format(Double.valueOf(decimal), stringBuffer, new FieldPosition(num));
        decimal = stringBuffer.toString();
        return decimal;
    }

    public static String decimalFormat(Object decimal, int num) {
        String dec = decimal.toString();
        return decimalFormat(dec, num);
    }

    public static String accurateDivide(String dividend, String divisor, int digits) {
        BigDecimal decimal = BigDecimal.valueOf(Double.valueOf(dividend));
        return decimal.divide(BigDecimal.valueOf(Double.valueOf(divisor)), digits, BigDecimal.ROUND_HALF_UP).toString();
    }

    public static double accurateDivide(double dividend, double divisor, int digits) {
        BigDecimal decimal = BigDecimal.valueOf(dividend);
        return decimal.divide(BigDecimal.valueOf(divisor), digits, BigDecimal.ROUND_HALF_UP).doubleValue();
    }

    public static double round(double v, int scale) {

        if (scale < 0) {

            throw new IllegalArgumentException("The scale must be a positive integer or zero");

        }

        BigDecimal b = new BigDecimal(Double.toString(v));

        BigDecimal one = new BigDecimal("1");

        return b.divide(one, scale, BigDecimal.ROUND_HALF_UP).doubleValue();

    }

    public static int getMax(int[] values) {
        if (values != null) {
            int max = Integer.MIN_VALUE;
            for (int i : values) {
                max = max > i ? max : i;
            }
            return max;
        } else {
            return -1;
        }
    }


    public static String formatAmt(String amt, int dot) {
        String s = NumberUtil.decimalFormat(amt, dot);
        return s.replace(".", "");
    }

    public static BigDecimal round(BigDecimal amt, int scale) {
        if (amt == null)
            amt = BigDecimal.ZERO;
        if (scale < 0)
            throw new IllegalArgumentException("The scale must be a positive integer or zero");
        return amt.divide(BigDecimal.ONE, scale, 4);
    }

    public static String formatAmt(BigDecimal amt, String ccy) {
        if (amt == null) {
            throw new RuntimeException("Source Amt cannot be null.");
        }
        int ccyDecimalNum = getCcyDecimalNum(ccy);
        amt = round(amt, ccyDecimalNum);
        String s = NumberUtil.decimalFormat(amt.toString(), ccyDecimalNum);
        String pointSuffiex = ".";
        for (int i=0; i<ccyDecimalNum; i++) {
            pointSuffiex +="0";
        }
        if (s.indexOf(pointSuffiex) > -1) { //like 1000.00 -> 1000,
           return s.replace(pointSuffiex, ",");
        } else {
            return s.replace(".", ",");//like 1000.01 -> 1000,01
        }
    }

    /**
     * 从币种小数位数配置文件中获取币种对应的小数点位数
     * 默认值是2
     * @param ccy
     * @return
     */
    private static int getCcyDecimalNum(String ccy) {
        try {
            if (properties == null) {
                String fileName = "/CurrencyDecimalDigits.properties";
                InputStream resourceAsStream = NumberUtil.class.getResourceAsStream(fileName);
                properties = new Properties();
                properties.load(resourceAsStream);
            }
            if (properties != null) {
                String decimalNumStr = properties.getProperty(ccy, "2");
                return Integer.parseInt(decimalNumStr);
            }
            return 2;
        } catch (
        IOException e) {
            throw new SwiftException("ERROR", e.getMessage());
        }
    }

}
