package com.brilliance.swift.vo;

import com.google.gson.*;

import java.lang.reflect.Type;

public class SwiftDtoAdapter implements JsonSerializer<SwiftDto>, JsonDeserializer<SwiftDto> {

    private static final String MESSAGETYPE = "messageType";

    @Override
    public SwiftDto deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
        JsonObject jsonObject = json.getAsJsonObject();
        JsonObject jsonObject1 = jsonObject.getAsJsonObject("swiftHeader");
        JsonPrimitive prim = (JsonPrimitive) jsonObject1.get(MESSAGETYPE);
        if (prim == null) {
            throw new JsonParseException("Missing " + MESSAGETYPE + " in JSON structure");
        }
        Class<?> klass = null;
        try {
            String className = "";
            if ("pacs.008.001".equals(prim.getAsString())) {
                className = "com.brilliance.swift.vo.VoCustomerCreditTransfer";
            } else if ("pacs.009.001".equals(prim.getAsString())) {
                className = "com.brilliance.swift.vo.VoFinancialInstitutionCreditTransfer";
            }else if("camt.054.001".equals(prim.getAsString())){
                className = "com.brilliance.swift.vo.BankToCustomerDebitCreditNotification";
            }else if("camt.053.001".equals(prim.getAsString())){
                className = "com.brilliance.swift.vo.BankToCustomerStatement";
            }
            klass = Class.forName(className);
        } catch (ClassNotFoundException e) {
            throw new JsonParseException("Cannot find MX implementation for " + e.getMessage());
        }
        return context.deserialize(json, klass);
    }

    @Override
    public JsonElement serialize(SwiftDto src, Type typeOfSrc, JsonSerializationContext context) {
        JsonObject object = context.serialize(src).getAsJsonObject();
        return object;
    }
}
